/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "MorphologicalAnalysis.MorphologicalParse",
        "sources": [
            "MorphologicalAnalysis/MorphologicalParse.pyx"
        ]
    },
    "module_name": "MorphologicalAnalysis.MorphologicalParse"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__MorphologicalAnalysis__MorphologicalParse
#define __PYX_HAVE_API__MorphologicalAnalysis__MorphologicalParse
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "MorphologicalAnalysis/MorphologicalParse.pyx",
  "stringsource",
  "Word.pxd",
  "MorphologicalAnalysis/InflectionalGroup.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_10Dictionary_4Word_Word;
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;

/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_10Dictionary_4Word_Word {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtab;
  PyObject *name;
};


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtab;
  PyObject *__pyx___IG;
};


/* "MorphologicalAnalysis/MorphologicalParse.pxd":7
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectionalGroups
 */
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtab;
  PyObject *inflectionalGroups;
  struct __pyx_obj_10Dictionary_4Word_Word *root;
};



/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_10Dictionary_4Word_Word {
  int (*charCount)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_10Dictionary_4Word_Word *, PyObject *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*toCharacters)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtabptr_10Dictionary_4Word_Word;


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  PyObject *(*containsCase)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsPlural)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, PyObject *, int __pyx_skip_dispatch);
  int (*containsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;


/* "MorphologicalAnalysis/MorphologicalParse.pyx":7
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, parse=None):
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTransitionList)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getInflectionalGroupString)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getLastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  int (*tagSize)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*firstInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*lastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getRootPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*lastIGContainsCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*lastIGContainsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*lastIGContainsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCapitalWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRootVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCardinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isHashTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isEmail)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAuxiliary)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getTreePos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPronType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getReflex)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDefinite)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDegree)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPolarity)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPerson)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVoice)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getAspect)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTense)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getMood)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbForm)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFeatures)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static struct __pyx_obj_10Dictionary_4Word_Word *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTransitionList(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroupString(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getLastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_tagSize(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_size(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_firstInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_10Dictionary_4Word_Word *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWordWithPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getRootPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsPossessive(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCapitalWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRootVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAdjective(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isProperNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPunctuation(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCardinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isOrdinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isReal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isTime(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isDate(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isHashTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isEmail(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPercent(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isFraction(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRange(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPlural(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAuxiliary(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_containsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTreePos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPronType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getReflex(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDefinite(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDegree(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPolarity(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPerson(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVoice(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getAspect(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTense(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getMood(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVerbForm(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyFeatures(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_uPos, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'Dictionary.Word' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Word_Word = 0;

/* Module declarations from 'MorphologicalAnalysis.InflectionalGroup' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = 0;

/* Module declarations from 'MorphologicalAnalysis.MorphologicalParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = 0;
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse__set_state(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "MorphologicalAnalysis.MorphologicalParse"
extern int __pyx_module_is_main_MorphologicalAnalysis__MorphologicalParse;
int __pyx_module_is_main_MorphologicalAnalysis__MorphologicalParse = 0;

/* Implementation of 'MorphologicalAnalysis.MorphologicalParse' */
static PyObject *__pyx_builtin_range;
static const char __pyx_k_[] = "+";
static const char __pyx_k_1[] = "1";
static const char __pyx_k_2[] = "2";
static const char __pyx_k_3[] = "3";
static const char __pyx_k_X[] = "X";
static const char __pyx_k_m[] = "m\304\261";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_u[] = "\305\237u";
static const char __pyx_k_DB[] = "^DB+";
static const char __pyx_k_DP[] = "DP";
static const char __pyx_k_NP[] = "NP";
static const char __pyx_k_PP[] = "PP";
static const char __pyx_k_VP[] = "VP";
static const char __pyx_k_WP[] = "WP";
static const char __pyx_k__4[] = "!";
static const char __pyx_k__5[] = "?";
static const char __pyx_k__6[] = ".";
static const char __pyx_k__7[] = ";";
static const char __pyx_k__8[] = "-";
static const char __pyx_k__9[] = "--";
static const char __pyx_k_bu[] = "bu";
static const char __pyx_k_en[] = "en";
static const char __pyx_k_et[] = "et";
static const char __pyx_k_ka[] = "ka\303\247";
static const char __pyx_k_ki[] = "ki";
static const char __pyx_k_mi[] = "mi";
static const char __pyx_k_mu[] = "mu";
static const char __pyx_k_ne[] = "ne";
static const char __pyx_k_ol[] = "ol";
static const char __pyx_k_ADJ[] = "ADJ";
static const char __pyx_k_ADP[] = "ADP";
static const char __pyx_k_ADV[] = "ADV";
static const char __pyx_k_AUX[] = "AUX";
static const char __pyx_k_Abl[] = "Abl";
static const char __pyx_k_Acc[] = "Acc";
static const char __pyx_k_Cau[] = "Cau";
static const char __pyx_k_Cmp[] = "Cmp";
static const char __pyx_k_Cnd[] = "Cnd";
static const char __pyx_k_DET[] = "DET";
static const char __pyx_k_Dat[] = "Dat";
static const char __pyx_k_Def[] = "Def";
static const char __pyx_k_Dem[] = "Dem";
static const char __pyx_k_Des[] = "Des";
static const char __pyx_k_Dur[] = "Dur";
static const char __pyx_k_Fut[] = "Fut";
static const char __pyx_k_Gen[] = "Gen";
static const char __pyx_k_Hab[] = "Hab";
static const char __pyx_k_Imp[] = "Imp";
static const char __pyx_k_Ind[] = "Ind";
static const char __pyx_k_Ins[] = "Ins";
static const char __pyx_k_Int[] = "Int";
static const char __pyx_k_LRB[] = "-LRB-";
static const char __pyx_k_Loc[] = "Loc";
static const char __pyx_k_NEG[] = "NEG";
static const char __pyx_k_NUM[] = "NUM";
static const char __pyx_k_Nec[] = "Nec";
static const char __pyx_k_Neg[] = "Neg";
static const char __pyx_k_Nom[] = "Nom";
static const char __pyx_k_Opt[] = "Opt";
static const char __pyx_k_Ord[] = "Ord";
static const char __pyx_k_Pos[] = "Pos";
static const char __pyx_k_Pqp[] = "Pqp";
static const char __pyx_k_Prs[] = "Prs";
static const char __pyx_k_RRB[] = "-RRB-";
static const char __pyx_k_Rcp[] = "Rcp";
static const char __pyx_k_Rfl[] = "Rfl";
static const char __pyx_k_Sup[] = "Sup";
static const char __pyx_k_XXX[] = "-XXX-";
static const char __pyx_k_Yes[] = "Yes";
static const char __pyx_k__10[] = ":";
static const char __pyx_k__11[] = "(";
static const char __pyx_k__12[] = ")";
static const char __pyx_k__13[] = "";
static const char __pyx_k__14[] = "%";
static const char __pyx_k_baz[] = "baz\304\261";
static const char __pyx_k_bir[] = "bir";
static const char __pyx_k_btn[] = "b\303\274t\303\274n";
static const char __pyx_k_eer[] = "e\304\237er";
static const char __pyx_k_her[] = "her";
static const char __pyx_k_kim[] = "kim";
static const char __pyx_k_lrb[] = "-lrb-";
static const char __pyx_k_m_2[] = "m\303\274";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_rrb[] = "-rrb-";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_yap[] = "yap";
static const char __pyx_k_A1PL[] = "A1PL";
static const char __pyx_k_A1SG[] = "A1SG";
static const char __pyx_k_A2PL[] = "A2PL";
static const char __pyx_k_A2SG[] = "A2SG";
static const char __pyx_k_A3PL[] = "A3PL";
static const char __pyx_k_A3SG[] = "A3SG";
static const char __pyx_k_ADJP[] = "ADJP";
static const char __pyx_k_ADVP[] = "ADVP";
static const char __pyx_k_CONJ[] = "CONJ";
static const char __pyx_k_Card[] = "Card";
static const char __pyx_k_Case[] = "Case=";
static const char __pyx_k_Conv[] = "Conv";
static const char __pyx_k_DATE[] = "DATE";
static const char __pyx_k_Dist[] = "Dist";
static const char __pyx_k_INTJ[] = "INTJ";
static const char __pyx_k_Mood[] = "Mood=";
static const char __pyx_k_NOMP[] = "NOMP";
static const char __pyx_k_NOUN[] = "NOUN";
static const char __pyx_k_NULL[] = "NULL";
static const char __pyx_k_P1PL[] = "P1PL";
static const char __pyx_k_P1SG[] = "P1SG";
static const char __pyx_k_P2PL[] = "P2PL";
static const char __pyx_k_P2SG[] = "P2SG";
static const char __pyx_k_P3PL[] = "P3PL";
static const char __pyx_k_P3SG[] = "P3SG";
static const char __pyx_k_PRON[] = "PRON";
static const char __pyx_k_Part[] = "Part";
static const char __pyx_k_Pass[] = "Pass";
static const char __pyx_k_Past[] = "Past";
static const char __pyx_k_Perf[] = "Perf";
static const char __pyx_k_Plur[] = "Plur";
static const char __pyx_k_Pres[] = "Pres";
static const char __pyx_k_Prog[] = "Prog";
static const char __pyx_k_Punc[] = "++Punc";
static const char __pyx_k_QUES[] = "QUES";
static const char __pyx_k_REAL[] = "REAL";
static const char __pyx_k_STAY[] = "STAY";
static const char __pyx_k_Sing[] = "Sing";
static const char __pyx_k_TIME[] = "TIME";
static const char __pyx_k_VERB[] = "VERB";
static const char __pyx_k_ZERO[] = "ZERO";
static const char __pyx_k_daha[] = "daha";
static const char __pyx_k_deil[] = "de\304\237il";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_diye[] = "diye";
static const char __pyx_k_kanc[] = "ka\303\247\304\261nc\304\261";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_nasl[] = "nas\304\261l";
static const char __pyx_k_nere[] = "nere";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_CCONJ[] = "CCONJ";
static const char __pyx_k_CONJP[] = "CONJP";
static const char __pyx_k_EMAIL[] = "EMAIL";
static const char __pyx_k_INTJP[] = "INTJP";
static const char __pyx_k_POSTP[] = "POSTP";
static const char __pyx_k_PROPN[] = "PROPN";
static const char __pyx_k_PUNCT[] = "PUNCT";
static const char __pyx_k_RANGE[] = "RANGE";
static const char __pyx_k_Rapid[] = "Rapid";
static const char __pyx_k_SCONJ[] = "SCONJ";
static const char __pyx_k_START[] = "START";
static const char __pyx_k_Tense[] = "Tense=";
static const char __pyx_k_Voice[] = "Voice=";
static const char __pyx_k_birka[] = "birka\303\247";
static const char __pyx_k_hangi[] = "hangi";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_kendi[] = "kendi";
static const char __pyx_k_parse[] = "parse";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_ADVERB[] = "ADVERB";
static const char __pyx_k_AORIST[] = "AORIST";
static const char __pyx_k_Aspect[] = "Aspect=";
static const char __pyx_k_DATIVE[] = "DATIVE";
static const char __pyx_k_DESIRE[] = "DESIRE";
static const char __pyx_k_Degree[] = "Degree=";
static const char __pyx_k_FUTURE[] = "FUTURE";
static const char __pyx_k_NUMBER[] = "NUMBER";
static const char __pyx_k_Number[] = "Number=";
static const char __pyx_k_Person[] = "Person=";
static const char __pyx_k_Punc_2[] = "Punc";
static const char __pyx_k_REPEAT[] = "REPEAT";
static const char __pyx_k_Reflex[] = "Reflex=";
static const char __pyx_k_getPos[] = "getPos";
static const char __pyx_k_getTag[] = "getTag";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_isDate[] = "isDate";
static const char __pyx_k_isNoun[] = "isNoun";
static const char __pyx_k_isReal[] = "isReal";
static const char __pyx_k_isTime[] = "isTime";
static const char __pyx_k_isVerb[] = "isVerb";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_HASHTAG[] = "HASHTAG";
static const char __pyx_k_HASTILY[] = "HASTILY";
static const char __pyx_k_NumType[] = "NumType=";
static const char __pyx_k_ORDINAL[] = "ORDINAL";
static const char __pyx_k_PASSIVE[] = "PASSIVE";
static const char __pyx_k_PERCENT[] = "PERCENT";
static const char __pyx_k_PRONOUN[] = "PRONOUN";
static const char __pyx_k_birbiri[] = "birbiri";
static const char __pyx_k_getCase[] = "getCase";
static const char __pyx_k_getMood[] = "getMood";
static const char __pyx_k_getWord[] = "getWord";
static const char __pyx_k_isEmail[] = "isEmail";
static const char __pyx_k_isRange[] = "isRange";
static const char __pyx_k_isupper[] = "isupper";
static const char __pyx_k_tagSize[] = "tagSize";
static const char __pyx_k_ABLATIVE[] = "ABLATIVE";
static const char __pyx_k_CARDINAL[] = "CARDINAL";
static const char __pyx_k_Definite[] = "Definite=";
static const char __pyx_k_FRACTION[] = "FRACTION";
static const char __pyx_k_GENITIVE[] = "GENITIVE";
static const char __pyx_k_LOCATIVE[] = "LOCATIVE";
static const char __pyx_k_NEGATIVE[] = "NEGATIVE";
static const char __pyx_k_OPTATIVE[] = "OPTATIVE";
static const char __pyx_k_PCDATIVE[] = "PCDATIVE";
static const char __pyx_k_POSITIVE[] = "POSITIVE";
static const char __pyx_k_Polarity[] = "Polarity=";
static const char __pyx_k_PronType[] = "PronType=";
static const char __pyx_k_VerbForm[] = "VerbForm=";
static const char __pyx_k_getTense[] = "getTense";
static const char __pyx_k_getVoice[] = "getVoice";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_isNumber[] = "isNumber";
static const char __pyx_k_isPlural[] = "isPlural";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_BYDOINGSO[] = "BYDOINGSO";
static const char __pyx_k_CAUSATIVE[] = "CAUSATIVE";
static const char __pyx_k_NARRATIVE[] = "NARRATIVE";
static const char __pyx_k_NECESSITY[] = "NECESSITY";
static const char __pyx_k_PASTTENSE[] = "PASTTENSE";
static const char __pyx_k_REFLEXIVE[] = "REFLEXIVE";
static const char __pyx_k_getAspect[] = "getAspect";
static const char __pyx_k_getDegree[] = "getDegree";
static const char __pyx_k_getNumber[] = "getNumber";
static const char __pyx_k_getPerson[] = "getPerson";
static const char __pyx_k_getReflex[] = "getReflex";
static const char __pyx_k_isHashTag[] = "isHashTag";
static const char __pyx_k_isOrdinal[] = "isOrdinal";
static const char __pyx_k_isPercent[] = "isPercent";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_ACCUSATIVE[] = "ACCUSATIVE";
static const char __pyx_k_DETERMINER[] = "DETERMINER";
static const char __pyx_k_IMPERATIVE[] = "IMPERATIVE";
static const char __pyx_k_NOMINATIVE[] = "NOMINATIVE";
static const char __pyx_k_PCABLATIVE[] = "PCABLATIVE";
static const char __pyx_k_PCGENITIVE[] = "PCGENITIVE";
static const char __pyx_k_PROPERNOUN[] = "PROPERNOUN";
static const char __pyx_k_RECIPROCAL[] = "RECIPROCAL";
static const char __pyx_k_birbirleri[] = "birbirleri";
static const char __pyx_k_getNumType[] = "getNumType";
static const char __pyx_k_getRootPos[] = "getRootPos";
static const char __pyx_k_getTreePos[] = "getTreePos";
static const char __pyx_k_isCardinal[] = "isCardinal";
static const char __pyx_k_isFraction[] = "isFraction";
static const char __pyx_k_isRootVerb[] = "isRootVerb";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_CONDITIONAL[] = "CONDITIONAL";
static const char __pyx_k_CONJUNCTION[] = "CONJUNCTION";
static const char __pyx_k_INFINITIVE3[] = "INFINITIVE3";
static const char __pyx_k_PUNCTUATION[] = "PUNCTUATION";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_containsTag[] = "containsTag";
static const char __pyx_k_getDefinite[] = "getDefinite";
static const char __pyx_k_getPolarity[] = "getPolarity";
static const char __pyx_k_getPronType[] = "getPronType";
static const char __pyx_k_getVerbForm[] = "getVerbForm";
static const char __pyx_k_isAdjective[] = "isAdjective";
static const char __pyx_k_isAuxiliary[] = "isAuxiliary";
static const char __pyx_k_AFTERDOINGSO[] = "AFTERDOINGSO";
static const char __pyx_k_DISTRIBUTIVE[] = "DISTRIBUTIVE";
static const char __pyx_k_INSTRUMENTAL[] = "INSTRUMENTAL";
static const char __pyx_k_INTERJECTION[] = "INTERJECTION";
static const char __pyx_k_PCACCUSATIVE[] = "PCACCUSATIVE";
static const char __pyx_k_PCNOMINATIVE[] = "PCNOMINATIVE";
static const char __pyx_k_POSTPOSITION[] = "POSTPOSITION";
static const char __pyx_k_PROGRESSIVE1[] = "PROGRESSIVE1";
static const char __pyx_k_PROGRESSIVE2[] = "PROGRESSIVE2";
static const char __pyx_k_SINCEDOINGSO[] = "SINCEDOINGSO";
static const char __pyx_k_getTagString[] = "getTagString";
static const char __pyx_k_isProperNoun[] = "isProperNoun";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_isCapitalWord[] = "isCapitalWord";
static const char __pyx_k_isPunctuation[] = "isPunctuation";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_PASTPARTICIPLE[] = "PASTPARTICIPLE";
static const char __pyx_k_PCINSTRUMENTAL[] = "PCINSTRUMENTAL";
static const char __pyx_k_getWordWithPos[] = "getWordWithPos";
static const char __pyx_k_PERSONALPRONOUN[] = "PERSONALPRONOUN";
static const char __pyx_k_QUESTIONPRONOUN[] = "QUESTIONPRONOUN";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_FUTUREPARTICIPLE[] = "FUTUREPARTICIPLE";
static const char __pyx_k_MorphologicalTag[] = "MorphologicalTag";
static const char __pyx_k_PRESENTPARTICIPLE[] = "PRESENTPARTICIPLE";
static const char __pyx_k_getTransitionList[] = "getTransitionList";
static const char __pyx_k_lastIGContainsTag[] = "lastIGContainsTag";
static const char __pyx_k_MorphologicalParse[] = "MorphologicalParse";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_lastIGContainsCase[] = "lastIGContainsCase";
static const char __pyx_k_WITHOUTHAVINGDONESO[] = "WITHOUTHAVINGDONESO";
static const char __pyx_k_DEMONSTRATIVEPRONOUN[] = "DEMONSTRATIVEPRONOUN";
static const char __pyx_k_getInflectionalGroup[] = "getInflectionalGroup";
static const char __pyx_k_lastInflectionalGroup[] = "lastInflectionalGroup";
static const char __pyx_k_firstInflectionalGroup[] = "firstInflectionalGroup";
static const char __pyx_k_getLastInflectionalGroup[] = "getLastInflectionalGroup";
static const char __pyx_k_lastIGContainsPossessive[] = "lastIGContainsPossessive";
static const char __pyx_k_getUniversalDependencyPos[] = "getUniversalDependencyPos";
static const char __pyx_k_getInflectionalGroupString[] = "getInflectionalGroupString";
static const char __pyx_k_WITHOUTBEINGABLETOHAVEDONESO[] = "WITHOUTBEINGABLETOHAVEDONESO";
static const char __pyx_k_getUniversalDependencyFeatures[] = "getUniversalDependencyFeatures";
static const char __pyx_k_pyx_unpickle_MorphologicalPars[] = "__pyx_unpickle_MorphologicalParse";
static const char __pyx_k_Incompatible_checksums_s_vs_0xbe[] = "Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))";
static const char __pyx_k_MorphologicalAnalysis_Morphologi[] = "MorphologicalAnalysis.MorphologicalTag";
static const char __pyx_k_MorphologicalAnalysis_Morphologi_2[] = "MorphologicalAnalysis.MorphologicalParse";
static PyObject *__pyx_kp_u_;
static PyObject *__pyx_kp_u_1;
static PyObject *__pyx_kp_u_2;
static PyObject *__pyx_kp_u_3;
static PyObject *__pyx_n_s_A1PL;
static PyObject *__pyx_n_s_A1SG;
static PyObject *__pyx_n_s_A2PL;
static PyObject *__pyx_n_s_A2SG;
static PyObject *__pyx_n_s_A3PL;
static PyObject *__pyx_n_s_A3SG;
static PyObject *__pyx_n_s_ABLATIVE;
static PyObject *__pyx_n_s_ACCUSATIVE;
static PyObject *__pyx_n_u_ADJ;
static PyObject *__pyx_n_u_ADJP;
static PyObject *__pyx_n_u_ADP;
static PyObject *__pyx_n_u_ADV;
static PyObject *__pyx_n_s_ADVERB;
static PyObject *__pyx_n_u_ADVP;
static PyObject *__pyx_n_s_AFTERDOINGSO;
static PyObject *__pyx_n_s_AORIST;
static PyObject *__pyx_n_u_AUX;
static PyObject *__pyx_n_u_Abl;
static PyObject *__pyx_n_u_Acc;
static PyObject *__pyx_kp_u_Aspect;
static PyObject *__pyx_n_s_BYDOINGSO;
static PyObject *__pyx_n_s_CARDINAL;
static PyObject *__pyx_n_s_CAUSATIVE;
static PyObject *__pyx_n_u_CCONJ;
static PyObject *__pyx_n_s_CONDITIONAL;
static PyObject *__pyx_n_u_CONJ;
static PyObject *__pyx_n_u_CONJP;
static PyObject *__pyx_n_s_CONJUNCTION;
static PyObject *__pyx_n_u_Card;
static PyObject *__pyx_kp_u_Case;
static PyObject *__pyx_n_u_Cau;
static PyObject *__pyx_n_u_Cmp;
static PyObject *__pyx_n_u_Cnd;
static PyObject *__pyx_n_u_Conv;
static PyObject *__pyx_n_s_DATE;
static PyObject *__pyx_n_s_DATIVE;
static PyObject *__pyx_kp_u_DB;
static PyObject *__pyx_n_s_DEMONSTRATIVEPRONOUN;
static PyObject *__pyx_n_s_DESIRE;
static PyObject *__pyx_n_u_DET;
static PyObject *__pyx_n_s_DETERMINER;
static PyObject *__pyx_n_s_DISTRIBUTIVE;
static PyObject *__pyx_n_u_DP;
static PyObject *__pyx_n_u_Dat;
static PyObject *__pyx_n_u_Def;
static PyObject *__pyx_kp_u_Definite;
static PyObject *__pyx_kp_u_Degree;
static PyObject *__pyx_n_u_Dem;
static PyObject *__pyx_n_u_Des;
static PyObject *__pyx_n_u_Dist;
static PyObject *__pyx_n_u_Dur;
static PyObject *__pyx_n_s_EMAIL;
static PyObject *__pyx_n_s_FRACTION;
static PyObject *__pyx_n_s_FUTURE;
static PyObject *__pyx_n_s_FUTUREPARTICIPLE;
static PyObject *__pyx_n_u_Fut;
static PyObject *__pyx_n_s_GENITIVE;
static PyObject *__pyx_n_u_Gen;
static PyObject *__pyx_n_s_HASHTAG;
static PyObject *__pyx_n_s_HASTILY;
static PyObject *__pyx_n_u_Hab;
static PyObject *__pyx_n_s_IMPERATIVE;
static PyObject *__pyx_n_s_INFINITIVE3;
static PyObject *__pyx_n_s_INSTRUMENTAL;
static PyObject *__pyx_n_s_INTERJECTION;
static PyObject *__pyx_n_u_INTJ;
static PyObject *__pyx_n_u_INTJP;
static PyObject *__pyx_n_u_Imp;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xbe;
static PyObject *__pyx_n_u_Ind;
static PyObject *__pyx_n_u_Ins;
static PyObject *__pyx_n_u_Int;
static PyObject *__pyx_n_s_LOCATIVE;
static PyObject *__pyx_kp_u_LRB;
static PyObject *__pyx_n_u_Loc;
static PyObject *__pyx_kp_u_Mood;
static PyObject *__pyx_n_s_MorphologicalAnalysis_Morphologi;
static PyObject *__pyx_n_s_MorphologicalAnalysis_Morphologi_2;
static PyObject *__pyx_n_s_MorphologicalParse;
static PyObject *__pyx_n_s_MorphologicalTag;
static PyObject *__pyx_n_s_NARRATIVE;
static PyObject *__pyx_n_s_NECESSITY;
static PyObject *__pyx_n_u_NEG;
static PyObject *__pyx_n_s_NEGATIVE;
static PyObject *__pyx_n_s_NOMINATIVE;
static PyObject *__pyx_n_u_NOMP;
static PyObject *__pyx_n_u_NOUN;
static PyObject *__pyx_n_u_NP;
static PyObject *__pyx_n_u_NULL;
static PyObject *__pyx_n_u_NUM;
static PyObject *__pyx_n_s_NUMBER;
static PyObject *__pyx_n_u_Nec;
static PyObject *__pyx_n_u_Neg;
static PyObject *__pyx_n_u_Nom;
static PyObject *__pyx_kp_u_NumType;
static PyObject *__pyx_kp_u_Number;
static PyObject *__pyx_n_s_OPTATIVE;
static PyObject *__pyx_n_s_ORDINAL;
static PyObject *__pyx_n_u_Opt;
static PyObject *__pyx_n_u_Ord;
static PyObject *__pyx_n_s_P1PL;
static PyObject *__pyx_n_s_P1SG;
static PyObject *__pyx_n_s_P2PL;
static PyObject *__pyx_n_s_P2SG;
static PyObject *__pyx_n_s_P3PL;
static PyObject *__pyx_n_s_P3SG;
static PyObject *__pyx_n_s_PASSIVE;
static PyObject *__pyx_n_s_PASTPARTICIPLE;
static PyObject *__pyx_n_s_PASTTENSE;
static PyObject *__pyx_n_s_PCABLATIVE;
static PyObject *__pyx_n_s_PCACCUSATIVE;
static PyObject *__pyx_n_s_PCDATIVE;
static PyObject *__pyx_n_s_PCGENITIVE;
static PyObject *__pyx_n_s_PCINSTRUMENTAL;
static PyObject *__pyx_n_s_PCNOMINATIVE;
static PyObject *__pyx_n_s_PERCENT;
static PyObject *__pyx_n_s_PERSONALPRONOUN;
static PyObject *__pyx_n_s_POSITIVE;
static PyObject *__pyx_n_u_POSTP;
static PyObject *__pyx_n_s_POSTPOSITION;
static PyObject *__pyx_n_u_PP;
static PyObject *__pyx_n_s_PRESENTPARTICIPLE;
static PyObject *__pyx_n_s_PROGRESSIVE1;
static PyObject *__pyx_n_s_PROGRESSIVE2;
static PyObject *__pyx_n_u_PRON;
static PyObject *__pyx_n_s_PRONOUN;
static PyObject *__pyx_n_s_PROPERNOUN;
static PyObject *__pyx_n_u_PROPN;
static PyObject *__pyx_n_u_PUNCT;
static PyObject *__pyx_n_s_PUNCTUATION;
static PyObject *__pyx_n_u_Part;
static PyObject *__pyx_n_u_Pass;
static PyObject *__pyx_n_u_Past;
static PyObject *__pyx_n_u_Perf;
static PyObject *__pyx_kp_u_Person;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_u_Plur;
static PyObject *__pyx_kp_u_Polarity;
static PyObject *__pyx_n_u_Pos;
static PyObject *__pyx_n_u_Pqp;
static PyObject *__pyx_n_u_Pres;
static PyObject *__pyx_n_u_Prog;
static PyObject *__pyx_kp_u_PronType;
static PyObject *__pyx_n_u_Prs;
static PyObject *__pyx_kp_u_Punc;
static PyObject *__pyx_n_u_Punc_2;
static PyObject *__pyx_n_u_QUES;
static PyObject *__pyx_n_s_QUESTIONPRONOUN;
static PyObject *__pyx_n_s_RANGE;
static PyObject *__pyx_n_s_REAL;
static PyObject *__pyx_n_s_RECIPROCAL;
static PyObject *__pyx_n_s_REFLEXIVE;
static PyObject *__pyx_n_s_REPEAT;
static PyObject *__pyx_kp_u_RRB;
static PyObject *__pyx_n_u_Rapid;
static PyObject *__pyx_n_u_Rcp;
static PyObject *__pyx_kp_u_Reflex;
static PyObject *__pyx_n_u_Rfl;
static PyObject *__pyx_n_u_SCONJ;
static PyObject *__pyx_n_s_SINCEDOINGSO;
static PyObject *__pyx_n_s_START;
static PyObject *__pyx_n_s_STAY;
static PyObject *__pyx_n_u_Sing;
static PyObject *__pyx_n_u_Sup;
static PyObject *__pyx_n_s_TIME;
static PyObject *__pyx_kp_u_Tense;
static PyObject *__pyx_n_u_VERB;
static PyObject *__pyx_n_u_VP;
static PyObject *__pyx_kp_u_VerbForm;
static PyObject *__pyx_kp_u_Voice;
static PyObject *__pyx_n_s_WITHOUTBEINGABLETOHAVEDONESO;
static PyObject *__pyx_n_s_WITHOUTHAVINGDONESO;
static PyObject *__pyx_n_u_WP;
static PyObject *__pyx_n_u_X;
static PyObject *__pyx_kp_u_XXX;
static PyObject *__pyx_n_u_Yes;
static PyObject *__pyx_n_s_ZERO;
static PyObject *__pyx_kp_u__10;
static PyObject *__pyx_kp_u__11;
static PyObject *__pyx_kp_u__12;
static PyObject *__pyx_kp_u__13;
static PyObject *__pyx_kp_u__14;
static PyObject *__pyx_kp_u__4;
static PyObject *__pyx_kp_u__5;
static PyObject *__pyx_kp_u__6;
static PyObject *__pyx_kp_u__7;
static PyObject *__pyx_kp_u__8;
static PyObject *__pyx_kp_u__9;
static PyObject *__pyx_n_u_baz;
static PyObject *__pyx_n_u_bir;
static PyObject *__pyx_n_u_birbiri;
static PyObject *__pyx_n_u_birbirleri;
static PyObject *__pyx_n_u_birka;
static PyObject *__pyx_n_u_btn;
static PyObject *__pyx_n_u_bu;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_containsTag;
static PyObject *__pyx_n_u_daha;
static PyObject *__pyx_n_u_deil;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_u_diye;
static PyObject *__pyx_n_u_eer;
static PyObject *__pyx_n_u_en;
static PyObject *__pyx_n_u_et;
static PyObject *__pyx_n_s_firstInflectionalGroup;
static PyObject *__pyx_n_s_getAspect;
static PyObject *__pyx_n_s_getCase;
static PyObject *__pyx_n_s_getDefinite;
static PyObject *__pyx_n_s_getDegree;
static PyObject *__pyx_n_s_getInflectionalGroup;
static PyObject *__pyx_n_s_getInflectionalGroupString;
static PyObject *__pyx_n_s_getLastInflectionalGroup;
static PyObject *__pyx_n_s_getMood;
static PyObject *__pyx_n_s_getNumType;
static PyObject *__pyx_n_s_getNumber;
static PyObject *__pyx_n_s_getPerson;
static PyObject *__pyx_n_s_getPolarity;
static PyObject *__pyx_n_s_getPos;
static PyObject *__pyx_n_s_getPronType;
static PyObject *__pyx_n_s_getReflex;
static PyObject *__pyx_n_s_getRootPos;
static PyObject *__pyx_n_s_getTag;
static PyObject *__pyx_n_s_getTagString;
static PyObject *__pyx_n_s_getTense;
static PyObject *__pyx_n_s_getTransitionList;
static PyObject *__pyx_n_s_getTreePos;
static PyObject *__pyx_n_s_getUniversalDependencyFeatures;
static PyObject *__pyx_n_s_getUniversalDependencyPos;
static PyObject *__pyx_n_s_getVerbForm;
static PyObject *__pyx_n_s_getVoice;
static PyObject *__pyx_n_s_getWord;
static PyObject *__pyx_n_s_getWordWithPos;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_u_hangi;
static PyObject *__pyx_n_u_her;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_isAdjective;
static PyObject *__pyx_n_s_isAuxiliary;
static PyObject *__pyx_n_s_isCapitalWord;
static PyObject *__pyx_n_s_isCardinal;
static PyObject *__pyx_n_s_isDate;
static PyObject *__pyx_n_s_isEmail;
static PyObject *__pyx_n_s_isFraction;
static PyObject *__pyx_n_s_isHashTag;
static PyObject *__pyx_n_s_isNoun;
static PyObject *__pyx_n_s_isNumber;
static PyObject *__pyx_n_s_isOrdinal;
static PyObject *__pyx_n_s_isPercent;
static PyObject *__pyx_n_s_isPlural;
static PyObject *__pyx_n_s_isProperNoun;
static PyObject *__pyx_n_s_isPunctuation;
static PyObject *__pyx_n_s_isRange;
static PyObject *__pyx_n_s_isReal;
static PyObject *__pyx_n_s_isRootVerb;
static PyObject *__pyx_n_s_isTime;
static PyObject *__pyx_n_s_isVerb;
static PyObject *__pyx_n_s_isupper;
static PyObject *__pyx_n_u_ka;
static PyObject *__pyx_n_u_kanc;
static PyObject *__pyx_n_u_kendi;
static PyObject *__pyx_n_u_ki;
static PyObject *__pyx_n_u_kim;
static PyObject *__pyx_n_s_lastIGContainsCase;
static PyObject *__pyx_n_s_lastIGContainsPossessive;
static PyObject *__pyx_n_s_lastIGContainsTag;
static PyObject *__pyx_n_s_lastInflectionalGroup;
static PyObject *__pyx_kp_u_lrb;
static PyObject *__pyx_n_u_m;
static PyObject *__pyx_n_u_m_2;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_u_mi;
static PyObject *__pyx_n_u_mu;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_u_nasl;
static PyObject *__pyx_n_u_ne;
static PyObject *__pyx_n_u_nere;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_u_o;
static PyObject *__pyx_n_u_ol;
static PyObject *__pyx_n_s_parse;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_MorphologicalPars;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_kp_u_rrb;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_tagSize;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_u_u;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_u_yap;
static int __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_parse); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_2getWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_4getTransitionList(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_6getInflectionalGroupString(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_8getInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_10getLastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_12getTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_14tagSize(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_16size(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_18firstInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_20lastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_22getWordWithPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_24getPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_26getRootPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_28lastIGContainsCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_30lastIGContainsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_32lastIGContainsPossessive(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_34isCapitalWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_36isNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_38isVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_40isRootVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_42isAdjective(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_44isProperNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_46isPunctuation(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_48isCardinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_50isOrdinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_52isReal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_54isNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_56isTime(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_58isDate(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_60isHashTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_62isEmail(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_64isPercent(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_66isFraction(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_68isRange(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_70isPlural(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_72isAuxiliary(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_74containsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_76getTreePos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_78getPronType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_80getNumType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_82getReflex(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_84getNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_86getCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_88getDefinite(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_90getDegree(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_92getPolarity(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_94getPerson(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_96getVoice(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_98getAspect(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_100getTense(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_102getMood(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_104getVerbForm(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_106getUniversalDependencyFeatures(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_uPos); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_108getUniversalDependencyPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_112__reduce_cython__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_114__setstate_cython__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_index = {0, &__pyx_n_s_index, 0, 0, 0};
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_199806697;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_codeobj__16;
/* Late includes */

/* "MorphologicalAnalysis/MorphologicalParse.pyx":9
 * cdef class MorphologicalParse:
 * 
 *     def __init__(self, parse=None):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor of MorphologicalParse class which takes a String parse as an input. First it creates
 */

/* Python wrapper */
static int __pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__[] = "\n        Constructor of MorphologicalParse class which takes a String parse as an input. First it creates\n        a list as iGs for inflectional groups, and while given String contains derivational boundary (^DB+), it\n        adds the substring to the iGs list and continue to use given String from 4th index. If it does not contain ^DB+,\n        it directly adds the given String to the iGs list. Then, it creates a new list as\n        inflectionalGroups and checks for some cases.\n\n        If the first item of iGs list is ++Punc, it creates a new root as +, and by calling\n        InflectionalGroup method with Punc it initializes the IG list by parsing given input\n        String IG by + and calling the getMorphologicalTag method with these substrings. If getMorphologicalTag method\n        returns a tag, it adds this tag to the IG list and also to the inflectionalGroups list.\n\n        If the first item of iGs list has +, it creates a new word of first item's substring from index 0 to +,\n        and assigns it to root. Then, by calling InflectionalGroup method with substring from index 0 to +,\n        it initializes the IG list by parsing given input String IG by + and calling the getMorphologicalTag\n        method with these substrings. If getMorphologicalTag method returns a tag, it adds this tag to the IG list\n        and also to the inflectionalGroups list.\n\n        If the first item of iGs list does not contain +, it creates a new word with first item and assigns it as root.\n        At the end, it loops through the items of iGs and by calling InflectionalGroup method with these items\n        it initializes the IG list by parsing given input String IG by + and calling the getMorphologicalTag\n        method with these substrings. If getMorphologicalTag method returns a tag, it adds this tag to the IG list\n        and also to the inflectionalGroups list.\n\n        PARAMETERS\n        ----------\n        parse : str\n            String input.\n    ""    ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__;
#endif
static int __pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_parse = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_parse,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parse);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 9, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_parse = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 9, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), __pyx_v_parse);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_parse) {
  PyObject *__pyx_v_iGs = 0;
  PyObject *__pyx_v_st = 0;
  int __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":42
 *         cdef str st
 *         cdef int i
 *         if parse is not None:             # <<<<<<<<<<<<<<
 *             if isinstance(parse, str):
 *                 iGs = []
 */
  __pyx_t_1 = (__pyx_v_parse != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":43
 *         cdef int i
 *         if parse is not None:
 *             if isinstance(parse, str):             # <<<<<<<<<<<<<<
 *                 iGs = []
 *                 st = parse
 */
    __pyx_t_2 = PyUnicode_Check(__pyx_v_parse); 
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":44
 *         if parse is not None:
 *             if isinstance(parse, str):
 *                 iGs = []             # <<<<<<<<<<<<<<
 *                 st = parse
 *                 while "^DB+" in st:
 */
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 44, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_iGs = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":45
 *             if isinstance(parse, str):
 *                 iGs = []
 *                 st = parse             # <<<<<<<<<<<<<<
 *                 while "^DB+" in st:
 *                     iGs.append(st[:st.index("^DB+")])
 */
      if (!(likely(PyUnicode_CheckExact(__pyx_v_parse))||((__pyx_v_parse) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_parse)->tp_name), 0))) __PYX_ERR(0, 45, __pyx_L1_error)
      __pyx_t_3 = __pyx_v_parse;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_st = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":46
 *                 iGs = []
 *                 st = parse
 *                 while "^DB+" in st:             # <<<<<<<<<<<<<<
 *                     iGs.append(st[:st.index("^DB+")])
 *                     st = st[st.index("^DB+") + 4:]
 */
      while (1) {
        if (unlikely(__pyx_v_st == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(0, 46, __pyx_L1_error)
        }
        __pyx_t_1 = (__Pyx_PyUnicode_ContainsTF(__pyx_kp_u_DB, __pyx_v_st, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 46, __pyx_L1_error)
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (!__pyx_t_2) break;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":47
 *                 st = parse
 *                 while "^DB+" in st:
 *                     iGs.append(st[:st.index("^DB+")])             # <<<<<<<<<<<<<<
 *                     st = st[st.index("^DB+") + 4:]
 *                 iGs.append(st)
 */
        if (unlikely(__pyx_v_st == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 47, __pyx_L1_error)
        }
        __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_index, __pyx_v_st, __pyx_kp_u_DB); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 47, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = (__pyx_t_3 == Py_None);
        if (__pyx_t_2) {
          __pyx_t_4 = PY_SSIZE_T_MAX;
        } else {
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 47, __pyx_L1_error)
          __pyx_t_4 = __pyx_t_5;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyUnicode_Substring(__pyx_v_st, 0, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 47, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_iGs, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 47, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":48
 *                 while "^DB+" in st:
 *                     iGs.append(st[:st.index("^DB+")])
 *                     st = st[st.index("^DB+") + 4:]             # <<<<<<<<<<<<<<
 *                 iGs.append(st)
 *                 self.inflectionalGroups = []
 */
        if (unlikely(__pyx_v_st == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 48, __pyx_L1_error)
        }
        __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_index, __pyx_v_st, __pyx_kp_u_DB); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 48, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_4, 4, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 48, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_2 = (__pyx_t_7 == Py_None);
        if (__pyx_t_2) {
          __pyx_t_4 = 0;
        } else {
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_7); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 48, __pyx_L1_error)
          __pyx_t_4 = __pyx_t_5;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyUnicode_Substring(__pyx_v_st, __pyx_t_4, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 48, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF_SET(__pyx_v_st, ((PyObject*)__pyx_t_7));
        __pyx_t_7 = 0;
      }

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":49
 *                     iGs.append(st[:st.index("^DB+")])
 *                     st = st[st.index("^DB+") + 4:]
 *                 iGs.append(st)             # <<<<<<<<<<<<<<
 *                 self.inflectionalGroups = []
 *                 if iGs[0] == "++Punc":
 */
      __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_iGs, __pyx_v_st); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 49, __pyx_L1_error)

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":50
 *                     st = st[st.index("^DB+") + 4:]
 *                 iGs.append(st)
 *                 self.inflectionalGroups = []             # <<<<<<<<<<<<<<
 *                 if iGs[0] == "++Punc":
 *                     self.root = Word("+")
 */
      __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 50, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_v_self->inflectionalGroups);
      __Pyx_DECREF(__pyx_v_self->inflectionalGroups);
      __pyx_v_self->inflectionalGroups = ((PyObject*)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":51
 *                 iGs.append(st)
 *                 self.inflectionalGroups = []
 *                 if iGs[0] == "++Punc":             # <<<<<<<<<<<<<<
 *                     self.root = Word("+")
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))
 */
      __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 51, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_kp_u_Punc, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":52
 *                 self.inflectionalGroups = []
 *                 if iGs[0] == "++Punc":
 *                     self.root = Word("+")             # <<<<<<<<<<<<<<
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))
 *                 else:
 */
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 52, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_v_self->root);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->root));
        __pyx_v_self->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_7);
        __pyx_t_7 = 0;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":53
 *                 if iGs[0] == "++Punc":
 *                     self.root = Word("+")
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))             # <<<<<<<<<<<<<<
 *                 else:
 *                     if iGs[0].index("+") != -1:
 */
        if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 53, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 53, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_self->inflectionalGroups, __pyx_t_7); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 53, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":51
 *                 iGs.append(st)
 *                 self.inflectionalGroups = []
 *                 if iGs[0] == "++Punc":             # <<<<<<<<<<<<<<
 *                     self.root = Word("+")
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))
 */
        goto __pyx_L7;
      }

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":55
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))
 *                 else:
 *                     if iGs[0].index("+") != -1:             # <<<<<<<<<<<<<<
 *                         self.root = Word(iGs[0][:iGs[0].index("+")])
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[0][iGs[0].index("+") + 1:]))
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_index); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 55, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_3, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_kp_u_);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 55, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyInt_NeObjC(__pyx_t_7, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 55, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 55, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_2) {

          /* "MorphologicalAnalysis/MorphologicalParse.pyx":56
 *                 else:
 *                     if iGs[0].index("+") != -1:
 *                         self.root = Word(iGs[0][:iGs[0].index("+")])             # <<<<<<<<<<<<<<
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[0][iGs[0].index("+") + 1:]))
 *                     else:
 */
          __pyx_t_8 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 56, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 56, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 56, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_3, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_kp_u_);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 56, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_t_8, 0, 0, NULL, &__pyx_t_7, NULL, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 56, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 56, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GIVEREF(__pyx_t_7);
          __Pyx_GOTREF(__pyx_v_self->root);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->root));
          __pyx_v_self->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_7);
          __pyx_t_7 = 0;

          /* "MorphologicalAnalysis/MorphologicalParse.pyx":57
 *                     if iGs[0].index("+") != -1:
 *                         self.root = Word(iGs[0][:iGs[0].index("+")])
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[0][iGs[0].index("+") + 1:]))             # <<<<<<<<<<<<<<
 *                     else:
 *                         self.root = Word(iGs[0])
 */
          if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 57, __pyx_L1_error)
          }
          __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_9 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_8, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_kp_u_);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_9, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_t_7, 0, 0, &__pyx_t_3, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_self->inflectionalGroups, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 57, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "MorphologicalAnalysis/MorphologicalParse.pyx":55
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))
 *                 else:
 *                     if iGs[0].index("+") != -1:             # <<<<<<<<<<<<<<
 *                         self.root = Word(iGs[0][:iGs[0].index("+")])
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[0][iGs[0].index("+") + 1:]))
 */
          goto __pyx_L8;
        }

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":59
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[0][iGs[0].index("+") + 1:]))
 *                     else:
 *                         self.root = Word(iGs[0])             # <<<<<<<<<<<<<<
 *                     for i in range(1, len(iGs)):
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[i]))
 */
        /*else*/ {
          __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_iGs, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 59, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GIVEREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_v_self->root);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->root));
          __pyx_v_self->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_9);
          __pyx_t_9 = 0;
        }
        __pyx_L8:;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":60
 *                     else:
 *                         self.root = Word(iGs[0])
 *                     for i in range(1, len(iGs)):             # <<<<<<<<<<<<<<
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[i]))
 *             elif isinstance(parse, list):
 */
        __pyx_t_4 = PyList_GET_SIZE(__pyx_v_iGs); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 60, __pyx_L1_error)
        __pyx_t_5 = __pyx_t_4;
        for (__pyx_t_10 = 1; __pyx_t_10 < __pyx_t_5; __pyx_t_10+=1) {
          __pyx_v_i = __pyx_t_10;

          /* "MorphologicalAnalysis/MorphologicalParse.pyx":61
 *                         self.root = Word(iGs[0])
 *                     for i in range(1, len(iGs)):
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[i]))             # <<<<<<<<<<<<<<
 *             elif isinstance(parse, list):
 *                 self.inflectionalGroups = []
 */
          if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 61, __pyx_L1_error)
          }
          __pyx_t_9 = __Pyx_GetItemInt_List(__pyx_v_iGs, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 61, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 61, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_self->inflectionalGroups, __pyx_t_3); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 61, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
      }
      __pyx_L7:;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":43
 *         cdef int i
 *         if parse is not None:
 *             if isinstance(parse, str):             # <<<<<<<<<<<<<<
 *                 iGs = []
 *                 st = parse
 */
      goto __pyx_L4;
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":62
 *                     for i in range(1, len(iGs)):
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[i]))
 *             elif isinstance(parse, list):             # <<<<<<<<<<<<<<
 *                 self.inflectionalGroups = []
 *                 if parse[0].index("+") != -1:
 */
    __pyx_t_2 = PyList_Check(__pyx_v_parse); 
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":63
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[i]))
 *             elif isinstance(parse, list):
 *                 self.inflectionalGroups = []             # <<<<<<<<<<<<<<
 *                 if parse[0].index("+") != -1:
 *                     self.root = Word(parse[0][:parse[0].index("+")])
 */
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 63, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_v_self->inflectionalGroups);
      __Pyx_DECREF(__pyx_v_self->inflectionalGroups);
      __pyx_v_self->inflectionalGroups = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":64
 *             elif isinstance(parse, list):
 *                 self.inflectionalGroups = []
 *                 if parse[0].index("+") != -1:             # <<<<<<<<<<<<<<
 *                     self.root = Word(parse[0][:parse[0].index("+")])
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[0][parse[0].index("+") + 1:]))
 */
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_parse, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 64, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 64, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_3 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_9, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u_);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 64, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyInt_NeObjC(__pyx_t_3, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 64, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 64, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_1) {

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":65
 *                 self.inflectionalGroups = []
 *                 if parse[0].index("+") != -1:
 *                     self.root = Word(parse[0][:parse[0].index("+")])             # <<<<<<<<<<<<<<
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[0][parse[0].index("+") + 1:]))
 *                 for i in range(1, len(parse)):
 */
        __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_parse, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_parse, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_index); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        __pyx_t_3 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_kp_u_);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_t_7, 0, 0, NULL, &__pyx_t_3, NULL, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_v_self->root);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->root));
        __pyx_v_self->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3);
        __pyx_t_3 = 0;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":66
 *                 if parse[0].index("+") != -1:
 *                     self.root = Word(parse[0][:parse[0].index("+")])
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[0][parse[0].index("+") + 1:]))             # <<<<<<<<<<<<<<
 *                 for i in range(1, len(parse)):
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[i]))
 */
        if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 66, __pyx_L1_error)
        }
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_parse, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_parse, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
          }
        }
        __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_kp_u_) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_kp_u_);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_t_8, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 0, &__pyx_t_9, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_self->inflectionalGroups, __pyx_t_9); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 66, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":64
 *             elif isinstance(parse, list):
 *                 self.inflectionalGroups = []
 *                 if parse[0].index("+") != -1:             # <<<<<<<<<<<<<<
 *                     self.root = Word(parse[0][:parse[0].index("+")])
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[0][parse[0].index("+") + 1:]))
 */
      }

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":67
 *                     self.root = Word(parse[0][:parse[0].index("+")])
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[0][parse[0].index("+") + 1:]))
 *                 for i in range(1, len(parse)):             # <<<<<<<<<<<<<<
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[i]))
 * 
 */
      __pyx_t_4 = PyObject_Length(__pyx_v_parse); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 67, __pyx_L1_error)
      __pyx_t_5 = __pyx_t_4;
      for (__pyx_t_10 = 1; __pyx_t_10 < __pyx_t_5; __pyx_t_10+=1) {
        __pyx_v_i = __pyx_t_10;

        /* "MorphologicalAnalysis/MorphologicalParse.pyx":68
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[0][parse[0].index("+") + 1:]))
 *                 for i in range(1, len(parse)):
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[i]))             # <<<<<<<<<<<<<<
 * 
 *     cpdef Word getWord(self):
 */
        if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 68, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_parse, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 68, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 68, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_self->inflectionalGroups, __pyx_t_8); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 68, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":62
 *                     for i in range(1, len(iGs)):
 *                         self.inflectionalGroups.append(InflectionalGroup(iGs[i]))
 *             elif isinstance(parse, list):             # <<<<<<<<<<<<<<
 *                 self.inflectionalGroups = []
 *                 if parse[0].index("+") != -1:
 */
    }
    __pyx_L4:;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":42
 *         cdef str st
 *         cdef int i
 *         if parse is not None:             # <<<<<<<<<<<<<<
 *             if isinstance(parse, str):
 *                 iGs = []
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":9
 * cdef class MorphologicalParse:
 * 
 *     def __init__(self, parse=None):             # <<<<<<<<<<<<<<
 *         """
 *         Constructor of MorphologicalParse class which takes a String parse as an input. First it creates
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_iGs);
  __Pyx_XDECREF(__pyx_v_st);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":70
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[i]))
 * 
 *     cpdef Word getWord(self):             # <<<<<<<<<<<<<<
 *         """
 *         The no-arg getWord method returns root Word.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_3getWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_10Dictionary_4Word_Word *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_10Dictionary_4Word_Word *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWord", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getWord); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_3getWord)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 70, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_10Dictionary_4Word_Word))))) __PYX_ERR(0, 70, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":79
 *             root Word.
 *         """
 *         return self.root             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getTransitionList(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->root));
  __pyx_r = __pyx_v_self->root;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":70
 *                     self.inflectionalGroups.append(InflectionalGroup(parse[i]))
 * 
 *     cpdef Word getWord(self):             # <<<<<<<<<<<<<<
 *         """
 *         The no-arg getWord method returns root Word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_3getWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_2getWord[] = "\n        The no-arg getWord method returns root Word.\n\n        RETURNS\n        -------\n        Word\n            root Word.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_3getWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWord (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_2getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_2getWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWord", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWord(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":81
 *         return self.root
 * 
 *     cpdef str getTransitionList(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getTransitionList method gets the first item of inflectionalGroups list as a str, then loops
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_5getTransitionList(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTransitionList(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTransitionList", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getTransitionList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 81, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_5getTransitionList)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 81, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":93
 *         cdef str result
 *         cdef int i
 *         result = self.inflectionalGroups[0].__str__()             # <<<<<<<<<<<<<<
 *         for i in range(1, len(self.inflectionalGroups)):
 *             result = result + "+" + self.inflectionalGroups[i].__str__()
 */
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 93, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 93, __pyx_L1_error)
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":94
 *         cdef int i
 *         result = self.inflectionalGroups[0].__str__()
 *         for i in range(1, len(self.inflectionalGroups)):             # <<<<<<<<<<<<<<
 *             result = result + "+" + self.inflectionalGroups[i].__str__()
 *         return result
 */
  __pyx_t_1 = __pyx_v_self->inflectionalGroups;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 94, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 1; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_v_i = __pyx_t_7;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":95
 *         result = self.inflectionalGroups[0].__str__()
 *         for i in range(1, len(self.inflectionalGroups)):
 *             result = result + "+" + self.inflectionalGroups[i].__str__()             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 95, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":96
 *         for i in range(1, len(self.inflectionalGroups)):
 *             result = result + "+" + self.inflectionalGroups[i].__str__()
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getInflectionalGroupString(self, int index):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":81
 *         return self.root
 * 
 *     cpdef str getTransitionList(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getTransitionList method gets the first item of inflectionalGroups list as a str, then loops
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTransitionList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_5getTransitionList(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_4getTransitionList[] = "\n        The getTransitionList method gets the first item of inflectionalGroups list as a str, then loops\n        through the items of inflectionalGroups and concatenates them by using +.\n\n        RETURNS\n        -------\n        str\n            String that contains transition list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_5getTransitionList(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTransitionList (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_4getTransitionList(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_4getTransitionList(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTransitionList", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTransitionList(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTransitionList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":98
 *         return result
 * 
 *     cpdef str getInflectionalGroupString(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getInflectionalGroupString method takes an int index as an input and if index is 0, it directly returns the
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_7getInflectionalGroupString(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroupString(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getInflectionalGroupString", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getInflectionalGroupString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_7getInflectionalGroupString)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 98, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 98, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 98, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":114
 *             Corresponding item of inflectionalGroups at given index as a str.
 *         """
 *         if index == 0:             # <<<<<<<<<<<<<<
 *             return self.root.getName() + "+" + self.inflectionalGroups[0].__str__()
 *         else:
 */
  __pyx_t_6 = ((__pyx_v_index == 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":115
 *         """
 *         if index == 0:
 *             return self.root.getName() + "+" + self.inflectionalGroups[0].__str__()             # <<<<<<<<<<<<<<
 *         else:
 *             return self.inflectionalGroups[index].__str__()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_kp_u_); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 115, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 115, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":114
 *             Corresponding item of inflectionalGroups at given index as a str.
 *         """
 *         if index == 0:             # <<<<<<<<<<<<<<
 *             return self.root.getName() + "+" + self.inflectionalGroups[0].__str__()
 *         else:
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":117
 *             return self.root.getName() + "+" + self.inflectionalGroups[0].__str__()
 *         else:
 *             return self.inflectionalGroups[index].__str__()             # <<<<<<<<<<<<<<
 * 
 *     cpdef InflectionalGroup getInflectionalGroup(self, int index):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 117, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, __pyx_v_index, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 117, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":98
 *         return result
 * 
 *     cpdef str getInflectionalGroupString(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getInflectionalGroupString method takes an int index as an input and if index is 0, it directly returns the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getInflectionalGroupString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_7getInflectionalGroupString(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_6getInflectionalGroupString[] = "\n        The getInflectionalGroupString method takes an int index as an input and if index is 0, it directly returns the\n        root and the first item of inflectionalGroups list. If the index is not 0, it then returns the corresponding\n        item of inflectionalGroups list as a str.\n\n        PARAMETERS\n        ----------\n        index : int\n            Integer input.\n\n        RETURNS\n        -------\n        str\n            Corresponding item of inflectionalGroups at given index as a str.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_7getInflectionalGroupString(PyObject *__pyx_v_self, PyObject *__pyx_arg_index) {
  int __pyx_v_index;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getInflectionalGroupString (wrapper)", 0);
  assert(__pyx_arg_index); {
    __pyx_v_index = __Pyx_PyInt_As_int(__pyx_arg_index); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 98, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getInflectionalGroupString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_6getInflectionalGroupString(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((int)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_6getInflectionalGroupString(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getInflectionalGroupString", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroupString(__pyx_v_self, __pyx_v_index, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getInflectionalGroupString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":119
 *             return self.inflectionalGroups[index].__str__()
 * 
 *     cpdef InflectionalGroup getInflectionalGroup(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getInflectionalGroup method takes an integer index as an input and it directly returns the InflectionalGroup
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_9getInflectionalGroup(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getInflectionalGroup", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getInflectionalGroup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_9getInflectionalGroup)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 119, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":134
 *             InflectionalGroup at given index.
 *         """
 *         return self.inflectionalGroups[index]             # <<<<<<<<<<<<<<
 * 
 *     cpdef InflectionalGroup getLastInflectionalGroup(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 134, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, __pyx_v_index, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 134, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":119
 *             return self.inflectionalGroups[index].__str__()
 * 
 *     cpdef InflectionalGroup getInflectionalGroup(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getInflectionalGroup method takes an integer index as an input and it directly returns the InflectionalGroup
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_9getInflectionalGroup(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_8getInflectionalGroup[] = "\n        The getInflectionalGroup method takes an integer index as an input and it directly returns the InflectionalGroup\n        at given index.\n\n        PARAMETERS\n        ----------\n        index : int\n            Integer input.\n\n        RETURNS\n        -------\n        InflectionalGroup\n            InflectionalGroup at given index.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_9getInflectionalGroup(PyObject *__pyx_v_self, PyObject *__pyx_arg_index) {
  int __pyx_v_index;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getInflectionalGroup (wrapper)", 0);
  assert(__pyx_arg_index); {
    __pyx_v_index = __Pyx_PyInt_As_int(__pyx_arg_index); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 119, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_8getInflectionalGroup(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((int)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_8getInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getInflectionalGroup", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroup(__pyx_v_self, __pyx_v_index, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":136
 *         return self.inflectionalGroups[index]
 * 
 *     cpdef InflectionalGroup getLastInflectionalGroup(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getLastInflectionalGroup method directly returns the last InflectionalGroup of inflectionalGroups list.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_11getLastInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getLastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLastInflectionalGroup", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getLastInflectionalGroup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_11getLastInflectionalGroup)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 136, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":145
 *             The last InflectionalGroup of inflectionalGroups list.
 *         """
 *         return self.inflectionalGroups[len(self.inflectionalGroups) - 1]             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getTag(self, int index):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 145, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->inflectionalGroups;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 145, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_5 - 1);
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, __pyx_t_6, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 145, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":136
 *         return self.inflectionalGroups[index]
 * 
 *     cpdef InflectionalGroup getLastInflectionalGroup(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getLastInflectionalGroup method directly returns the last InflectionalGroup of inflectionalGroups list.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getLastInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_11getLastInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_10getLastInflectionalGroup[] = "\n        The getLastInflectionalGroup method directly returns the last InflectionalGroup of inflectionalGroups list.\n\n        RETURNS\n        -------\n        InflectionalGroup\n            The last InflectionalGroup of inflectionalGroups list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_11getLastInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLastInflectionalGroup (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_10getLastInflectionalGroup(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_10getLastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLastInflectionalGroup", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getLastInflectionalGroup(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getLastInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":147
 *         return self.inflectionalGroups[len(self.inflectionalGroups) - 1]
 * 
 *     cpdef str getTag(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getTag method takes an integer index as an input and and if the given index is 0, it directly return the
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_13getTag(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch) {
  int __pyx_v_size;
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_v_group = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_13getTag)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 147, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":165
 *         cdef int size
 *         cdef InflectionalGroup group
 *         size = 1             # <<<<<<<<<<<<<<
 *         if index == 0:
 *             return self.root.getName()
 */
  __pyx_v_size = 1;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":166
 *         cdef InflectionalGroup group
 *         size = 1
 *         if index == 0:             # <<<<<<<<<<<<<<
 *             return self.root.getName()
 *         for group in self.inflectionalGroups:
 */
  __pyx_t_6 = ((__pyx_v_index == 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":167
 *         size = 1
 *         if index == 0:
 *             return self.root.getName()             # <<<<<<<<<<<<<<
 *         for group in self.inflectionalGroups:
 *             if index < size + group.size():
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":166
 *         cdef InflectionalGroup group
 *         size = 1
 *         if index == 0:             # <<<<<<<<<<<<<<
 *             return self.root.getName()
 *         for group in self.inflectionalGroups:
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":168
 *         if index == 0:
 *             return self.root.getName()
 *         for group in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             if index < size + group.size():
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))
 */
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 168, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->inflectionalGroups; __Pyx_INCREF(__pyx_t_1); __pyx_t_7 = 0;
  for (;;) {
    if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 168, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 168, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_group, ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":169
 *             return self.root.getName()
 *         for group in self.inflectionalGroups:
 *             if index < size + group.size():             # <<<<<<<<<<<<<<
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))
 *             size += group.size()
 */
    __pyx_t_6 = ((__pyx_v_index < (__pyx_v_size + ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_v_group->__pyx_vtab)->size(__pyx_v_group, 0))) != 0);
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":170
 *         for group in self.inflectionalGroups:
 *             if index < size + group.size():
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))             # <<<<<<<<<<<<<<
 *             size += group.size()
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_n_s_getTagString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_v_group->__pyx_vtab)->getTag(__pyx_v_group, (__pyx_v_index - __pyx_v_size), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 170, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":169
 *             return self.root.getName()
 *         for group in self.inflectionalGroups:
 *             if index < size + group.size():             # <<<<<<<<<<<<<<
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))
 *             size += group.size()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":171
 *             if index < size + group.size():
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))
 *             size += group.size()             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __pyx_v_size = (__pyx_v_size + ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_v_group->__pyx_vtab)->size(__pyx_v_group, 0));

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":168
 *         if index == 0:
 *             return self.root.getName()
 *         for group in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             if index < size + group.size():
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":172
 *                 return InflectionalGroup.getTagString(group.getTag(index - size))
 *             size += group.size()
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     cpdef int tagSize(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":147
 *         return self.inflectionalGroups[len(self.inflectionalGroups) - 1]
 * 
 *     cpdef str getTag(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getTag method takes an integer index as an input and and if the given index is 0, it directly return the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_group);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_13getTag(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_12getTag[] = "\n        The getTag method takes an integer index as an input and and if the given index is 0, it directly return the\n        root. Then, it loops through the inflectionalGroups list it returns the MorphologicalTag of the corresponding\n        inflectional group.\n\n        PARAMETERS\n        ----------\n        index : int\n            Integer input.\n\n        RETURNS\n        -------\n        str\n            The MorphologicalTag of the corresponding inflectional group, or null of invalid index inputs.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_13getTag(PyObject *__pyx_v_self, PyObject *__pyx_arg_index) {
  int __pyx_v_index;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTag (wrapper)", 0);
  assert(__pyx_arg_index); {
    __pyx_v_index = __Pyx_PyInt_As_int(__pyx_arg_index); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 147, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_12getTag(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((int)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_12getTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTag(__pyx_v_self, __pyx_v_index, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":174
 *         return None
 * 
 *     cpdef int tagSize(self):             # <<<<<<<<<<<<<<
 *         """
 *         The tagSize method loops through the inflectionalGroups list and accumulates the sizes of each inflectional
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_15tagSize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_tagSize(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_v_size;
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_v_group = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tagSize", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_tagSize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_15tagSize)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 174, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":186
 *         cdef int size
 *         cdef InflectionalGroup group
 *         size = 1             # <<<<<<<<<<<<<<
 *         for group in self.inflectionalGroups:
 *             size += group.size()
 */
  __pyx_v_size = 1;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":187
 *         cdef InflectionalGroup group
 *         size = 1
 *         for group in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             size += group.size()
 *         return size
 */
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 187, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->inflectionalGroups; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
  for (;;) {
    if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 187, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 187, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_group, ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":188
 *         size = 1
 *         for group in self.inflectionalGroups:
 *             size += group.size()             # <<<<<<<<<<<<<<
 *         return size
 * 
 */
    __pyx_v_size = (__pyx_v_size + ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_v_group->__pyx_vtab)->size(__pyx_v_group, 0));

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":187
 *         cdef InflectionalGroup group
 *         size = 1
 *         for group in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             size += group.size()
 *         return size
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":189
 *         for group in self.inflectionalGroups:
 *             size += group.size()
 *         return size             # <<<<<<<<<<<<<<
 * 
 *     cpdef int size(self):
 */
  __pyx_r = __pyx_v_size;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":174
 *         return None
 * 
 *     cpdef int tagSize(self):             # <<<<<<<<<<<<<<
 *         """
 *         The tagSize method loops through the inflectionalGroups list and accumulates the sizes of each inflectional
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.tagSize", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_group);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_15tagSize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_14tagSize[] = "\n        The tagSize method loops through the inflectionalGroups list and accumulates the sizes of each inflectional\n        group in the inflectionalGroups.\n\n        RETURNS\n        -------\n        int\n            Total size of the inflectionalGroups list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_15tagSize(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tagSize (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_14tagSize(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_14tagSize(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tagSize", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_tagSize(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.tagSize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":191
 *         return size
 * 
 *     cpdef int size(self):             # <<<<<<<<<<<<<<
 *         """
 *         The size method returns the size of the inflectionalGroups list.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_17size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_size(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("size", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_17size)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 191, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":200
 *             The size of the inflectionalGroups list.
 *         """
 *         return len(self.inflectionalGroups)             # <<<<<<<<<<<<<<
 * 
 *     cpdef InflectionalGroup firstInflectionalGroup(self):
 */
  __pyx_t_1 = __pyx_v_self->inflectionalGroups;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 200, __pyx_L1_error)
  }
  __pyx_t_6 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":191
 *         return size
 * 
 *     cpdef int size(self):             # <<<<<<<<<<<<<<
 *         """
 *         The size method returns the size of the inflectionalGroups list.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.size", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_17size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_16size[] = "\n        The size method returns the size of the inflectionalGroups list.\n\n        RETURNS\n        -------\n        int\n            The size of the inflectionalGroups list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_17size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("size (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_16size(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_16size(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("size", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_size(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":202
 *         return len(self.inflectionalGroups)
 * 
 *     cpdef InflectionalGroup firstInflectionalGroup(self):             # <<<<<<<<<<<<<<
 *         """
 *         The firstInflectionalGroup method returns the first inflectional group of inflectionalGroups list.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_19firstInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_firstInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("firstInflectionalGroup", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_firstInflectionalGroup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_19firstInflectionalGroup)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 202, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":211
 *             The first inflectional group of inflectionalGroups list.
 *         """
 *         return self.inflectionalGroups[0]             # <<<<<<<<<<<<<<
 * 
 *     cpdef InflectionalGroup lastInflectionalGroup(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 211, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 211, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":202
 *         return len(self.inflectionalGroups)
 * 
 *     cpdef InflectionalGroup firstInflectionalGroup(self):             # <<<<<<<<<<<<<<
 *         """
 *         The firstInflectionalGroup method returns the first inflectional group of inflectionalGroups list.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.firstInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_19firstInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_18firstInflectionalGroup[] = "\n        The firstInflectionalGroup method returns the first inflectional group of inflectionalGroups list.\n\n        RETURNS\n        -------\n        InflectionalGroup\n            The first inflectional group of inflectionalGroups list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_19firstInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("firstInflectionalGroup (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_18firstInflectionalGroup(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_18firstInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("firstInflectionalGroup", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_firstInflectionalGroup(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.firstInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":213
 *         return self.inflectionalGroups[0]
 * 
 *     cpdef InflectionalGroup lastInflectionalGroup(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastInflectionalGroup method returns the last inflectional group of inflectionalGroups list.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_21lastInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastInflectionalGroup", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastInflectionalGroup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_21lastInflectionalGroup)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 213, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":222
 *             The last inflectional group of inflectionalGroups list.
 *         """
 *         return self.inflectionalGroups[len(self.inflectionalGroups) - 1]             # <<<<<<<<<<<<<<
 * 
 *     cpdef Word getWordWithPos(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 222, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->inflectionalGroups;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 222, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_5 - 1);
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, __pyx_t_6, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 222, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":213
 *         return self.inflectionalGroups[0]
 * 
 *     cpdef InflectionalGroup lastInflectionalGroup(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastInflectionalGroup method returns the last inflectional group of inflectionalGroups list.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_21lastInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_20lastInflectionalGroup[] = "\n        The lastInflectionalGroup method returns the last inflectional group of inflectionalGroups list.\n\n        RETURNS\n        -------\n        InflectionalGroup\n            The last inflectional group of inflectionalGroups list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_21lastInflectionalGroup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastInflectionalGroup (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_20lastInflectionalGroup(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_20lastInflectionalGroup(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastInflectionalGroup", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastInflectionalGroup(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastInflectionalGroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":224
 *         return self.inflectionalGroups[len(self.inflectionalGroups) - 1]
 * 
 *     cpdef Word getWordWithPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getWordWithPos method returns root with the MorphologicalTag of the first inflectional as a new word.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_23getWordWithPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_10Dictionary_4Word_Word *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWordWithPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_10Dictionary_4Word_Word *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWordWithPos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getWordWithPos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_23getWordWithPos)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_10Dictionary_4Word_Word))))) __PYX_ERR(0, 224, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":233
 *             Root with the MorphologicalTag of the first inflectional as a new word.
 *         """
 *         return Word(self.root.getName() + "+" + InflectionalGroup.getTagString(self.firstInflectionalGroup().getTag(0)))             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getPos(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_kp_u_); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_n_s_getTagString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->firstInflectionalGroup(__pyx_v_self, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_4)->__pyx_vtab)->getTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_4), 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_10Dictionary_4Word_Word), __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":224
 *         return self.inflectionalGroups[len(self.inflectionalGroups) - 1]
 * 
 *     cpdef Word getWordWithPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getWordWithPos method returns root with the MorphologicalTag of the first inflectional as a new word.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getWordWithPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_23getWordWithPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_22getWordWithPos[] = "\n        The getWordWithPos method returns root with the MorphologicalTag of the first inflectional as a new word.\n\n        RETURNS\n        -------\n        Word\n            Root with the MorphologicalTag of the first inflectional as a new word.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_23getWordWithPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWordWithPos (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_22getWordWithPos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_22getWordWithPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWordWithPos", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWordWithPos(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getWordWithPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":235
 *         return Word(self.root.getName() + "+" + InflectionalGroup.getTagString(self.firstInflectionalGroup().getTag(0)))
 * 
 *     cpdef str getPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getPos method returns the MorphologicalTag of the last inflectional group.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_25getPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_25getPos)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 235, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":244
 *             The MorphologicalTag of the last inflectional group.
 *         """
 *         return InflectionalGroup.getTagString(self.lastInflectionalGroup().getTag(0))             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getRootPos(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_n_s_getTagString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->lastInflectionalGroup(__pyx_v_self, 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_3)->__pyx_vtab)->getTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_3), 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 244, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":235
 *         return Word(self.root.getName() + "+" + InflectionalGroup.getTagString(self.firstInflectionalGroup().getTag(0)))
 * 
 *     cpdef str getPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getPos method returns the MorphologicalTag of the last inflectional group.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_25getPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_24getPos[] = "\n        The getPos method returns the MorphologicalTag of the last inflectional group.\n\n        RETURNS\n        -------\n        str\n            The MorphologicalTag of the last inflectional group.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_25getPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPos (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_24getPos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_24getPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPos", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPos(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":246
 *         return InflectionalGroup.getTagString(self.lastInflectionalGroup().getTag(0))
 * 
 *     cpdef str getRootPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getRootPos method returns the MorphologicalTag of the first inflectional group.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_27getRootPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getRootPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getRootPos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getRootPos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_27getRootPos)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 246, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":255
 *             The MorphologicalTag of the first inflectional group.
 *         """
 *         return InflectionalGroup.getTagString(self.firstInflectionalGroup().getTag(0))             # <<<<<<<<<<<<<<
 * 
 *     cpdef str lastIGContainsCase(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_n_s_getTagString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->firstInflectionalGroup(__pyx_v_self, 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_3)->__pyx_vtab)->getTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_3), 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 255, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":246
 *         return InflectionalGroup.getTagString(self.lastInflectionalGroup().getTag(0))
 * 
 *     cpdef str getRootPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getRootPos method returns the MorphologicalTag of the first inflectional group.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getRootPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_27getRootPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_26getRootPos[] = "\n        The getRootPos method returns the MorphologicalTag of the first inflectional group.\n\n        RETURNS\n        -------\n        str\n            The MorphologicalTag of the first inflectional group.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_27getRootPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getRootPos (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_26getRootPos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_26getRootPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getRootPos", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getRootPos(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getRootPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":257
 *         return InflectionalGroup.getTagString(self.firstInflectionalGroup().getTag(0))
 * 
 *     cpdef str lastIGContainsCase(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIGContainsCase method returns the MorphologicalTag of last inflectional group if it is one of the
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_29lastIGContainsCase(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_caseTag = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIGContainsCase", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastIGContainsCase); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_29lastIGContainsCase)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 257, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 257, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":269
 *         """
 *         cdef object caseTag
 *         caseTag = self.lastInflectionalGroup().containsCase()             # <<<<<<<<<<<<<<
 *         if caseTag is not None:
 *             return InflectionalGroup.getTagString(caseTag)
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->lastInflectionalGroup(__pyx_v_self, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsCase(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_caseTag = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":270
 *         cdef object caseTag
 *         caseTag = self.lastInflectionalGroup().containsCase()
 *         if caseTag is not None:             # <<<<<<<<<<<<<<
 *             return InflectionalGroup.getTagString(caseTag)
 *         else:
 */
  __pyx_t_5 = (__pyx_v_caseTag != Py_None);
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":271
 *         caseTag = self.lastInflectionalGroup().containsCase()
 *         if caseTag is not None:
 *             return InflectionalGroup.getTagString(caseTag)             # <<<<<<<<<<<<<<
 *         else:
 *             return "NULL"
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __pyx_n_s_getTagString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_v_caseTag) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_caseTag);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 271, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":270
 *         cdef object caseTag
 *         caseTag = self.lastInflectionalGroup().containsCase()
 *         if caseTag is not None:             # <<<<<<<<<<<<<<
 *             return InflectionalGroup.getTagString(caseTag)
 *         else:
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":273
 *             return InflectionalGroup.getTagString(caseTag)
 *         else:
 *             return "NULL"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint lastIGContainsTag(self, object tag):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NULL);
    __pyx_r = __pyx_n_u_NULL;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":257
 *         return InflectionalGroup.getTagString(self.firstInflectionalGroup().getTag(0))
 * 
 *     cpdef str lastIGContainsCase(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIGContainsCase method returns the MorphologicalTag of last inflectional group if it is one of the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastIGContainsCase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_caseTag);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_29lastIGContainsCase(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_28lastIGContainsCase[] = "\n        The lastIGContainsCase method returns the MorphologicalTag of last inflectional group if it is one of the\n        NOMINATIVE, ACCUSATIVE, DATIVE, LOCATIVE or ABLATIVE cases, null otherwise.\n\n        RETURNS\n        -------\n        str\n            The MorphologicalTag of last inflectional group if it is one of the NOMINATIVE, ACCUSATIVE, DATIVE, LOCATIVE\n            or ABLATIVE cases, null otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_29lastIGContainsCase(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastIGContainsCase (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_28lastIGContainsCase(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_28lastIGContainsCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIGContainsCase", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsCase(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastIGContainsCase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":275
 *             return "NULL"
 * 
 *     cpdef bint lastIGContainsTag(self, object tag):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIGContainsTag method takes a MorphologicalTag as an input and returns true if the last inflectional
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_31lastIGContainsTag(PyObject *__pyx_v_self, PyObject *__pyx_v_tag); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIGContainsTag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastIGContainsTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_31lastIGContainsTag)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_tag) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_tag);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 275, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 275, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":291
 *             otherwise.
 *         """
 *         return self.lastInflectionalGroup().containsTag(tag)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint lastIGContainsPossessive(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->lastInflectionalGroup(__pyx_v_self, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_v_tag, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":275
 *             return "NULL"
 * 
 *     cpdef bint lastIGContainsTag(self, object tag):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIGContainsTag method takes a MorphologicalTag as an input and returns true if the last inflectional
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastIGContainsTag", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_31lastIGContainsTag(PyObject *__pyx_v_self, PyObject *__pyx_v_tag); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_30lastIGContainsTag[] = "\n        The lastIGContainsTag method takes a MorphologicalTag as an input and returns true if the last inflectional\n        group's MorphologicalTag matches with one of the tags in the IG list, false otherwise.\n\n        PARAMETERS\n        ----------\n        tag : MorphologicalTag\n            MorphologicalTag type input.\n\n        RETURNS\n        -------\n        bool\n            True if the last inflectional group's MorphologicalTag matches with one of the tags in the IG list, False\n            otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_31lastIGContainsTag(PyObject *__pyx_v_self, PyObject *__pyx_v_tag) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastIGContainsTag (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_30lastIGContainsTag(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((PyObject *)__pyx_v_tag));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_30lastIGContainsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIGContainsTag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsTag(__pyx_v_self, __pyx_v_tag, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastIGContainsTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":293
 *         return self.lastInflectionalGroup().containsTag(tag)
 * 
 *     cpdef bint lastIGContainsPossessive(self):             # <<<<<<<<<<<<<<
 *         """
 *         lastIGContainsPossessive method returns true if the last inflectional group contains one of the
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_33lastIGContainsPossessive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsPossessive(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIGContainsPossessive", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastIGContainsPossessive); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 293, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_33lastIGContainsPossessive)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 293, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":304
 *             false otherwise.
 *         """
 *         return self.lastInflectionalGroup().containsPossessive()             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isCapitalWord(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->lastInflectionalGroup(__pyx_v_self, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsPossessive(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":293
 *         return self.lastInflectionalGroup().containsTag(tag)
 * 
 *     cpdef bint lastIGContainsPossessive(self):             # <<<<<<<<<<<<<<
 *         """
 *         lastIGContainsPossessive method returns true if the last inflectional group contains one of the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastIGContainsPossessive", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_33lastIGContainsPossessive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_32lastIGContainsPossessive[] = "\n        lastIGContainsPossessive method returns true if the last inflectional group contains one of the\n        possessives: P1PL, P1SG, P2PL, P2SG, P3PL AND P3SG, false otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the last inflectional group contains one of the possessives: P1PL, P1SG, P2PL, P2SG, P3PL AND P3SG,\n            false otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_33lastIGContainsPossessive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastIGContainsPossessive (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_32lastIGContainsPossessive(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_32lastIGContainsPossessive(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIGContainsPossessive", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsPossessive(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.lastIGContainsPossessive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":306
 *         return self.lastInflectionalGroup().containsPossessive()
 * 
 *     cpdef bint isCapitalWord(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isCapitalWord method returns True if the character at first index of root is an uppercase letter, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_35isCapitalWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCapitalWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isCapitalWord", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isCapitalWord); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_35isCapitalWord)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 306, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":316
 *             True if the character at first index of root is an uppercase letter, False otherwise.
 *         """
 *         return self.root.getName()[0:0].isupper()             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isNoun(self):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 316, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyUnicode_Substring(__pyx_t_2, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_isupper); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":306
 *         return self.lastInflectionalGroup().containsPossessive()
 * 
 *     cpdef bint isCapitalWord(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isCapitalWord method returns True if the character at first index of root is an uppercase letter, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isCapitalWord", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_35isCapitalWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_34isCapitalWord[] = "\n        The isCapitalWord method returns True if the character at first index of root is an uppercase letter, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the character at first index of root is an uppercase letter, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_35isCapitalWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isCapitalWord (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_34isCapitalWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_34isCapitalWord(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isCapitalWord", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCapitalWord(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isCapitalWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":318
 *         return self.root.getName()[0:0].isupper()
 * 
 *     cpdef bint isNoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNoun method returns true if the past of speech is NOUN, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_37isNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNoun", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isNoun); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_37isNoun)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 318, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":327
 *             True if the past of speech is NOUN, False otherwise.
 *         """
 *         return self.getPos() == "NOUN"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isVerb(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_NOUN, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":318
 *         return self.root.getName()[0:0].isupper()
 * 
 *     cpdef bint isNoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNoun method returns true if the past of speech is NOUN, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isNoun", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_37isNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_36isNoun[] = "\n        The isNoun method returns true if the past of speech is NOUN, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the past of speech is NOUN, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_37isNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isNoun (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_36isNoun(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_36isNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNoun", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNoun(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isNoun", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":329
 *         return self.getPos() == "NOUN"
 * 
 *     cpdef bint isVerb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isVerb method returns true if the past of speech is VERB, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_39isVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isVerb", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isVerb); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_39isVerb)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 329, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":338
 *             True if the past of speech is VERB, False otherwise.
 *         """
 *         return self.getPos() == "VERB"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isRootVerb(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_VERB, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":329
 *         return self.getPos() == "NOUN"
 * 
 *     cpdef bint isVerb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isVerb method returns true if the past of speech is VERB, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isVerb", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_39isVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_38isVerb[] = "\n        The isVerb method returns true if the past of speech is VERB, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the past of speech is VERB, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_39isVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isVerb (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_38isVerb(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_38isVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isVerb", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isVerb(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isVerb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":340
 *         return self.getPos() == "VERB"
 * 
 *     cpdef bint isRootVerb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isRootVerb method returns True if the past of speech of root is BERV, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_41isRootVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRootVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRootVerb", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isRootVerb); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 340, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_41isRootVerb)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 340, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 340, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":349
 *             True if the past of speech of root is VERB, False otherwise.
 *         """
 *         return self.getRootPos() == "VERB"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isAdjective(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getRootPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_VERB, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":340
 *         return self.getPos() == "VERB"
 * 
 *     cpdef bint isRootVerb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isRootVerb method returns True if the past of speech of root is BERV, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isRootVerb", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_41isRootVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_40isRootVerb[] = "\n        The isRootVerb method returns True if the past of speech of root is BERV, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the past of speech of root is VERB, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_41isRootVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isRootVerb (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_40isRootVerb(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_40isRootVerb(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRootVerb", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRootVerb(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isRootVerb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":351
 *         return self.getRootPos() == "VERB"
 * 
 *     cpdef bint isAdjective(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAdjective method returns True if the past of speech is ADJ, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_43isAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAdjective(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAdjective", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isAdjective); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 351, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_43isAdjective)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 351, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":360
 *             True if the past of speech is ADJ, False otherwise.
 *         """
 *         return self.getPos() == "ADJ"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isProperNoun(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_ADJ, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":351
 *         return self.getRootPos() == "VERB"
 * 
 *     cpdef bint isAdjective(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAdjective method returns True if the past of speech is ADJ, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isAdjective", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_43isAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_42isAdjective[] = "\n        The isAdjective method returns True if the past of speech is ADJ, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the past of speech is ADJ, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_43isAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isAdjective (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_42isAdjective(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_42isAdjective(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAdjective", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAdjective(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isAdjective", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":362
 *         return self.getPos() == "ADJ"
 * 
 *     cpdef bint isProperNoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isProperNoun method returns True if the first inflectional group's MorphologicalTag is a PROPERNOUN, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_45isProperNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isProperNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isProperNoun", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isProperNoun); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 362, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_45isProperNoun)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 362, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 362, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":372
 *             True if the first inflectional group's MorphologicalTag is a PROPERNOUN, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PROPERNOUN)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPunctuation(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PROPERNOUN); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":362
 *         return self.getPos() == "ADJ"
 * 
 *     cpdef bint isProperNoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isProperNoun method returns True if the first inflectional group's MorphologicalTag is a PROPERNOUN, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isProperNoun", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_45isProperNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_44isProperNoun[] = "\n        The isProperNoun method returns True if the first inflectional group's MorphologicalTag is a PROPERNOUN, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a PROPERNOUN, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_45isProperNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isProperNoun (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_44isProperNoun(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_44isProperNoun(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isProperNoun", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isProperNoun(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isProperNoun", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":374
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PROPERNOUN)
 * 
 *     cpdef bint isPunctuation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPunctuation method returns True if the first inflectional group's MorphologicalTag is a PUNCTUATION, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_47isPunctuation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPunctuation(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPunctuation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPunctuation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_47isPunctuation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 374, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":384
 *             True if the first inflectional group's MorphologicalTag is a PUNCTUATION, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PUNCTUATION)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isCardinal(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PUNCTUATION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":374
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PROPERNOUN)
 * 
 *     cpdef bint isPunctuation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPunctuation method returns True if the first inflectional group's MorphologicalTag is a PUNCTUATION, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isPunctuation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_47isPunctuation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_46isPunctuation[] = "\n        The isPunctuation method returns True if the first inflectional group's MorphologicalTag is a PUNCTUATION, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a PUNCTUATION, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_47isPunctuation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPunctuation (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_46isPunctuation(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_46isPunctuation(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPunctuation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPunctuation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isPunctuation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":386
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PUNCTUATION)
 * 
 *     cpdef bint isCardinal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isCardinal method returns True if the first inflectional group's MorphologicalTag is a CARDINAL, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_49isCardinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCardinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isCardinal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isCardinal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_49isCardinal)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 386, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 386, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":396
 *             True if the first inflectional group's MorphologicalTag is a CARDINAL, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.CARDINAL)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isOrdinal(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_CARDINAL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":386
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PUNCTUATION)
 * 
 *     cpdef bint isCardinal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isCardinal method returns True if the first inflectional group's MorphologicalTag is a CARDINAL, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isCardinal", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_49isCardinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_48isCardinal[] = "\n        The isCardinal method returns True if the first inflectional group's MorphologicalTag is a CARDINAL, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a CARDINAL, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_49isCardinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isCardinal (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_48isCardinal(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_48isCardinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isCardinal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCardinal(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isCardinal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":398
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.CARDINAL)
 * 
 *     cpdef bint isOrdinal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isOrdinal method returns True if the first inflectional group's MorphologicalTag is a ORDINAL, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_51isOrdinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isOrdinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isOrdinal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isOrdinal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_51isOrdinal)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":408
 *             True if the first inflectional group's MorphologicalTag is a ORDINAL, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.ORDINAL)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isReal(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ORDINAL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":398
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.CARDINAL)
 * 
 *     cpdef bint isOrdinal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isOrdinal method returns True if the first inflectional group's MorphologicalTag is a ORDINAL, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isOrdinal", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_51isOrdinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_50isOrdinal[] = "\n        The isOrdinal method returns True if the first inflectional group's MorphologicalTag is a ORDINAL, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a ORDINAL, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_51isOrdinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isOrdinal (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_50isOrdinal(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_50isOrdinal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isOrdinal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isOrdinal(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isOrdinal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":410
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.ORDINAL)
 * 
 *     cpdef bint isReal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isReal method returns True if the first inflectional group's MorphologicalTag is a REAL, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_53isReal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isReal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isReal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isReal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_53isReal)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 410, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 410, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":419
 *             True if the first inflectional group's MorphologicalTag is a REAL, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.REAL)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isNumber(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_REAL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":410
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.ORDINAL)
 * 
 *     cpdef bint isReal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isReal method returns True if the first inflectional group's MorphologicalTag is a REAL, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isReal", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_53isReal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_52isReal[] = "\n        The isReal method returns True if the first inflectional group's MorphologicalTag is a REAL, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a REAL, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_53isReal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isReal (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_52isReal(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_52isReal(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isReal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isReal(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isReal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":421
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.REAL)
 * 
 *     cpdef bint isNumber(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNumber method returns True if the first inflectional group's MorphologicalTag is REAL or CARDINAL, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_55isNumber(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNumber", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isNumber); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_55isNumber)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 421, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":431
 *             True if the first inflectional group's MorphologicalTag is a REAL or CARDINAL, False otherwise.
 *         """
 *         return self.isReal() or self.isCardinal()             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isTime(self):
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isReal(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isCardinal(__pyx_v_self, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":421
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.REAL)
 * 
 *     cpdef bint isNumber(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNumber method returns True if the first inflectional group's MorphologicalTag is REAL or CARDINAL, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isNumber", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_55isNumber(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_54isNumber[] = "\n        The isNumber method returns True if the first inflectional group's MorphologicalTag is REAL or CARDINAL, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a REAL or CARDINAL, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_55isNumber(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isNumber (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_54isNumber(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_54isNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNumber", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNumber(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":433
 *         return self.isReal() or self.isCardinal()
 * 
 *     cpdef bint isTime(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isTime method returns True if the first inflectional group's MorphologicalTag is a TIME, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_57isTime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isTime(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isTime", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isTime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_57isTime)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 433, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":442
 *             True if the first inflectional group's MorphologicalTag is a TIME, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.TIME)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isDate(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_TIME); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":433
 *         return self.isReal() or self.isCardinal()
 * 
 *     cpdef bint isTime(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isTime method returns True if the first inflectional group's MorphologicalTag is a TIME, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isTime", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_57isTime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_56isTime[] = "\n        The isTime method returns True if the first inflectional group's MorphologicalTag is a TIME, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a TIME, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_57isTime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isTime (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_56isTime(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_56isTime(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isTime", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isTime(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isTime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":444
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.TIME)
 * 
 *     cpdef bint isDate(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDate method returns True if the first inflectional group's MorphologicalTag is a DATE, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_59isDate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isDate(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDate", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isDate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_59isDate)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":453
 *             True if the first inflectional group's MorphologicalTag is a DATE, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.DATE)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isHashTag(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DATE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":444
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.TIME)
 * 
 *     cpdef bint isDate(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDate method returns True if the first inflectional group's MorphologicalTag is a DATE, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isDate", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_59isDate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_58isDate[] = "\n        The isDate method returns True if the first inflectional group's MorphologicalTag is a DATE, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a DATE, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_59isDate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isDate (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_58isDate(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_58isDate(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDate", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isDate(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":455
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.DATE)
 * 
 *     cpdef bint isHashTag(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isHashTag method returns True if the first inflectional group's MorphologicalTag is a HASHTAG, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_61isHashTag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isHashTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isHashTag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isHashTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_61isHashTag)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 455, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":465
 *             True if the first inflectional group's MorphologicalTag is a HASHTAG, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.HASHTAG)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isEmail(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_HASHTAG); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":455
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.DATE)
 * 
 *     cpdef bint isHashTag(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isHashTag method returns True if the first inflectional group's MorphologicalTag is a HASHTAG, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isHashTag", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_61isHashTag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_60isHashTag[] = "\n        The isHashTag method returns True if the first inflectional group's MorphologicalTag is a HASHTAG, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a HASHTAG, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_61isHashTag(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isHashTag (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_60isHashTag(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_60isHashTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isHashTag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isHashTag(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isHashTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":467
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.HASHTAG)
 * 
 *     cpdef bint isEmail(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isEmail method returns True if the first inflectional group's MorphologicalTag is a EMAIL, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_63isEmail(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isEmail(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isEmail", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isEmail); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_63isEmail)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 467, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":476
 *             True if the first inflectional group's MorphologicalTag is a EMAIL, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.EMAIL)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPercent(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_EMAIL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":467
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.HASHTAG)
 * 
 *     cpdef bint isEmail(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isEmail method returns True if the first inflectional group's MorphologicalTag is a EMAIL, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isEmail", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_63isEmail(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_62isEmail[] = "\n        The isEmail method returns True if the first inflectional group's MorphologicalTag is a EMAIL, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a EMAIL, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_63isEmail(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isEmail (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_62isEmail(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_62isEmail(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isEmail", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isEmail(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isEmail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":478
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.EMAIL)
 * 
 *     cpdef bint isPercent(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPercent method returns True if the first inflectional group's MorphologicalTag is a PERCENT, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_65isPercent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPercent(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPercent", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPercent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_65isPercent)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 478, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 478, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":488
 *             True if the first inflectional group's MorphologicalTag is a PERCENT, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PERCENT)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isFraction(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PERCENT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":478
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.EMAIL)
 * 
 *     cpdef bint isPercent(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPercent method returns True if the first inflectional group's MorphologicalTag is a PERCENT, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isPercent", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_65isPercent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_64isPercent[] = "\n        The isPercent method returns True if the first inflectional group's MorphologicalTag is a PERCENT, False\n        otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a PERCENT, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_65isPercent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPercent (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_64isPercent(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_64isPercent(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPercent", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPercent(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isPercent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":490
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PERCENT)
 * 
 *     cpdef bint isFraction(self):             # <<<<<<<<<<<<<<
 *         """
 *          The isFraction method returns True if the first inflectional group's MorphologicalTag is a FRACTION, False
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_67isFraction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isFraction(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isFraction", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isFraction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 490, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_67isFraction)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 490, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":500
 *             True if the first inflectional group's MorphologicalTag is a FRACTION, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.FRACTION)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isRange(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FRACTION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":490
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.PERCENT)
 * 
 *     cpdef bint isFraction(self):             # <<<<<<<<<<<<<<
 *         """
 *          The isFraction method returns True if the first inflectional group's MorphologicalTag is a FRACTION, False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isFraction", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_67isFraction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_66isFraction[] = "\n         The isFraction method returns True if the first inflectional group's MorphologicalTag is a FRACTION, False\n         otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a FRACTION, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_67isFraction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isFraction (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_66isFraction(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_66isFraction(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isFraction", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isFraction(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isFraction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":502
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.FRACTION)
 * 
 *     cpdef bint isRange(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isRange method returns True if the first inflectional group's MorphologicalTag is a RANGE, False otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_69isRange(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRange(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRange", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isRange); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_69isRange)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 502, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":511
 *             True if the first inflectional group's MorphologicalTag is a RANGE, False otherwise.
 *         """
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.RANGE)             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPlural(self):
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getInflectionalGroup(__pyx_v_self, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_RANGE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1)->__pyx_vtab)->containsTag(((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_1), __pyx_t_3, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":502
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.FRACTION)
 * 
 *     cpdef bint isRange(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isRange method returns True if the first inflectional group's MorphologicalTag is a RANGE, False otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isRange", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_69isRange(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_68isRange[] = "\n        The isRange method returns True if the first inflectional group's MorphologicalTag is a RANGE, False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the first inflectional group's MorphologicalTag is a RANGE, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_69isRange(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isRange (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_68isRange(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_68isRange(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRange", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRange(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isRange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":513
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.RANGE)
 * 
 *     cpdef bint isPlural(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPlural method returns true if InflectionalGroup's MorphologicalTags are from the agreement plural
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_71isPlural(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPlural(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_v_inflectionalGroup = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPlural", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPlural); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_71isPlural)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 513, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 513, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":524
 *         """
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             if inflectionalGroup.containsPlural():
 *                 return True
 */
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 524, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->inflectionalGroups; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
  for (;;) {
    if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 524, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_inflectionalGroup, ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":525
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:
 *             if inflectionalGroup.containsPlural():             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_v_inflectionalGroup->__pyx_vtab)->containsPlural(__pyx_v_inflectionalGroup, 0) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":526
 *         for inflectionalGroup in self.inflectionalGroups:
 *             if inflectionalGroup.containsPlural():
 *                 return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
      __pyx_r = 1;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":525
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:
 *             if inflectionalGroup.containsPlural():             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":524
 *         """
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             if inflectionalGroup.containsPlural():
 *                 return True
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":527
 *             if inflectionalGroup.containsPlural():
 *                 return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isAuxiliary(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":513
 *         return self.getInflectionalGroup(0).containsTag(MorphologicalTag.RANGE)
 * 
 *     cpdef bint isPlural(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPlural method returns true if InflectionalGroup's MorphologicalTags are from the agreement plural
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isPlural", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_inflectionalGroup);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_71isPlural(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_70isPlural[] = "\n        The isPlural method returns true if InflectionalGroup's MorphologicalTags are from the agreement plural\n        or possessive plural, i.e A1PL, A2PL, A3PL, P1PL, P2PL or P3PL, and False otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if InflectionalGroup's MorphologicalTags are from the agreement plural or possessive plural.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_71isPlural(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPlural (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_70isPlural(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_70isPlural(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPlural", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPlural(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isPlural", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":529
 *         return False
 * 
 *     cpdef bint isAuxiliary(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAuxiliary method returns true if the root equals to the et, ol, or yap, and false otherwise.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_73isAuxiliary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAuxiliary(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAuxiliary", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isAuxiliary); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_73isAuxiliary)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 529, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":538
 *             True if the root equals to the et, ol, or yap, and False otherwise.
 *         """
 *         return self.root.getName() == "et" or self.root.getName() == "ol" or self.root.getName() == "yap"             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint containsTag(self, object tag):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_et, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_ol, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_yap, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_6 != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":529
 *         return False
 * 
 *     cpdef bint isAuxiliary(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAuxiliary method returns true if the root equals to the et, ol, or yap, and false otherwise.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isAuxiliary", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_73isAuxiliary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_72isAuxiliary[] = "\n        The isAuxiliary method returns true if the root equals to the et, ol, or yap, and false otherwise.\n\n        RETURNS\n        -------\n        bool\n            True if the root equals to the et, ol, or yap, and False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_73isAuxiliary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isAuxiliary (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_72isAuxiliary(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_72isAuxiliary(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAuxiliary", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAuxiliary(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.isAuxiliary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":540
 *         return self.root.getName() == "et" or self.root.getName() == "ol" or self.root.getName() == "yap"
 * 
 *     cpdef bint containsTag(self, object tag):             # <<<<<<<<<<<<<<
 *         """
 *         The containsTag method takes a MorphologicalTag as an input and loops through the inflectionalGroups list,
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_75containsTag(PyObject *__pyx_v_self, PyObject *__pyx_v_tag); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_containsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_v_inflectionalGroup = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("containsTag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_containsTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_75containsTag)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_tag) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_tag);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 540, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":556
 *         """
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             if inflectionalGroup.containsTag(tag):
 *                 return True
 */
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 556, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->inflectionalGroups; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
  for (;;) {
    if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 556, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup))))) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_inflectionalGroup, ((struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":557
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:
 *             if inflectionalGroup.containsTag(tag):             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *)__pyx_v_inflectionalGroup->__pyx_vtab)->containsTag(__pyx_v_inflectionalGroup, __pyx_v_tag, 0) != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":558
 *         for inflectionalGroup in self.inflectionalGroups:
 *             if inflectionalGroup.containsTag(tag):
 *                 return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
      __pyx_r = 1;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":557
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:
 *             if inflectionalGroup.containsTag(tag):             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":556
 *         """
 *         cdef InflectionalGroup inflectionalGroup
 *         for inflectionalGroup in self.inflectionalGroups:             # <<<<<<<<<<<<<<
 *             if inflectionalGroup.containsTag(tag):
 *                 return True
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":559
 *             if inflectionalGroup.containsTag(tag):
 *                 return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getTreePos(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":540
 *         return self.root.getName() == "et" or self.root.getName() == "ol" or self.root.getName() == "yap"
 * 
 *     cpdef bint containsTag(self, object tag):             # <<<<<<<<<<<<<<
 *         """
 *         The containsTag method takes a MorphologicalTag as an input and loops through the inflectionalGroups list,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.containsTag", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_inflectionalGroup);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_75containsTag(PyObject *__pyx_v_self, PyObject *__pyx_v_tag); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_74containsTag[] = "\n        The containsTag method takes a MorphologicalTag as an input and loops through the inflectionalGroups list,\n        returns True if the input matches with on of the tags in the IG, False otherwise.\n\n        PARAMETERS\n        ----------\n        tag : MorphologicalTag\n            checked tag\n\n        RETURNS\n        -------\n        bool\n            True if the input matches with on of the tags in the IG, False otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_75containsTag(PyObject *__pyx_v_self, PyObject *__pyx_v_tag) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("containsTag (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_74containsTag(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((PyObject *)__pyx_v_tag));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_74containsTag(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_tag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("containsTag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_containsTag(__pyx_v_self, __pyx_v_tag, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.containsTag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":561
 *         return False
 * 
 *     cpdef str getTreePos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getTreePos method returns the tree pos tag of a morphological analysis.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_77getTreePos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTreePos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTreePos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getTreePos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_77getTreePos)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 561, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 561, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":570
 *             Tree pos tag of the morphological analysis in string form.
 *         """
 *         if self.isProperNoun():             # <<<<<<<<<<<<<<
 *             return "NP"
 *         elif self.root.getName() == "deil":
 */
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, 0) != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":571
 *         """
 *         if self.isProperNoun():
 *             return "NP"             # <<<<<<<<<<<<<<
 *         elif self.root.getName() == "deil":
 *             return "NEG"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NP);
    __pyx_r = __pyx_n_u_NP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":570
 *             Tree pos tag of the morphological analysis in string form.
 *         """
 *         if self.isProperNoun():             # <<<<<<<<<<<<<<
 *             return "NP"
 *         elif self.root.getName() == "deil":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":572
 *         if self.isProperNoun():
 *             return "NP"
 *         elif self.root.getName() == "deil":             # <<<<<<<<<<<<<<
 *             return "NEG"
 *         elif self.isVerb():
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_deil, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":573
 *             return "NP"
 *         elif self.root.getName() == "deil":
 *             return "NEG"             # <<<<<<<<<<<<<<
 *         elif self.isVerb():
 *             if self.lastIGContainsTag(MorphologicalTag.ZERO):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NEG);
    __pyx_r = __pyx_n_u_NEG;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":572
 *         if self.isProperNoun():
 *             return "NP"
 *         elif self.root.getName() == "deil":             # <<<<<<<<<<<<<<
 *             return "NEG"
 *         elif self.isVerb():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":574
 *         elif self.root.getName() == "deil":
 *             return "NEG"
 *         elif self.isVerb():             # <<<<<<<<<<<<<<
 *             if self.lastIGContainsTag(MorphologicalTag.ZERO):
 *                 return "NOMP"
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isVerb(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":575
 *             return "NEG"
 *         elif self.isVerb():
 *             if self.lastIGContainsTag(MorphologicalTag.ZERO):             # <<<<<<<<<<<<<<
 *                 return "NOMP"
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ZERO); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->lastIGContainsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":576
 *         elif self.isVerb():
 *             if self.lastIGContainsTag(MorphologicalTag.ZERO):
 *                 return "NOMP"             # <<<<<<<<<<<<<<
 *             else:
 *                 return "VP"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_u_NOMP);
      __pyx_r = __pyx_n_u_NOMP;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":575
 *             return "NEG"
 *         elif self.isVerb():
 *             if self.lastIGContainsTag(MorphologicalTag.ZERO):             # <<<<<<<<<<<<<<
 *                 return "NOMP"
 *             else:
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":578
 *                 return "NOMP"
 *             else:
 *                 return "VP"             # <<<<<<<<<<<<<<
 *         elif self.isAdjective():
 *             return "ADJP"
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_u_VP);
      __pyx_r = __pyx_n_u_VP;
      goto __pyx_L0;
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":574
 *         elif self.root.getName() == "deil":
 *             return "NEG"
 *         elif self.isVerb():             # <<<<<<<<<<<<<<
 *             if self.lastIGContainsTag(MorphologicalTag.ZERO):
 *                 return "NOMP"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":579
 *             else:
 *                 return "VP"
 *         elif self.isAdjective():             # <<<<<<<<<<<<<<
 *             return "ADJP"
 *         elif self.isNoun() or self.isPercent():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isAdjective(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":580
 *                 return "VP"
 *         elif self.isAdjective():
 *             return "ADJP"             # <<<<<<<<<<<<<<
 *         elif self.isNoun() or self.isPercent():
 *             return "NP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_ADJP);
    __pyx_r = __pyx_n_u_ADJP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":579
 *             else:
 *                 return "VP"
 *         elif self.isAdjective():             # <<<<<<<<<<<<<<
 *             return "ADJP"
 *         elif self.isNoun() or self.isPercent():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":581
 *         elif self.isAdjective():
 *             return "ADJP"
 *         elif self.isNoun() or self.isPercent():             # <<<<<<<<<<<<<<
 *             return "NP"
 *         elif self.containsTag(MorphologicalTag.ADVERB):
 */
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNoun(__pyx_v_self, 0) != 0);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_6 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isPercent(__pyx_v_self, 0) != 0);
  __pyx_t_6 = __pyx_t_5;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":582
 *             return "ADJP"
 *         elif self.isNoun() or self.isPercent():
 *             return "NP"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.ADVERB):
 *             return "ADVP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NP);
    __pyx_r = __pyx_n_u_NP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":581
 *         elif self.isAdjective():
 *             return "ADJP"
 *         elif self.isNoun() or self.isPercent():             # <<<<<<<<<<<<<<
 *             return "NP"
 *         elif self.containsTag(MorphologicalTag.ADVERB):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":583
 *         elif self.isNoun() or self.isPercent():
 *             return "NP"
 *         elif self.containsTag(MorphologicalTag.ADVERB):             # <<<<<<<<<<<<<<
 *             return "ADVP"
 *         elif self.isNumber() or self.isFraction():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ADVERB); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":584
 *             return "NP"
 *         elif self.containsTag(MorphologicalTag.ADVERB):
 *             return "ADVP"             # <<<<<<<<<<<<<<
 *         elif self.isNumber() or self.isFraction():
 *             return "NUM"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_ADVP);
    __pyx_r = __pyx_n_u_ADVP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":583
 *         elif self.isNoun() or self.isPercent():
 *             return "NP"
 *         elif self.containsTag(MorphologicalTag.ADVERB):             # <<<<<<<<<<<<<<
 *             return "ADVP"
 *         elif self.isNumber() or self.isFraction():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":585
 *         elif self.containsTag(MorphologicalTag.ADVERB):
 *             return "ADVP"
 *         elif self.isNumber() or self.isFraction():             # <<<<<<<<<<<<<<
 *             return "NUM"
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):
 */
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNumber(__pyx_v_self, 0) != 0);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_6 = __pyx_t_5;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isFraction(__pyx_v_self, 0) != 0);
  __pyx_t_6 = __pyx_t_5;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":586
 *             return "ADVP"
 *         elif self.isNumber() or self.isFraction():
 *             return "NUM"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):
 *             return "PP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NUM);
    __pyx_r = __pyx_n_u_NUM;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":585
 *         elif self.containsTag(MorphologicalTag.ADVERB):
 *             return "ADVP"
 *         elif self.isNumber() or self.isFraction():             # <<<<<<<<<<<<<<
 *             return "NUM"
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":587
 *         elif self.isNumber() or self.isFraction():
 *             return "NUM"
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):             # <<<<<<<<<<<<<<
 *             return "PP"
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_POSTPOSITION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":588
 *             return "NUM"
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):
 *             return "PP"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):
 *             return "CONJP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_PP);
    __pyx_r = __pyx_n_u_PP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":587
 *         elif self.isNumber() or self.isFraction():
 *             return "NUM"
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):             # <<<<<<<<<<<<<<
 *             return "PP"
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":589
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):
 *             return "PP"
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):             # <<<<<<<<<<<<<<
 *             return "CONJP"
 *         elif self.containsTag(MorphologicalTag.DETERMINER):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_CONJUNCTION); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":590
 *             return "PP"
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):
 *             return "CONJP"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_CONJP);
    __pyx_r = __pyx_n_u_CONJP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":589
 *         elif self.containsTag(MorphologicalTag.POSTPOSITION):
 *             return "PP"
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):             # <<<<<<<<<<<<<<
 *             return "CONJP"
 *         elif self.containsTag(MorphologicalTag.DETERMINER):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":591
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):
 *             return "CONJP"
 *         elif self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             return "DP"
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DETERMINER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":592
 *             return "CONJP"
 *         elif self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DP"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_DP);
    __pyx_r = __pyx_n_u_DP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":591
 *         elif self.containsTag(MorphologicalTag.CONJUNCTION):
 *             return "CONJP"
 *         elif self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             return "DP"
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":593
 *         elif self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DP"
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):             # <<<<<<<<<<<<<<
 *             return "INTJP"
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_INTERJECTION); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":594
 *             return "DP"
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJP"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):
 *             return "WP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_INTJP);
    __pyx_r = __pyx_n_u_INTJP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":593
 *         elif self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DP"
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):             # <<<<<<<<<<<<<<
 *             return "INTJP"
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":595
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJP"
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):             # <<<<<<<<<<<<<<
 *             return "WP"
 *         elif self.containsTag(MorphologicalTag.PRONOUN):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_QUESTIONPRONOUN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":596
 *             return "INTJP"
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):
 *             return "WP"             # <<<<<<<<<<<<<<
 *         elif self.containsTag(MorphologicalTag.PRONOUN):
 *             return "NP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_WP);
    __pyx_r = __pyx_n_u_WP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":595
 *         elif self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJP"
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):             # <<<<<<<<<<<<<<
 *             return "WP"
 *         elif self.containsTag(MorphologicalTag.PRONOUN):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":597
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):
 *             return "WP"
 *         elif self.containsTag(MorphologicalTag.PRONOUN):             # <<<<<<<<<<<<<<
 *             return "NP"
 *         elif self.isPunctuation():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PRONOUN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":598
 *             return "WP"
 *         elif self.containsTag(MorphologicalTag.PRONOUN):
 *             return "NP"             # <<<<<<<<<<<<<<
 *         elif self.isPunctuation():
 *             if self.root.getName() == "!" or self.root.getName() == "?":
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NP);
    __pyx_r = __pyx_n_u_NP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":597
 *         elif self.containsTag(MorphologicalTag.QUESTIONPRONOUN):
 *             return "WP"
 *         elif self.containsTag(MorphologicalTag.PRONOUN):             # <<<<<<<<<<<<<<
 *             return "NP"
 *         elif self.isPunctuation():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":599
 *         elif self.containsTag(MorphologicalTag.PRONOUN):
 *             return "NP"
 *         elif self.isPunctuation():             # <<<<<<<<<<<<<<
 *             if self.root.getName() == "!" or self.root.getName() == "?":
 *                 return "."
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isPunctuation(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":600
 *             return "NP"
 *         elif self.isPunctuation():
 *             if self.root.getName() == "!" or self.root.getName() == "?":             # <<<<<<<<<<<<<<
 *                 return "."
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__4, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__5, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":601
 *         elif self.isPunctuation():
 *             if self.root.getName() == "!" or self.root.getName() == "?":
 *                 return "."             # <<<<<<<<<<<<<<
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":
 *                 return ":"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__6);
      __pyx_r = __pyx_kp_u__6;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":600
 *             return "NP"
 *         elif self.isPunctuation():
 *             if self.root.getName() == "!" or self.root.getName() == "?":             # <<<<<<<<<<<<<<
 *                 return "."
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":602
 *             if self.root.getName() == "!" or self.root.getName() == "?":
 *                 return "."
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":             # <<<<<<<<<<<<<<
 *                 return ":"
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__7, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 602, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__8, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 602, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_6 = __pyx_t_5;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__9, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 602, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L12_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":603
 *                 return "."
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":
 *                 return ":"             # <<<<<<<<<<<<<<
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":
 *                 return "-LRB-"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__10);
      __pyx_r = __pyx_kp_u__10;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":602
 *             if self.root.getName() == "!" or self.root.getName() == "?":
 *                 return "."
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":             # <<<<<<<<<<<<<<
 *                 return ":"
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":604
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":
 *                 return ":"
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":             # <<<<<<<<<<<<<<
 *                 return "-LRB-"
 *             elif self.root.getName() == ")" or self.root.getName() == "-RRB-" or self.root.getName() == "-rrb-":
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__11, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_6 = __pyx_t_5;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_LRB, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_lrb, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L15_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":605
 *                 return ":"
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":
 *                 return "-LRB-"             # <<<<<<<<<<<<<<
 *             elif self.root.getName() == ")" or self.root.getName() == "-RRB-" or self.root.getName() == "-rrb-":
 *                 return "-RRB-"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u_LRB);
      __pyx_r = __pyx_kp_u_LRB;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":604
 *             elif self.root.getName() == ";" or self.root.getName() == "-" or self.root.getName() == "--":
 *                 return ":"
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":             # <<<<<<<<<<<<<<
 *                 return "-LRB-"
 *             elif self.root.getName() == ")" or self.root.getName() == "-RRB-" or self.root.getName() == "-rrb-":
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":606
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":
 *                 return "-LRB-"
 *             elif self.root.getName() == ")" or self.root.getName() == "-RRB-" or self.root.getName() == "-rrb-":             # <<<<<<<<<<<<<<
 *                 return "-RRB-"
 *             else:
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__12, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L18_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_RRB, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_6 = __pyx_t_5;
      goto __pyx_L18_bool_binop_done;
    }
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_rrb, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L18_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":607
 *                 return "-LRB-"
 *             elif self.root.getName() == ")" or self.root.getName() == "-RRB-" or self.root.getName() == "-rrb-":
 *                 return "-RRB-"             # <<<<<<<<<<<<<<
 *             else:
 *                 return self.root.getName()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u_RRB);
      __pyx_r = __pyx_kp_u_RRB;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":606
 *             elif self.root.getName() == "(" or self.root.getName() == "-LRB-" or self.root.getName() == "-lrb-":
 *                 return "-LRB-"
 *             elif self.root.getName() == ")" or self.root.getName() == "-RRB-" or self.root.getName() == "-rrb-":             # <<<<<<<<<<<<<<
 *                 return "-RRB-"
 *             else:
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":609
 *                 return "-RRB-"
 *             else:
 *                 return self.root.getName()             # <<<<<<<<<<<<<<
 *         else:
 *             return "-XXX-"
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":599
 *         elif self.containsTag(MorphologicalTag.PRONOUN):
 *             return "NP"
 *         elif self.isPunctuation():             # <<<<<<<<<<<<<<
 *             if self.root.getName() == "!" or self.root.getName() == "?":
 *                 return "."
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":611
 *                 return self.root.getName()
 *         else:
 *             return "-XXX-"             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getPronType(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_XXX);
    __pyx_r = __pyx_kp_u_XXX;
    goto __pyx_L0;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":561
 *         return False
 * 
 *     cpdef str getTreePos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getTreePos method returns the tree pos tag of a morphological analysis.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTreePos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_77getTreePos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_76getTreePos[] = "\n        The getTreePos method returns the tree pos tag of a morphological analysis.\n\n        RETURNS\n        -------\n        bool\n            Tree pos tag of the morphological analysis in string form.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_77getTreePos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTreePos (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_76getTreePos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_76getTreePos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTreePos", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTreePos(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTreePos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":613
 *             return "-XXX-"
 * 
 *     cpdef str getPronType(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_79getPronType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPronType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lemma = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPronType", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPronType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_79getPronType)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 613, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":615
 *     cpdef str getPronType(self):
 *         cdef str lemma
 *         lemma = self.root.getName()             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PERSONALPRONOUN):
 *             return "Prs"
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lemma = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":616
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.PERSONALPRONOUN):             # <<<<<<<<<<<<<<
 *             return "Prs"
 *         if lemma == "birbiri" or lemma == "birbirleri":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PERSONALPRONOUN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":617
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.PERSONALPRONOUN):
 *             return "Prs"             # <<<<<<<<<<<<<<
 *         if lemma == "birbiri" or lemma == "birbirleri":
 *             return "Rcp"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Prs);
    __pyx_r = __pyx_n_u_Prs;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":616
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.PERSONALPRONOUN):             # <<<<<<<<<<<<<<
 *             return "Prs"
 *         if lemma == "birbiri" or lemma == "birbirleri":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":618
 *         if self.containsTag(MorphologicalTag.PERSONALPRONOUN):
 *             return "Prs"
 *         if lemma == "birbiri" or lemma == "birbirleri":             # <<<<<<<<<<<<<<
 *             return "Rcp"
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \
 */
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_birbiri, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 618, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_birbirleri, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 618, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":619
 *             return "Prs"
 *         if lemma == "birbiri" or lemma == "birbirleri":
 *             return "Rcp"             # <<<<<<<<<<<<<<
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Rcp);
    __pyx_r = __pyx_n_u_Rcp;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":618
 *         if self.containsTag(MorphologicalTag.PERSONALPRONOUN):
 *             return "Prs"
 *         if lemma == "birbiri" or lemma == "birbirleri":             # <<<<<<<<<<<<<<
 *             return "Rcp"
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":620
 *         if lemma == "birbiri" or lemma == "birbirleri":
 *             return "Rcp"
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \             # <<<<<<<<<<<<<<
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 *             return "Int"
 */
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_kim, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_nere, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_ne, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_hangi, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_nasl, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":621
 *             return "Rcp"
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":             # <<<<<<<<<<<<<<
 *             return "Int"
 *         if self.containsTag(MorphologicalTag.DEMONSTRATIVEPRONOUN):
 */
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_ka, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 621, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_mi, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 621, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_m, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 621, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_mu, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 621, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_m_2, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 621, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":620
 *         if lemma == "birbiri" or lemma == "birbirleri":
 *             return "Rcp"
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \             # <<<<<<<<<<<<<<
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 *             return "Int"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":622
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 *             return "Int"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DEMONSTRATIVEPRONOUN):
 *             return "Dem"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Int);
    __pyx_r = __pyx_n_u_Int;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":620
 *         if lemma == "birbiri" or lemma == "birbirleri":
 *             return "Rcp"
 *         if lemma == "kim" or lemma == "nere" or lemma == "ne" or lemma == "hangi" or lemma == "nasl" or \             # <<<<<<<<<<<<<<
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 *             return "Int"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":623
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 *             return "Int"
 *         if self.containsTag(MorphologicalTag.DEMONSTRATIVEPRONOUN):             # <<<<<<<<<<<<<<
 *             return "Dem"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEMONSTRATIVEPRONOUN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":624
 *             return "Int"
 *         if self.containsTag(MorphologicalTag.DEMONSTRATIVEPRONOUN):
 *             return "Dem"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Dem);
    __pyx_r = __pyx_n_u_Dem;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":623
 *                 lemma == "ka" or lemma == "mi" or lemma == "m" or lemma == "mu" or lemma == "m":
 *             return "Int"
 *         if self.containsTag(MorphologicalTag.DEMONSTRATIVEPRONOUN):             # <<<<<<<<<<<<<<
 *             return "Dem"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":625
 *         if self.containsTag(MorphologicalTag.DEMONSTRATIVEPRONOUN):
 *             return "Dem"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getNumType(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":613
 *             return "-XXX-"
 * 
 *     cpdef str getPronType(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPronType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lemma);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_79getPronType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_79getPronType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPronType (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_78getPronType(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_78getPronType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPronType", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPronType(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPronType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":627
 *         return ""
 * 
 *     cpdef str getNumType(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_81getNumType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lemma = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumType", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getNumType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_81getNumType)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 627, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":629
 *     cpdef str getNumType(self):
 *         cdef str lemma
 *         lemma = self.root.getName()             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.CARDINAL) or self.containsTag(MorphologicalTag.NUMBER) or lemma == "ka":
 *             return "Card"
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lemma = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":630
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.CARDINAL) or self.containsTag(MorphologicalTag.NUMBER) or lemma == "ka":             # <<<<<<<<<<<<<<
 *             return "Card"
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_CARDINAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_NUMBER); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_ka, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 630, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":631
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.CARDINAL) or self.containsTag(MorphologicalTag.NUMBER) or lemma == "ka":
 *             return "Card"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":
 *             return "Ord"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Card);
    __pyx_r = __pyx_n_u_Card;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":630
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.CARDINAL) or self.containsTag(MorphologicalTag.NUMBER) or lemma == "ka":             # <<<<<<<<<<<<<<
 *             return "Card"
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":632
 *         if self.containsTag(MorphologicalTag.CARDINAL) or self.containsTag(MorphologicalTag.NUMBER) or lemma == "ka":
 *             return "Card"
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":             # <<<<<<<<<<<<<<
 *             return "Ord"
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ORDINAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_kanc, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 632, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":633
 *             return "Card"
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":
 *             return "Ord"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):
 *             return "Dist"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Ord);
    __pyx_r = __pyx_n_u_Ord;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":632
 *         if self.containsTag(MorphologicalTag.CARDINAL) or self.containsTag(MorphologicalTag.NUMBER) or lemma == "ka":
 *             return "Card"
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":             # <<<<<<<<<<<<<<
 *             return "Ord"
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":634
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":
 *             return "Ord"
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):             # <<<<<<<<<<<<<<
 *             return "Dist"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DISTRIBUTIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":635
 *             return "Ord"
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):
 *             return "Dist"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Dist);
    __pyx_r = __pyx_n_u_Dist;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":634
 *         if self.containsTag(MorphologicalTag.ORDINAL) or lemma == "kanc":
 *             return "Ord"
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):             # <<<<<<<<<<<<<<
 *             return "Dist"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":636
 *         if self.containsTag(MorphologicalTag.DISTRIBUTIVE):
 *             return "Dist"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getReflex(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":627
 *         return ""
 * 
 *     cpdef str getNumType(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getNumType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lemma);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_81getNumType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_81getNumType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumType (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_80getNumType(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_80getNumType(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumType", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumType(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getNumType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":638
 *         return ""
 * 
 *     cpdef str getReflex(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_83getReflex(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getReflex(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lemma = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getReflex", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getReflex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_83getReflex)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 638, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 638, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":640
 *     cpdef str getReflex(self):
 *         cdef str lemma
 *         lemma = self.root.getName()             # <<<<<<<<<<<<<<
 *         if lemma == "kendi":
 *             return "Yes"
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lemma = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":641
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if lemma == "kendi":             # <<<<<<<<<<<<<<
 *             return "Yes"
 *         return ""
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_kendi, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 641, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":642
 *         lemma = self.root.getName()
 *         if lemma == "kendi":
 *             return "Yes"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Yes);
    __pyx_r = __pyx_n_u_Yes;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":641
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if lemma == "kendi":             # <<<<<<<<<<<<<<
 *             return "Yes"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":643
 *         if lemma == "kendi":
 *             return "Yes"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getNumber(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":638
 *         return ""
 * 
 *     cpdef str getReflex(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getReflex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lemma);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_83getReflex(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_83getReflex(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getReflex (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_82getReflex(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_82getReflex(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getReflex", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getReflex(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getReflex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":645
 *         return ""
 * 
 *     cpdef str getNumber(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_85getNumber(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumber", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getNumber); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_85getNumber)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 645, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":646
 * 
 *     cpdef str getNumber(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A1SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_A2SG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":647
 *     cpdef str getNumber(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 *             return "Sing"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A3SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P1SG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":648
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):             # <<<<<<<<<<<<<<
 *             return "Sing"
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_P2SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P3SG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":646
 * 
 *     cpdef str getNumber(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":649
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 *             return "Sing"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Sing);
    __pyx_r = __pyx_n_u_Sing;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":646
 * 
 *     cpdef str getNumber(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":650
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 *             return "Sing"
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A1PL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_A2PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":651
 *             return "Sing"
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):
 *             return "Plur"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A3PL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P1PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":652
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):             # <<<<<<<<<<<<<<
 *             return "Plur"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_P2PL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P3PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L11_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":650
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 *             return "Sing"
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":653
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):
 *             return "Plur"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Plur);
    __pyx_r = __pyx_n_u_Plur;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":650
 *                 self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P3SG):
 *             return "Sing"
 *         if self.containsTag(MorphologicalTag.A1PL) or self.containsTag(MorphologicalTag.A2PL) or \             # <<<<<<<<<<<<<<
 *                 self.containsTag(MorphologicalTag.A3PL) or self.containsTag(MorphologicalTag.P1PL) or \
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":654
 *                 self.containsTag(MorphologicalTag.P2PL) or self.containsTag(MorphologicalTag.P3PL):
 *             return "Plur"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getCase(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":645
 *         return ""
 * 
 *     cpdef str getNumber(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A2SG) or \
 *                 self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.P1SG) or \
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_85getNumber(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_85getNumber(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumber (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_84getNumber(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_84getNumber(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumber", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumber(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":656
 *         return ""
 * 
 *     cpdef str getCase(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):
 *             return "Acc"
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_87getCase(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCase", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getCase); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_87getCase)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 656, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 656, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":657
 * 
 *     cpdef str getCase(self):
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):             # <<<<<<<<<<<<<<
 *             return "Acc"
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ACCUSATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PCACCUSATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":658
 *     cpdef str getCase(self):
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):
 *             return "Acc"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):
 *             return "Dat"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Acc);
    __pyx_r = __pyx_n_u_Acc;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":657
 * 
 *     cpdef str getCase(self):
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):             # <<<<<<<<<<<<<<
 *             return "Acc"
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":659
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):
 *             return "Acc"
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):             # <<<<<<<<<<<<<<
 *             return "Dat"
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L7_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PCDATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":660
 *             return "Acc"
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):
 *             return "Dat"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):
 *             return "Gen"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Dat);
    __pyx_r = __pyx_n_u_Dat;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":659
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):
 *             return "Acc"
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):             # <<<<<<<<<<<<<<
 *             return "Dat"
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":661
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):
 *             return "Dat"
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):             # <<<<<<<<<<<<<<
 *             return "Gen"
 *         if self.containsTag(MorphologicalTag.LOCATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_GENITIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L10_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PCGENITIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":662
 *             return "Dat"
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):
 *             return "Gen"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.LOCATIVE):
 *             return "Loc"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Gen);
    __pyx_r = __pyx_n_u_Gen;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":661
 *         if self.containsTag(MorphologicalTag.DATIVE) or self.containsTag(MorphologicalTag.PCDATIVE):
 *             return "Dat"
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):             # <<<<<<<<<<<<<<
 *             return "Gen"
 *         if self.containsTag(MorphologicalTag.LOCATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":663
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):
 *             return "Gen"
 *         if self.containsTag(MorphologicalTag.LOCATIVE):             # <<<<<<<<<<<<<<
 *             return "Loc"
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_LOCATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":664
 *             return "Gen"
 *         if self.containsTag(MorphologicalTag.LOCATIVE):
 *             return "Loc"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):
 *             return "Ins"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Loc);
    __pyx_r = __pyx_n_u_Loc;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":663
 *         if self.containsTag(MorphologicalTag.GENITIVE) or self.containsTag(MorphologicalTag.PCGENITIVE):
 *             return "Gen"
 *         if self.containsTag(MorphologicalTag.LOCATIVE):             # <<<<<<<<<<<<<<
 *             return "Loc"
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":665
 *         if self.containsTag(MorphologicalTag.LOCATIVE):
 *             return "Loc"
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):             # <<<<<<<<<<<<<<
 *             return "Ins"
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_INSTRUMENTAL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L14_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PCINSTRUMENTAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":666
 *             return "Loc"
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):
 *             return "Ins"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):
 *             return "Abl"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Ins);
    __pyx_r = __pyx_n_u_Ins;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":665
 *         if self.containsTag(MorphologicalTag.LOCATIVE):
 *             return "Loc"
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):             # <<<<<<<<<<<<<<
 *             return "Ins"
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":667
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):
 *             return "Ins"
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):             # <<<<<<<<<<<<<<
 *             return "Abl"
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ABLATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L17_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PCABLATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L17_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":668
 *             return "Ins"
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):
 *             return "Abl"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):
 *             return "Nom"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Abl);
    __pyx_r = __pyx_n_u_Abl;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":667
 *         if self.containsTag(MorphologicalTag.INSTRUMENTAL) or self.containsTag(MorphologicalTag.PCINSTRUMENTAL):
 *             return "Ins"
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):             # <<<<<<<<<<<<<<
 *             return "Abl"
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":669
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):
 *             return "Abl"
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):             # <<<<<<<<<<<<<<
 *             return "Nom"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_NOMINATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L20_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PCNOMINATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L20_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":670
 *             return "Abl"
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):
 *             return "Nom"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Nom);
    __pyx_r = __pyx_n_u_Nom;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":669
 *         if self.containsTag(MorphologicalTag.ABLATIVE) or self.containsTag(MorphologicalTag.PCABLATIVE):
 *             return "Abl"
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):             # <<<<<<<<<<<<<<
 *             return "Nom"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":671
 *         if self.containsTag(MorphologicalTag.NOMINATIVE) or self.containsTag(MorphologicalTag.PCNOMINATIVE):
 *             return "Nom"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getDefinite(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":656
 *         return ""
 * 
 *     cpdef str getCase(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.ACCUSATIVE) or self.containsTag(MorphologicalTag.PCACCUSATIVE):
 *             return "Acc"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getCase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_87getCase(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_87getCase(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCase (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_86getCase(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_86getCase(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCase", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getCase(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getCase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":673
 *         return ""
 * 
 *     cpdef str getDefinite(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_89getDefinite(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDefinite(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lemma = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDefinite", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getDefinite); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_89getDefinite)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 673, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 673, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":675
 *     cpdef str getDefinite(self):
 *         cdef str lemma
 *         lemma = self.root.getName()             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lemma = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":676
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":
 *                 return "Ind"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DETERMINER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":677
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":             # <<<<<<<<<<<<<<
 *                 return "Ind"
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_bir, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 677, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_baz, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 677, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_birka, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 677, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    __pyx_t_5 = __pyx_t_7;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":678
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":
 *                 return "Ind"             # <<<<<<<<<<<<<<
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":
 *                 return "Def"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_u_Ind);
      __pyx_r = __pyx_n_u_Ind;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":677
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":             # <<<<<<<<<<<<<<
 *                 return "Ind"
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":679
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":
 *                 return "Ind"
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":             # <<<<<<<<<<<<<<
 *                 return "Def"
 *         return ""
 */
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_her, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 679, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_bu, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 679, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_u, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 679, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_o, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 679, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_btn, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 679, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":680
 *                 return "Ind"
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":
 *                 return "Def"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_u_Def);
      __pyx_r = __pyx_n_u_Def;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":679
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":
 *                 return "Ind"
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":             # <<<<<<<<<<<<<<
 *                 return "Def"
 *         return ""
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":676
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             if lemma == "bir" or lemma == "baz" or lemma == "birka":
 *                 return "Ind"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":681
 *             if lemma == "her" or lemma == "bu" or lemma == "u" or lemma == "o" or lemma == "btn":
 *                 return "Def"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getDegree(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":673
 *         return ""
 * 
 *     cpdef str getDefinite(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getDefinite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lemma);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_89getDefinite(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_89getDefinite(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDefinite (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_88getDefinite(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_88getDefinite(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDefinite", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDefinite(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getDefinite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":683
 *         return ""
 * 
 *     cpdef str getDegree(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_91getDegree(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDegree(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lemma = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDegree", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getDegree); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_91getDegree)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 683, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 683, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":685
 *     cpdef str getDegree(self):
 *         cdef str lemma
 *         lemma = self.root.getName()             # <<<<<<<<<<<<<<
 *         if lemma == "daha":
 *             return "Cmp"
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lemma = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":686
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if lemma == "daha":             # <<<<<<<<<<<<<<
 *             return "Cmp"
 *         if lemma == "en" and not self.isNoun():
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_daha, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 686, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":687
 *         lemma = self.root.getName()
 *         if lemma == "daha":
 *             return "Cmp"             # <<<<<<<<<<<<<<
 *         if lemma == "en" and not self.isNoun():
 *             return "Sup"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Cmp);
    __pyx_r = __pyx_n_u_Cmp;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":686
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if lemma == "daha":             # <<<<<<<<<<<<<<
 *             return "Cmp"
 *         if lemma == "en" and not self.isNoun():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":688
 *         if lemma == "daha":
 *             return "Cmp"
 *         if lemma == "en" and not self.isNoun():             # <<<<<<<<<<<<<<
 *             return "Sup"
 *         return ""
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_en, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_5 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_7 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNoun(__pyx_v_self, 0) != 0)) != 0);
  __pyx_t_6 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":689
 *             return "Cmp"
 *         if lemma == "en" and not self.isNoun():
 *             return "Sup"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Sup);
    __pyx_r = __pyx_n_u_Sup;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":688
 *         if lemma == "daha":
 *             return "Cmp"
 *         if lemma == "en" and not self.isNoun():             # <<<<<<<<<<<<<<
 *             return "Sup"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":690
 *         if lemma == "en" and not self.isNoun():
 *             return "Sup"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getPolarity(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":683
 *         return ""
 * 
 *     cpdef str getDegree(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getDegree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lemma);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_91getDegree(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_91getDegree(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDegree (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_90getDegree(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_90getDegree(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDegree", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDegree(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getDegree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":692
 *         return ""
 * 
 *     cpdef str getPolarity(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.POSITIVE):
 *             return "Pos"
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_93getPolarity(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPolarity(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPolarity", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPolarity); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_93getPolarity)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 692, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 692, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":693
 * 
 *     cpdef str getPolarity(self):
 *         if self.containsTag(MorphologicalTag.POSITIVE):             # <<<<<<<<<<<<<<
 *             return "Pos"
 *         if self.containsTag(MorphologicalTag.NEGATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_POSITIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":694
 *     cpdef str getPolarity(self):
 *         if self.containsTag(MorphologicalTag.POSITIVE):
 *             return "Pos"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.NEGATIVE):
 *             return "Neg"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Pos);
    __pyx_r = __pyx_n_u_Pos;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":693
 * 
 *     cpdef str getPolarity(self):
 *         if self.containsTag(MorphologicalTag.POSITIVE):             # <<<<<<<<<<<<<<
 *             return "Pos"
 *         if self.containsTag(MorphologicalTag.NEGATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":695
 *         if self.containsTag(MorphologicalTag.POSITIVE):
 *             return "Pos"
 *         if self.containsTag(MorphologicalTag.NEGATIVE):             # <<<<<<<<<<<<<<
 *             return "Neg"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_NEGATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":696
 *             return "Pos"
 *         if self.containsTag(MorphologicalTag.NEGATIVE):
 *             return "Neg"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Neg);
    __pyx_r = __pyx_n_u_Neg;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":695
 *         if self.containsTag(MorphologicalTag.POSITIVE):
 *             return "Pos"
 *         if self.containsTag(MorphologicalTag.NEGATIVE):             # <<<<<<<<<<<<<<
 *             return "Neg"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":697
 *         if self.containsTag(MorphologicalTag.NEGATIVE):
 *             return "Neg"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getPerson(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":692
 *         return ""
 * 
 *     cpdef str getPolarity(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.POSITIVE):
 *             return "Pos"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPolarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_93getPolarity(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_93getPolarity(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPolarity (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_92getPolarity(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_92getPolarity(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPolarity", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPolarity(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPolarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":699
 *         return ""
 * 
 *     cpdef str getPerson(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_95getPerson(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPerson(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPerson", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPerson); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_95getPerson)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 699, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 699, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":700
 * 
 *     cpdef str getPerson(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A1SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":701
 *     cpdef str getPerson(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):             # <<<<<<<<<<<<<<
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":700
 * 
 *     cpdef str getPerson(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_A1PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":701
 *     cpdef str getPerson(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):             # <<<<<<<<<<<<<<
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_P1SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P1PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":700
 * 
 *     cpdef str getPerson(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":702
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_1);
    __pyx_r = __pyx_kp_u_1;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":700
 * 
 *     cpdef str getPerson(self):
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":703
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A2SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":704
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):             # <<<<<<<<<<<<<<
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":703
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_A2PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":704
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):             # <<<<<<<<<<<<<<
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_P2SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P2PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L9_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":703
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":705
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_2);
    __pyx_r = __pyx_kp_u_2;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":703
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 *             return "1"
 *         if self.containsTag(MorphologicalTag.A2SG) or self.containsTag(MorphologicalTag.A2PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":706
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 *             return "3"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_A3SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L14_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":707
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):             # <<<<<<<<<<<<<<
 *             return "3"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":706
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 *             return "3"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_A3PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L14_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":707
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):             # <<<<<<<<<<<<<<
 *             return "3"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_P3SG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L14_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_P3PL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L14_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":706
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 *             return "3"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":708
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 *             return "3"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_3);
    __pyx_r = __pyx_kp_u_3;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":706
 *                 or self.containsTag(MorphologicalTag.P2SG) or self.containsTag(MorphologicalTag.P2PL):
 *             return "2"
 *         if self.containsTag(MorphologicalTag.A3SG) or self.containsTag(MorphologicalTag.A3PL) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 *             return "3"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":709
 *                 or self.containsTag(MorphologicalTag.P3SG) or self.containsTag(MorphologicalTag.P3PL):
 *             return "3"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getVoice(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":699
 *         return ""
 * 
 *     cpdef str getPerson(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.A1SG) or self.containsTag(MorphologicalTag.A1PL) \
 *                 or self.containsTag(MorphologicalTag.P1SG) or self.containsTag(MorphologicalTag.P1PL):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPerson", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_95getPerson(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_95getPerson(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPerson (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_94getPerson(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_94getPerson(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPerson", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPerson(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getPerson", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":711
 *         return ""
 * 
 *     cpdef str getVoice(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASSIVE):
 *             return "Pass"
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_97getVoice(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVoice(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getVoice", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getVoice); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_97getVoice)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 711, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 711, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":712
 * 
 *     cpdef str getVoice(self):
 *         if self.containsTag(MorphologicalTag.PASSIVE):             # <<<<<<<<<<<<<<
 *             return "Pass"
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PASSIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":713
 *     cpdef str getVoice(self):
 *         if self.containsTag(MorphologicalTag.PASSIVE):
 *             return "Pass"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):
 *             return "Rcp"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Pass);
    __pyx_r = __pyx_n_u_Pass;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":712
 * 
 *     cpdef str getVoice(self):
 *         if self.containsTag(MorphologicalTag.PASSIVE):             # <<<<<<<<<<<<<<
 *             return "Pass"
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":714
 *         if self.containsTag(MorphologicalTag.PASSIVE):
 *             return "Pass"
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):             # <<<<<<<<<<<<<<
 *             return "Rcp"
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_RECIPROCAL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":715
 *             return "Pass"
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):
 *             return "Rcp"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):
 *             return "Cau"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Rcp);
    __pyx_r = __pyx_n_u_Rcp;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":714
 *         if self.containsTag(MorphologicalTag.PASSIVE):
 *             return "Pass"
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):             # <<<<<<<<<<<<<<
 *             return "Rcp"
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":716
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):
 *             return "Rcp"
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):             # <<<<<<<<<<<<<<
 *             return "Cau"
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_CAUSATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":717
 *             return "Rcp"
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):
 *             return "Cau"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):
 *             return "Rfl"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Cau);
    __pyx_r = __pyx_n_u_Cau;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":716
 *         if self.containsTag(MorphologicalTag.RECIPROCAL):
 *             return "Rcp"
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):             # <<<<<<<<<<<<<<
 *             return "Cau"
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":718
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):
 *             return "Cau"
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):             # <<<<<<<<<<<<<<
 *             return "Rfl"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_REFLEXIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":719
 *             return "Cau"
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):
 *             return "Rfl"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Rfl);
    __pyx_r = __pyx_n_u_Rfl;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":718
 *         if self.containsTag(MorphologicalTag.CAUSATIVE):
 *             return "Cau"
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):             # <<<<<<<<<<<<<<
 *             return "Rfl"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":720
 *         if self.containsTag(MorphologicalTag.REFLEXIVE):
 *             return "Rfl"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getAspect(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":711
 *         return ""
 * 
 *     cpdef str getVoice(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASSIVE):
 *             return "Pass"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getVoice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_97getVoice(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_97getVoice(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getVoice (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_96getVoice(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_96getVoice(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getVoice", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVoice(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getVoice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":722
 *         return ""
 * 
 *     cpdef str getAspect(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_99getAspect(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getAspect(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAspect", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getAspect); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_99getAspect)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 722, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 722, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":723
 * 
 *     cpdef str getAspect(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PASTTENSE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":724
 *     cpdef str getAspect(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Perf"
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":723
 * 
 *     cpdef str getAspect(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_NARRATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":724
 *     cpdef str getAspect(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Perf"
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_FUTURE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":723
 * 
 *     cpdef str getAspect(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":725
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):
 *             return "Prog"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Perf);
    __pyx_r = __pyx_n_u_Perf;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":723
 * 
 *     cpdef str getAspect(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":726
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):             # <<<<<<<<<<<<<<
 *             return "Prog"
 *         if self.containsTag(MorphologicalTag.AORIST):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PROGRESSIVE1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PROGRESSIVE2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":727
 *             return "Perf"
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):
 *             return "Prog"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.AORIST):
 *             return "Hab"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Prog);
    __pyx_r = __pyx_n_u_Prog;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":726
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Perf"
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):             # <<<<<<<<<<<<<<
 *             return "Prog"
 *         if self.containsTag(MorphologicalTag.AORIST):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":728
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):
 *             return "Prog"
 *         if self.containsTag(MorphologicalTag.AORIST):             # <<<<<<<<<<<<<<
 *             return "Hab"
 *         if self.containsTag(MorphologicalTag.HASTILY):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_AORIST); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":729
 *             return "Prog"
 *         if self.containsTag(MorphologicalTag.AORIST):
 *             return "Hab"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.HASTILY):
 *             return "Rapid"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Hab);
    __pyx_r = __pyx_n_u_Hab;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":728
 *         if self.containsTag(MorphologicalTag.PROGRESSIVE1) or self.containsTag(MorphologicalTag.PROGRESSIVE2):
 *             return "Prog"
 *         if self.containsTag(MorphologicalTag.AORIST):             # <<<<<<<<<<<<<<
 *             return "Hab"
 *         if self.containsTag(MorphologicalTag.HASTILY):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":730
 *         if self.containsTag(MorphologicalTag.AORIST):
 *             return "Hab"
 *         if self.containsTag(MorphologicalTag.HASTILY):             # <<<<<<<<<<<<<<
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_HASTILY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":731
 *             return "Hab"
 *         if self.containsTag(MorphologicalTag.HASTILY):
 *             return "Rapid"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Rapid);
    __pyx_r = __pyx_n_u_Rapid;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":730
 *         if self.containsTag(MorphologicalTag.AORIST):
 *             return "Hab"
 *         if self.containsTag(MorphologicalTag.HASTILY):             # <<<<<<<<<<<<<<
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":732
 *         if self.containsTag(MorphologicalTag.HASTILY):
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 *             return "Dur"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_START); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L13_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":733
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \
 *                 or self.containsTag(MorphologicalTag.REPEAT):             # <<<<<<<<<<<<<<
 *             return "Dur"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":732
 *         if self.containsTag(MorphologicalTag.HASTILY):
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 *             return "Dur"
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_STAY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L13_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":733
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \
 *                 or self.containsTag(MorphologicalTag.REPEAT):             # <<<<<<<<<<<<<<
 *             return "Dur"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_REPEAT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L13_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":732
 *         if self.containsTag(MorphologicalTag.HASTILY):
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 *             return "Dur"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":734
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 *             return "Dur"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Dur);
    __pyx_r = __pyx_n_u_Dur;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":732
 *         if self.containsTag(MorphologicalTag.HASTILY):
 *             return "Rapid"
 *         if self.containsTag(MorphologicalTag.START) or self.containsTag(MorphologicalTag.STAY) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 *             return "Dur"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":735
 *                 or self.containsTag(MorphologicalTag.REPEAT):
 *             return "Dur"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getTense(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":722
 *         return ""
 * 
 *     cpdef str getAspect(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.NARRATIVE) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getAspect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_99getAspect(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_99getAspect(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAspect (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_98getAspect(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_98getAspect(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAspect", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getAspect(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getAspect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":737
 *         return ""
 * 
 *     cpdef str getTense(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Past"
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_101getTense(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTense(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTense", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getTense); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_101getTense)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 737, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 737, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":738
 * 
 *     cpdef str getTense(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE):             # <<<<<<<<<<<<<<
 *             return "Past"
 *         if self.containsTag(MorphologicalTag.FUTURE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PASTTENSE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":739
 *     cpdef str getTense(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Past"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.FUTURE):
 *             return "Fut"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Past);
    __pyx_r = __pyx_n_u_Past;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":738
 * 
 *     cpdef str getTense(self):
 *         if self.containsTag(MorphologicalTag.PASTTENSE):             # <<<<<<<<<<<<<<
 *             return "Past"
 *         if self.containsTag(MorphologicalTag.FUTURE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":740
 *         if self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Past"
 *         if self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Fut"
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FUTURE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":741
 *             return "Past"
 *         if self.containsTag(MorphologicalTag.FUTURE):
 *             return "Fut"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Pqp"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Fut);
    __pyx_r = __pyx_n_u_Fut;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":740
 *         if self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Past"
 *         if self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Fut"
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":742
 *         if self.containsTag(MorphologicalTag.FUTURE):
 *             return "Fut"
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):             # <<<<<<<<<<<<<<
 *             return "Pqp"
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NARRATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PASTTENSE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":743
 *             return "Fut"
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Pqp"             # <<<<<<<<<<<<<<
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):
 *             return "Pres"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Pqp);
    __pyx_r = __pyx_n_u_Pqp;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":742
 *         if self.containsTag(MorphologicalTag.FUTURE):
 *             return "Fut"
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):             # <<<<<<<<<<<<<<
 *             return "Pqp"
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":744
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Pqp"
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Pres"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PASTTENSE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0)) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FUTURE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0)) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":745
 *             return "Pqp"
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):
 *             return "Pres"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Pres);
    __pyx_r = __pyx_n_u_Pres;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":744
 *         if self.containsTag(MorphologicalTag.NARRATIVE) and self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Pqp"
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Pres"
 *         return ""
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":746
 *         if not self.containsTag(MorphologicalTag.PASTTENSE) and not self.containsTag(MorphologicalTag.FUTURE):
 *             return "Pres"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getMood(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":737
 *         return ""
 * 
 *     cpdef str getTense(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTTENSE):
 *             return "Past"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTense", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_101getTense(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_101getTense(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTense (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_100getTense(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_100getTense(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTense", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTense(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getTense", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":748
 *         return ""
 * 
 *     cpdef str getMood(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):
 *             return "Imp"
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_103getMood(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getMood(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getMood", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getMood); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_103getMood)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 748, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 748, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":749
 * 
 *     cpdef str getMood(self):
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):             # <<<<<<<<<<<<<<
 *             return "Imp"
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_IMPERATIVE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":750
 *     cpdef str getMood(self):
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):
 *             return "Imp"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):
 *             return "Cnd"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Imp);
    __pyx_r = __pyx_n_u_Imp;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":749
 * 
 *     cpdef str getMood(self):
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):             # <<<<<<<<<<<<<<
 *             return "Imp"
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":751
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):
 *             return "Imp"
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):             # <<<<<<<<<<<<<<
 *             return "Cnd"
 *         if self.containsTag(MorphologicalTag.DESIRE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_CONDITIONAL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":752
 *             return "Imp"
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):
 *             return "Cnd"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DESIRE):
 *             return "Des"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Cnd);
    __pyx_r = __pyx_n_u_Cnd;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":751
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):
 *             return "Imp"
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):             # <<<<<<<<<<<<<<
 *             return "Cnd"
 *         if self.containsTag(MorphologicalTag.DESIRE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":753
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):
 *             return "Cnd"
 *         if self.containsTag(MorphologicalTag.DESIRE):             # <<<<<<<<<<<<<<
 *             return "Des"
 *         if self.containsTag(MorphologicalTag.OPTATIVE):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DESIRE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":754
 *             return "Cnd"
 *         if self.containsTag(MorphologicalTag.DESIRE):
 *             return "Des"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.OPTATIVE):
 *             return "Opt"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Des);
    __pyx_r = __pyx_n_u_Des;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":753
 *         if self.containsTag(MorphologicalTag.CONDITIONAL):
 *             return "Cnd"
 *         if self.containsTag(MorphologicalTag.DESIRE):             # <<<<<<<<<<<<<<
 *             return "Des"
 *         if self.containsTag(MorphologicalTag.OPTATIVE):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":755
 *         if self.containsTag(MorphologicalTag.DESIRE):
 *             return "Des"
 *         if self.containsTag(MorphologicalTag.OPTATIVE):             # <<<<<<<<<<<<<<
 *             return "Opt"
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_OPTATIVE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":756
 *             return "Des"
 *         if self.containsTag(MorphologicalTag.OPTATIVE):
 *             return "Opt"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 *             return "Nec"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Opt);
    __pyx_r = __pyx_n_u_Opt;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":755
 *         if self.containsTag(MorphologicalTag.DESIRE):
 *             return "Des"
 *         if self.containsTag(MorphologicalTag.OPTATIVE):             # <<<<<<<<<<<<<<
 *             return "Opt"
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":757
 *         if self.containsTag(MorphologicalTag.OPTATIVE):
 *             return "Opt"
 *         if self.containsTag(MorphologicalTag.NECESSITY):             # <<<<<<<<<<<<<<
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NECESSITY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":758
 *             return "Opt"
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 *             return "Nec"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Nec);
    __pyx_r = __pyx_n_u_Nec;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":757
 *         if self.containsTag(MorphologicalTag.OPTATIVE):
 *             return "Opt"
 *         if self.containsTag(MorphologicalTag.NECESSITY):             # <<<<<<<<<<<<<<
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":759
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Ind"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_PASTTENSE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":760
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Ind"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":759
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Ind"
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PROGRESSIVE1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":760
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):             # <<<<<<<<<<<<<<
 *             return "Ind"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FUTURE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L9_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":759
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Ind"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":761
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Ind"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Ind);
    __pyx_r = __pyx_n_u_Ind;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":759
 *         if self.containsTag(MorphologicalTag.NECESSITY):
 *             return "Nec"
 *         if self.containsTag(MorphologicalTag.PASTTENSE) or self.containsTag(MorphologicalTag.PROGRESSIVE1) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Ind"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":762
 *                 or self.containsTag(MorphologicalTag.FUTURE):
 *             return "Ind"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getVerbForm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":748
 *         return ""
 * 
 *     cpdef str getMood(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.IMPERATIVE):
 *             return "Imp"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getMood", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_103getMood(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_103getMood(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getMood (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_102getMood(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_102getMood(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getMood", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getMood(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getMood", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":764
 *         return ""
 * 
 *     cpdef str getVerbForm(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_105getVerbForm(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVerbForm(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getVerbForm", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getVerbForm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_105getVerbForm)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 764, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 764, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":765
 * 
 *     cpdef str getVerbForm(self):
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PASTPARTICIPLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":766
 *     cpdef str getVerbForm(self):
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):             # <<<<<<<<<<<<<<
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":765
 * 
 *     cpdef str getVerbForm(self):
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FUTUREPARTICIPLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":766
 *     cpdef str getVerbForm(self):
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):             # <<<<<<<<<<<<<<
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PRESENTPARTICIPLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":765
 * 
 *     cpdef str getVerbForm(self):
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":767
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Part);
    __pyx_r = __pyx_n_u_Part;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":765
 * 
 *     cpdef str getVerbForm(self):
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":768
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SINCEDOINGSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":769
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":768
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_WITHOUTHAVINGDONESO); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":769
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_WITHOUTBEINGABLETOHAVEDONESO); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":770
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):
 *             return "Conv"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_BYDOINGSO); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":771
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):             # <<<<<<<<<<<<<<
 *             return "Conv"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":770
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):
 *             return "Conv"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_AFTERDOINGSO); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":771
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):             # <<<<<<<<<<<<<<
 *             return "Conv"
 *         return ""
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_INFINITIVE3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":768
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":772
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):
 *             return "Conv"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_Conv);
    __pyx_r = __pyx_n_u_Conv;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":768
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 *             return "Part"
 *         if self.containsTag(MorphologicalTag.SINCEDOINGSO) or self.containsTag(MorphologicalTag.WITHOUTHAVINGDONESO) \             # <<<<<<<<<<<<<<
 *                 or self.containsTag(MorphologicalTag.WITHOUTBEINGABLETOHAVEDONESO) \
 *                 or self.containsTag(MorphologicalTag.BYDOINGSO) or self.containsTag(MorphologicalTag.AFTERDOINGSO) \
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":773
 *                 or self.containsTag(MorphologicalTag.INFINITIVE3):
 *             return "Conv"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef list getUniversalDependencyFeatures(self, str uPos):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__13);
  __pyx_r = __pyx_kp_u__13;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":764
 *         return ""
 * 
 *     cpdef str getVerbForm(self):             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.PASTPARTICIPLE) or self.containsTag(MorphologicalTag.FUTUREPARTICIPLE) \
 *                 or self.containsTag(MorphologicalTag.PRESENTPARTICIPLE):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getVerbForm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_105getVerbForm(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_105getVerbForm(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getVerbForm (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_104getVerbForm(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_104getVerbForm(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getVerbForm", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVerbForm(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getVerbForm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":775
 *         return ""
 * 
 *     cpdef list getUniversalDependencyFeatures(self, str uPos):             # <<<<<<<<<<<<<<
 *         cdef list featureList
 *         cdef str pronType, numType, reflex, degree, number, case_, definite, polarity, person
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_107getUniversalDependencyFeatures(PyObject *__pyx_v_self, PyObject *__pyx_v_uPos); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyFeatures(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_uPos, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_featureList = 0;
  PyObject *__pyx_v_pronType = 0;
  PyObject *__pyx_v_numType = 0;
  PyObject *__pyx_v_reflex = 0;
  PyObject *__pyx_v_degree = 0;
  PyObject *__pyx_v_number = 0;
  PyObject *__pyx_v_case_ = 0;
  PyObject *__pyx_v_definite = 0;
  PyObject *__pyx_v_polarity = 0;
  PyObject *__pyx_v_person = 0;
  PyObject *__pyx_v_voice = 0;
  PyObject *__pyx_v_aspect = 0;
  PyObject *__pyx_v_tense = 0;
  PyObject *__pyx_v_mood = 0;
  PyObject *__pyx_v_verbForm = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependencyFeatures", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getUniversalDependencyFeatures); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 775, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_107getUniversalDependencyFeatures)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_uPos) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_uPos);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 775, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 775, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":779
 *         cdef str pronType, numType, reflex, degree, number, case_, definite, polarity, person
 *         cdef str voice, aspect, tense, mood, verbForm
 *         featureList = []             # <<<<<<<<<<<<<<
 *         pronType = self.getPronType()
 *         if pronType != ""  and uPos != "ADJ" and uPos != "VERB" and uPos != "CCONJ":
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_featureList = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":780
 *         cdef str voice, aspect, tense, mood, verbForm
 *         featureList = []
 *         pronType = self.getPronType()             # <<<<<<<<<<<<<<
 *         if pronType != ""  and uPos != "ADJ" and uPos != "VERB" and uPos != "CCONJ":
 *             featureList.append("PronType=" + pronType)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPronType(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pronType = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":781
 *         featureList = []
 *         pronType = self.getPronType()
 *         if pronType != ""  and uPos != "ADJ" and uPos != "VERB" and uPos != "CCONJ":             # <<<<<<<<<<<<<<
 *             featureList.append("PronType=" + pronType)
 *         numType = self.getNumType()
 */
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_pronType, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 781, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_ADJ, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 781, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_VERB, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 781, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_CCONJ, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 781, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":782
 *         pronType = self.getPronType()
 *         if pronType != ""  and uPos != "ADJ" and uPos != "VERB" and uPos != "CCONJ":
 *             featureList.append("PronType=" + pronType)             # <<<<<<<<<<<<<<
 *         numType = self.getNumType()
 *         if numType != "" and uPos != "VERB":
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_PronType, __pyx_v_pronType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 782, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":781
 *         featureList = []
 *         pronType = self.getPronType()
 *         if pronType != ""  and uPos != "ADJ" and uPos != "VERB" and uPos != "CCONJ":             # <<<<<<<<<<<<<<
 *             featureList.append("PronType=" + pronType)
 *         numType = self.getNumType()
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":783
 *         if pronType != ""  and uPos != "ADJ" and uPos != "VERB" and uPos != "CCONJ":
 *             featureList.append("PronType=" + pronType)
 *         numType = self.getNumType()             # <<<<<<<<<<<<<<
 *         if numType != "" and uPos != "VERB":
 *             featureList.append("NumType=" + numType)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getNumType(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_numType = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":784
 *             featureList.append("PronType=" + pronType)
 *         numType = self.getNumType()
 *         if numType != "" and uPos != "VERB":             # <<<<<<<<<<<<<<
 *             featureList.append("NumType=" + numType)
 *         reflex = self.getReflex()
 */
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_numType, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 784, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_VERB, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 784, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":785
 *         numType = self.getNumType()
 *         if numType != "" and uPos != "VERB":
 *             featureList.append("NumType=" + numType)             # <<<<<<<<<<<<<<
 *         reflex = self.getReflex()
 *         if reflex != "":
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_NumType, __pyx_v_numType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 785, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":784
 *             featureList.append("PronType=" + pronType)
 *         numType = self.getNumType()
 *         if numType != "" and uPos != "VERB":             # <<<<<<<<<<<<<<
 *             featureList.append("NumType=" + numType)
 *         reflex = self.getReflex()
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":786
 *         if numType != "" and uPos != "VERB":
 *             featureList.append("NumType=" + numType)
 *         reflex = self.getReflex()             # <<<<<<<<<<<<<<
 *         if reflex != "":
 *             featureList.append("Reflex=" + reflex)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getReflex(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_reflex = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":787
 *             featureList.append("NumType=" + numType)
 *         reflex = self.getReflex()
 *         if reflex != "":             # <<<<<<<<<<<<<<
 *             featureList.append("Reflex=" + reflex)
 *         degree = self.getDegree()
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_reflex, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 787, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":788
 *         reflex = self.getReflex()
 *         if reflex != "":
 *             featureList.append("Reflex=" + reflex)             # <<<<<<<<<<<<<<
 *         degree = self.getDegree()
 *         if degree != "":
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Reflex, __pyx_v_reflex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":787
 *             featureList.append("NumType=" + numType)
 *         reflex = self.getReflex()
 *         if reflex != "":             # <<<<<<<<<<<<<<
 *             featureList.append("Reflex=" + reflex)
 *         degree = self.getDegree()
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":789
 *         if reflex != "":
 *             featureList.append("Reflex=" + reflex)
 *         degree = self.getDegree()             # <<<<<<<<<<<<<<
 *         if degree != "":
 *             featureList.append("Degree=" + degree)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getDegree(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_degree = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":790
 *             featureList.append("Reflex=" + reflex)
 *         degree = self.getDegree()
 *         if degree != "":             # <<<<<<<<<<<<<<
 *             featureList.append("Degree=" + degree)
 *         if self.isNoun() or self.isVerb():
 */
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_degree, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 790, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":791
 *         degree = self.getDegree()
 *         if degree != "":
 *             featureList.append("Degree=" + degree)             # <<<<<<<<<<<<<<
 *         if self.isNoun() or self.isVerb():
 *             number = self.getNumber()
 */
    __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Degree, __pyx_v_degree); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 791, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":790
 *             featureList.append("Reflex=" + reflex)
 *         degree = self.getDegree()
 *         if degree != "":             # <<<<<<<<<<<<<<
 *             featureList.append("Degree=" + degree)
 *         if self.isNoun() or self.isVerb():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":792
 *         if degree != "":
 *             featureList.append("Degree=" + degree)
 *         if self.isNoun() or self.isVerb():             # <<<<<<<<<<<<<<
 *             number = self.getNumber()
 *             if number != "":
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNoun(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isVerb(__pyx_v_self, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":793
 *             featureList.append("Degree=" + degree)
 *         if self.isNoun() or self.isVerb():
 *             number = self.getNumber()             # <<<<<<<<<<<<<<
 *             if number != "":
 *                 featureList.append("Number=" + number)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getNumber(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_number = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":794
 *         if self.isNoun() or self.isVerb():
 *             number = self.getNumber()
 *             if number != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Number=" + number)
 *         if self.isNoun():
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_number, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 794, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":795
 *             number = self.getNumber()
 *             if number != "":
 *                 featureList.append("Number=" + number)             # <<<<<<<<<<<<<<
 *         if self.isNoun():
 *             case_ = self.getCase()
 */
      __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Number, __pyx_v_number); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 795, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 795, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":794
 *         if self.isNoun() or self.isVerb():
 *             number = self.getNumber()
 *             if number != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Number=" + number)
 *         if self.isNoun():
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":792
 *         if degree != "":
 *             featureList.append("Degree=" + degree)
 *         if self.isNoun() or self.isVerb():             # <<<<<<<<<<<<<<
 *             number = self.getNumber()
 *             if number != "":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":796
 *             if number != "":
 *                 featureList.append("Number=" + number)
 *         if self.isNoun():             # <<<<<<<<<<<<<<
 *             case_ = self.getCase()
 *             if case_ != "":
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNoun(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":797
 *                 featureList.append("Number=" + number)
 *         if self.isNoun():
 *             case_ = self.getCase()             # <<<<<<<<<<<<<<
 *             if case_ != "":
 *                 featureList.append("Case=" + case_)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getCase(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 797, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_case_ = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":798
 *         if self.isNoun():
 *             case_ = self.getCase()
 *             if case_ != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Case=" + case_)
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_case_, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 798, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":799
 *             case_ = self.getCase()
 *             if case_ != "":
 *                 featureList.append("Case=" + case_)             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             definite = self.getDefinite()
 */
      __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Case, __pyx_v_case_); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 799, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 799, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":798
 *         if self.isNoun():
 *             case_ = self.getCase()
 *             if case_ != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Case=" + case_)
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":796
 *             if number != "":
 *                 featureList.append("Number=" + number)
 *         if self.isNoun():             # <<<<<<<<<<<<<<
 *             case_ = self.getCase()
 *             if case_ != "":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":800
 *             if case_ != "":
 *                 featureList.append("Case=" + case_)
 *         if self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             definite = self.getDefinite()
 *             if definite != "":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DETERMINER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":801
 *                 featureList.append("Case=" + case_)
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             definite = self.getDefinite()             # <<<<<<<<<<<<<<
 *             if definite != "":
 *                 featureList.append("Definite=" + definite)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getDefinite(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_definite = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":802
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             definite = self.getDefinite()
 *             if definite != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Definite=" + definite)
 *         if self.isVerb():
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_definite, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 802, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":803
 *             definite = self.getDefinite()
 *             if definite != "":
 *                 featureList.append("Definite=" + definite)             # <<<<<<<<<<<<<<
 *         if self.isVerb():
 *             polarity = self.getPolarity()
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Definite, __pyx_v_definite); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":802
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             definite = self.getDefinite()
 *             if definite != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Definite=" + definite)
 *         if self.isVerb():
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":800
 *             if case_ != "":
 *                 featureList.append("Case=" + case_)
 *         if self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             definite = self.getDefinite()
 *             if definite != "":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":804
 *             if definite != "":
 *                 featureList.append("Definite=" + definite)
 *         if self.isVerb():             # <<<<<<<<<<<<<<
 *             polarity = self.getPolarity()
 *             if polarity != "":
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isVerb(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":805
 *                 featureList.append("Definite=" + definite)
 *         if self.isVerb():
 *             polarity = self.getPolarity()             # <<<<<<<<<<<<<<
 *             if polarity != "":
 *                 featureList.append("Polarity=" + polarity)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPolarity(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 805, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_polarity = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":806
 *         if self.isVerb():
 *             polarity = self.getPolarity()
 *             if polarity != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Polarity=" + polarity)
 *             person = self.getPerson()
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_polarity, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 806, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":807
 *             polarity = self.getPolarity()
 *             if polarity != "":
 *                 featureList.append("Polarity=" + polarity)             # <<<<<<<<<<<<<<
 *             person = self.getPerson()
 *             if person != "" and uPos != "PROPN":
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Polarity, __pyx_v_polarity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 807, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":806
 *         if self.isVerb():
 *             polarity = self.getPolarity()
 *             if polarity != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Polarity=" + polarity)
 *             person = self.getPerson()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":808
 *             if polarity != "":
 *                 featureList.append("Polarity=" + polarity)
 *             person = self.getPerson()             # <<<<<<<<<<<<<<
 *             if person != "" and uPos != "PROPN":
 *                 featureList.append("Person=" + person)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPerson(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 808, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_person = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":809
 *                 featureList.append("Polarity=" + polarity)
 *             person = self.getPerson()
 *             if person != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Person=" + person)
 *             voice = self.getVoice()
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_person, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 809, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L24_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_PROPN, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 809, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L24_bool_binop_done:;
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":810
 *             person = self.getPerson()
 *             if person != "" and uPos != "PROPN":
 *                 featureList.append("Person=" + person)             # <<<<<<<<<<<<<<
 *             voice = self.getVoice()
 *             if voice != "":
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Person, __pyx_v_person); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 810, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":809
 *                 featureList.append("Polarity=" + polarity)
 *             person = self.getPerson()
 *             if person != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Person=" + person)
 *             voice = self.getVoice()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":811
 *             if person != "" and uPos != "PROPN":
 *                 featureList.append("Person=" + person)
 *             voice = self.getVoice()             # <<<<<<<<<<<<<<
 *             if voice != "":
 *                 featureList.append("Voice=" + voice)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getVoice(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_voice = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":812
 *                 featureList.append("Person=" + person)
 *             voice = self.getVoice()
 *             if voice != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Voice=" + voice)
 *             aspect = self.getAspect()
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_voice, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 812, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":813
 *             voice = self.getVoice()
 *             if voice != "":
 *                 featureList.append("Voice=" + voice)             # <<<<<<<<<<<<<<
 *             aspect = self.getAspect()
 *             if aspect != "" and uPos != "PROPN":
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Voice, __pyx_v_voice); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":812
 *                 featureList.append("Person=" + person)
 *             voice = self.getVoice()
 *             if voice != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("Voice=" + voice)
 *             aspect = self.getAspect()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":814
 *             if voice != "":
 *                 featureList.append("Voice=" + voice)
 *             aspect = self.getAspect()             # <<<<<<<<<<<<<<
 *             if aspect != "" and uPos != "PROPN":
 *                 featureList.append("Aspect=" + aspect)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getAspect(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_aspect = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":815
 *                 featureList.append("Voice=" + voice)
 *             aspect = self.getAspect()
 *             if aspect != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Aspect=" + aspect)
 *             tense = self.getTense()
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_aspect, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 815, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L28_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_PROPN, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 815, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L28_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":816
 *             aspect = self.getAspect()
 *             if aspect != "" and uPos != "PROPN":
 *                 featureList.append("Aspect=" + aspect)             # <<<<<<<<<<<<<<
 *             tense = self.getTense()
 *             if tense != "" and uPos != "PROPN":
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Aspect, __pyx_v_aspect); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":815
 *                 featureList.append("Voice=" + voice)
 *             aspect = self.getAspect()
 *             if aspect != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Aspect=" + aspect)
 *             tense = self.getTense()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":817
 *             if aspect != "" and uPos != "PROPN":
 *                 featureList.append("Aspect=" + aspect)
 *             tense = self.getTense()             # <<<<<<<<<<<<<<
 *             if tense != "" and uPos != "PROPN":
 *                 featureList.append("Tense=" + tense)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getTense(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_tense = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":818
 *                 featureList.append("Aspect=" + aspect)
 *             tense = self.getTense()
 *             if tense != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Tense=" + tense)
 *             mood = self.getMood()
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_tense, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 818, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L31_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_PROPN, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 818, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L31_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":819
 *             tense = self.getTense()
 *             if tense != "" and uPos != "PROPN":
 *                 featureList.append("Tense=" + tense)             # <<<<<<<<<<<<<<
 *             mood = self.getMood()
 *             if mood != "" and uPos != "PROPN":
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Tense, __pyx_v_tense); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":818
 *                 featureList.append("Aspect=" + aspect)
 *             tense = self.getTense()
 *             if tense != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Tense=" + tense)
 *             mood = self.getMood()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":820
 *             if tense != "" and uPos != "PROPN":
 *                 featureList.append("Tense=" + tense)
 *             mood = self.getMood()             # <<<<<<<<<<<<<<
 *             if mood != "" and uPos != "PROPN":
 *                 featureList.append("Mood=" + mood)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getMood(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_mood = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":821
 *                 featureList.append("Tense=" + tense)
 *             mood = self.getMood()
 *             if mood != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Mood=" + mood)
 *             verbForm = self.getVerbForm()
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_mood, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 821, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L34_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_uPos, __pyx_n_u_PROPN, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 821, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_7 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L34_bool_binop_done:;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":822
 *             mood = self.getMood()
 *             if mood != "" and uPos != "PROPN":
 *                 featureList.append("Mood=" + mood)             # <<<<<<<<<<<<<<
 *             verbForm = self.getVerbForm()
 *             if verbForm != "":
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_Mood, __pyx_v_mood); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":821
 *                 featureList.append("Tense=" + tense)
 *             mood = self.getMood()
 *             if mood != "" and uPos != "PROPN":             # <<<<<<<<<<<<<<
 *                 featureList.append("Mood=" + mood)
 *             verbForm = self.getVerbForm()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":823
 *             if mood != "" and uPos != "PROPN":
 *                 featureList.append("Mood=" + mood)
 *             verbForm = self.getVerbForm()             # <<<<<<<<<<<<<<
 *             if verbForm != "":
 *                 featureList.append("VerbForm=" + verbForm)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getVerbForm(__pyx_v_self, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_verbForm = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":824
 *                 featureList.append("Mood=" + mood)
 *             verbForm = self.getVerbForm()
 *             if verbForm != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("VerbForm=" + verbForm)
 *         featureList.sort()
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_verbForm, __pyx_kp_u__13, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 824, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":825
 *             verbForm = self.getVerbForm()
 *             if verbForm != "":
 *                 featureList.append("VerbForm=" + verbForm)             # <<<<<<<<<<<<<<
 *         featureList.sort()
 *         return featureList
 */
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_VerbForm, __pyx_v_verbForm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_featureList, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 825, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":824
 *                 featureList.append("Mood=" + mood)
 *             verbForm = self.getVerbForm()
 *             if verbForm != "":             # <<<<<<<<<<<<<<
 *                 featureList.append("VerbForm=" + verbForm)
 *         featureList.sort()
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":804
 *             if definite != "":
 *                 featureList.append("Definite=" + definite)
 *         if self.isVerb():             # <<<<<<<<<<<<<<
 *             polarity = self.getPolarity()
 *             if polarity != "":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":826
 *             if verbForm != "":
 *                 featureList.append("VerbForm=" + verbForm)
 *         featureList.sort()             # <<<<<<<<<<<<<<
 *         return featureList
 * 
 */
  __pyx_t_8 = PyList_Sort(__pyx_v_featureList); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 826, __pyx_L1_error)

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":827
 *                 featureList.append("VerbForm=" + verbForm)
 *         featureList.sort()
 *         return featureList             # <<<<<<<<<<<<<<
 * 
 *     cpdef str getUniversalDependencyPos(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_featureList);
  __pyx_r = __pyx_v_featureList;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":775
 *         return ""
 * 
 *     cpdef list getUniversalDependencyFeatures(self, str uPos):             # <<<<<<<<<<<<<<
 *         cdef list featureList
 *         cdef str pronType, numType, reflex, degree, number, case_, definite, polarity, person
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getUniversalDependencyFeatures", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_featureList);
  __Pyx_XDECREF(__pyx_v_pronType);
  __Pyx_XDECREF(__pyx_v_numType);
  __Pyx_XDECREF(__pyx_v_reflex);
  __Pyx_XDECREF(__pyx_v_degree);
  __Pyx_XDECREF(__pyx_v_number);
  __Pyx_XDECREF(__pyx_v_case_);
  __Pyx_XDECREF(__pyx_v_definite);
  __Pyx_XDECREF(__pyx_v_polarity);
  __Pyx_XDECREF(__pyx_v_person);
  __Pyx_XDECREF(__pyx_v_voice);
  __Pyx_XDECREF(__pyx_v_aspect);
  __Pyx_XDECREF(__pyx_v_tense);
  __Pyx_XDECREF(__pyx_v_mood);
  __Pyx_XDECREF(__pyx_v_verbForm);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_107getUniversalDependencyFeatures(PyObject *__pyx_v_self, PyObject *__pyx_v_uPos); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_107getUniversalDependencyFeatures(PyObject *__pyx_v_self, PyObject *__pyx_v_uPos) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getUniversalDependencyFeatures (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uPos), (&PyUnicode_Type), 1, "uPos", 1))) __PYX_ERR(0, 775, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_106getUniversalDependencyFeatures(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((PyObject*)__pyx_v_uPos));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_106getUniversalDependencyFeatures(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v_uPos) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependencyFeatures", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyFeatures(__pyx_v_self, __pyx_v_uPos, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getUniversalDependencyFeatures", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":829
 *         return featureList
 * 
 *     cpdef str getUniversalDependencyPos(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_109getUniversalDependencyPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lemma = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependencyPos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getUniversalDependencyPos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_109getUniversalDependencyPos)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 829, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 829, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":831
 *     cpdef str getUniversalDependencyPos(self):
 *         cdef str lemma
 *         lemma = self.root.getName()             # <<<<<<<<<<<<<<
 *         if lemma == "deil":
 *             return "AUX"
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lemma = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":832
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if lemma == "deil":             # <<<<<<<<<<<<<<
 *             return "AUX"
 *         if self.isProperNoun():
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_deil, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 832, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":833
 *         lemma = self.root.getName()
 *         if lemma == "deil":
 *             return "AUX"             # <<<<<<<<<<<<<<
 *         if self.isProperNoun():
 *             return "PROPN"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_AUX);
    __pyx_r = __pyx_n_u_AUX;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":832
 *         cdef str lemma
 *         lemma = self.root.getName()
 *         if lemma == "deil":             # <<<<<<<<<<<<<<
 *             return "AUX"
 *         if self.isProperNoun():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":834
 *         if lemma == "deil":
 *             return "AUX"
 *         if self.isProperNoun():             # <<<<<<<<<<<<<<
 *             return "PROPN"
 *         if self.isNoun():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isProperNoun(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":835
 *             return "AUX"
 *         if self.isProperNoun():
 *             return "PROPN"             # <<<<<<<<<<<<<<
 *         if self.isNoun():
 *             return "NOUN"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_PROPN);
    __pyx_r = __pyx_n_u_PROPN;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":834
 *         if lemma == "deil":
 *             return "AUX"
 *         if self.isProperNoun():             # <<<<<<<<<<<<<<
 *             return "PROPN"
 *         if self.isNoun():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":836
 *         if self.isProperNoun():
 *             return "PROPN"
 *         if self.isNoun():             # <<<<<<<<<<<<<<
 *             return "NOUN"
 *         if self.isAdjective():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNoun(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":837
 *             return "PROPN"
 *         if self.isNoun():
 *             return "NOUN"             # <<<<<<<<<<<<<<
 *         if self.isAdjective():
 *             return "ADJ"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NOUN);
    __pyx_r = __pyx_n_u_NOUN;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":836
 *         if self.isProperNoun():
 *             return "PROPN"
 *         if self.isNoun():             # <<<<<<<<<<<<<<
 *             return "NOUN"
 *         if self.isAdjective():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":838
 *         if self.isNoun():
 *             return "NOUN"
 *         if self.isAdjective():             # <<<<<<<<<<<<<<
 *             return "ADJ"
 *         if self.getPos() == "ADV":
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isAdjective(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":839
 *             return "NOUN"
 *         if self.isAdjective():
 *             return "ADJ"             # <<<<<<<<<<<<<<
 *         if self.getPos() == "ADV":
 *             return "ADV"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_ADJ);
    __pyx_r = __pyx_n_u_ADJ;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":838
 *         if self.isNoun():
 *             return "NOUN"
 *         if self.isAdjective():             # <<<<<<<<<<<<<<
 *             return "ADJ"
 *         if self.getPos() == "ADV":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":840
 *         if self.isAdjective():
 *             return "ADJ"
 *         if self.getPos() == "ADV":             # <<<<<<<<<<<<<<
 *             return "ADV"
 *         if self.containsTag(MorphologicalTag.INTERJECTION):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_ADV, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":841
 *             return "ADJ"
 *         if self.getPos() == "ADV":
 *             return "ADV"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJ"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_ADV);
    __pyx_r = __pyx_n_u_ADV;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":840
 *         if self.isAdjective():
 *             return "ADJ"
 *         if self.getPos() == "ADV":             # <<<<<<<<<<<<<<
 *             return "ADV"
 *         if self.containsTag(MorphologicalTag.INTERJECTION):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":842
 *         if self.getPos() == "ADV":
 *             return "ADV"
 *         if self.containsTag(MorphologicalTag.INTERJECTION):             # <<<<<<<<<<<<<<
 *             return "INTJ"
 *         if self.isVerb():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_INTERJECTION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_2, 0) != 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":843
 *             return "ADV"
 *         if self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJ"             # <<<<<<<<<<<<<<
 *         if self.isVerb():
 *             return "VERB"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_INTJ);
    __pyx_r = __pyx_n_u_INTJ;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":842
 *         if self.getPos() == "ADV":
 *             return "ADV"
 *         if self.containsTag(MorphologicalTag.INTERJECTION):             # <<<<<<<<<<<<<<
 *             return "INTJ"
 *         if self.isVerb():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":844
 *         if self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJ"
 *         if self.isVerb():             # <<<<<<<<<<<<<<
 *             return "VERB"
 *         if self.isPunctuation() or self.isHashTag():
 */
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isVerb(__pyx_v_self, 0) != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":845
 *             return "INTJ"
 *         if self.isVerb():
 *             return "VERB"             # <<<<<<<<<<<<<<
 *         if self.isPunctuation() or self.isHashTag():
 *             return "PUNCT"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_VERB);
    __pyx_r = __pyx_n_u_VERB;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":844
 *         if self.containsTag(MorphologicalTag.INTERJECTION):
 *             return "INTJ"
 *         if self.isVerb():             # <<<<<<<<<<<<<<
 *             return "VERB"
 *         if self.isPunctuation() or self.isHashTag():
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":846
 *         if self.isVerb():
 *             return "VERB"
 *         if self.isPunctuation() or self.isHashTag():             # <<<<<<<<<<<<<<
 *             return "PUNCT"
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isPunctuation(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isHashTag(__pyx_v_self, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":847
 *             return "VERB"
 *         if self.isPunctuation() or self.isHashTag():
 *             return "PUNCT"             # <<<<<<<<<<<<<<
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DET"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_PUNCT);
    __pyx_r = __pyx_n_u_PUNCT;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":846
 *         if self.isVerb():
 *             return "VERB"
 *         if self.isPunctuation() or self.isHashTag():             # <<<<<<<<<<<<<<
 *             return "PUNCT"
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":848
 *         if self.isPunctuation() or self.isHashTag():
 *             return "PUNCT"
 *         if self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             return "DET"
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DETERMINER); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->containsTag(__pyx_v_self, __pyx_t_1, 0) != 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":849
 *             return "PUNCT"
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DET"             # <<<<<<<<<<<<<<
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":
 *             return "NUM"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_DET);
    __pyx_r = __pyx_n_u_DET;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":848
 *         if self.isPunctuation() or self.isHashTag():
 *             return "PUNCT"
 *         if self.containsTag(MorphologicalTag.DETERMINER):             # <<<<<<<<<<<<<<
 *             return "DET"
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":850
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DET"
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":             # <<<<<<<<<<<<<<
 *             return "NUM"
 *         if self.getPos() == "PRON":
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isNumber(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isDate(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isTime(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isOrdinal(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->isFraction(__pyx_v_self, 0) != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_kp_u__14, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 850, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":851
 *             return "DET"
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":
 *             return "NUM"             # <<<<<<<<<<<<<<
 *         if self.getPos() == "PRON":
 *             return "PRON"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_NUM);
    __pyx_r = __pyx_n_u_NUM;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":850
 *         if self.containsTag(MorphologicalTag.DETERMINER):
 *             return "DET"
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":             # <<<<<<<<<<<<<<
 *             return "NUM"
 *         if self.getPos() == "PRON":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":852
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":
 *             return "NUM"
 *         if self.getPos() == "PRON":             # <<<<<<<<<<<<<<
 *             return "PRON"
 *         if self.getPos() == "POSTP":
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_PRON, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_5 != 0);
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":853
 *             return "NUM"
 *         if self.getPos() == "PRON":
 *             return "PRON"             # <<<<<<<<<<<<<<
 *         if self.getPos() == "POSTP":
 *             return "ADP"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_PRON);
    __pyx_r = __pyx_n_u_PRON;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":852
 *         if self.isNumber() or self.isDate() or self.isTime() or self.isOrdinal() or self.isFraction() or lemma == "%":
 *             return "NUM"
 *         if self.getPos() == "PRON":             # <<<<<<<<<<<<<<
 *             return "PRON"
 *         if self.getPos() == "POSTP":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":854
 *         if self.getPos() == "PRON":
 *             return "PRON"
 *         if self.getPos() == "POSTP":             # <<<<<<<<<<<<<<
 *             return "ADP"
 *         if self.getPos() == "QUES":
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_POSTP, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_7 != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":855
 *             return "PRON"
 *         if self.getPos() == "POSTP":
 *             return "ADP"             # <<<<<<<<<<<<<<
 *         if self.getPos() == "QUES":
 *             return "AUX"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_ADP);
    __pyx_r = __pyx_n_u_ADP;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":854
 *         if self.getPos() == "PRON":
 *             return "PRON"
 *         if self.getPos() == "POSTP":             # <<<<<<<<<<<<<<
 *             return "ADP"
 *         if self.getPos() == "QUES":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":856
 *         if self.getPos() == "POSTP":
 *             return "ADP"
 *         if self.getPos() == "QUES":             # <<<<<<<<<<<<<<
 *             return "AUX"
 *         if self.getPos() == "CONJ":
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_QUES, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_5 != 0);
  if (__pyx_t_7) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":857
 *             return "ADP"
 *         if self.getPos() == "QUES":
 *             return "AUX"             # <<<<<<<<<<<<<<
 *         if self.getPos() == "CONJ":
 *             if lemma == "ki" or lemma == "eer" or lemma == "diye":
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_AUX);
    __pyx_r = __pyx_n_u_AUX;
    goto __pyx_L0;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":856
 *         if self.getPos() == "POSTP":
 *             return "ADP"
 *         if self.getPos() == "QUES":             # <<<<<<<<<<<<<<
 *             return "AUX"
 *         if self.getPos() == "CONJ":
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":858
 *         if self.getPos() == "QUES":
 *             return "AUX"
 *         if self.getPos() == "CONJ":             # <<<<<<<<<<<<<<
 *             if lemma == "ki" or lemma == "eer" or lemma == "diye":
 *                 return "SCONJ"
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self->__pyx_vtab)->getPos(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_CONJ, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_7 != 0);
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":859
 *             return "AUX"
 *         if self.getPos() == "CONJ":
 *             if lemma == "ki" or lemma == "eer" or lemma == "diye":             # <<<<<<<<<<<<<<
 *                 return "SCONJ"
 *             else:
 */
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_ki, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 859, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_eer, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 859, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_lemma, __pyx_n_u_diye, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 859, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_7 != 0);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L26_bool_binop_done:;
    if (__pyx_t_5) {

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":860
 *         if self.getPos() == "CONJ":
 *             if lemma == "ki" or lemma == "eer" or lemma == "diye":
 *                 return "SCONJ"             # <<<<<<<<<<<<<<
 *             else:
 *                 return "CCONJ"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_u_SCONJ);
      __pyx_r = __pyx_n_u_SCONJ;
      goto __pyx_L0;

      /* "MorphologicalAnalysis/MorphologicalParse.pyx":859
 *             return "AUX"
 *         if self.getPos() == "CONJ":
 *             if lemma == "ki" or lemma == "eer" or lemma == "diye":             # <<<<<<<<<<<<<<
 *                 return "SCONJ"
 *             else:
 */
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":862
 *                 return "SCONJ"
 *             else:
 *                 return "CCONJ"             # <<<<<<<<<<<<<<
 *         return "X"
 * 
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_u_CCONJ);
      __pyx_r = __pyx_n_u_CCONJ;
      goto __pyx_L0;
    }

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":858
 *         if self.getPos() == "QUES":
 *             return "AUX"
 *         if self.getPos() == "CONJ":             # <<<<<<<<<<<<<<
 *             if lemma == "ki" or lemma == "eer" or lemma == "diye":
 *                 return "SCONJ"
 */
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":863
 *             else:
 *                 return "CCONJ"
 *         return "X"             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_n_u_X);
  __pyx_r = __pyx_n_u_X;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":829
 *         return featureList
 * 
 *     cpdef str getUniversalDependencyPos(self):             # <<<<<<<<<<<<<<
 *         cdef str lemma
 *         lemma = self.root.getName()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getUniversalDependencyPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lemma);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_109getUniversalDependencyPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_109getUniversalDependencyPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getUniversalDependencyPos (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_108getUniversalDependencyPos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_108getUniversalDependencyPos(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getUniversalDependencyPos", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyPos(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.getUniversalDependencyPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/MorphologicalParse.pyx":865
 *         return "X"
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         """
 *         The overridden toString method gets the root and the first inflectional group as a result String then
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_111__str__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__[] = "\n        The overridden toString method gets the root and the first inflectional group as a result String then\n        concatenates with ^DB+ and the following inflectional groups.\n\n        RETURNS\n        -------\n        str\n            result str.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__;
#endif
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_111__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_v_result = 0;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":877
 *         cdef str result
 *         cdef int i
 *         result = self.root.getName() + "+" + self.inflectionalGroups[0].__str__()             # <<<<<<<<<<<<<<
 *         for i in range(1, len(self.inflectionalGroups)):
 *             result = result + "^DB+" + self.inflectionalGroups[i].__str__()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)__pyx_v_self->root->__pyx_vtab)->getName(__pyx_v_self->root, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_kp_u_); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 877, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(0, 877, __pyx_L1_error)
  __pyx_v_result = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":878
 *         cdef int i
 *         result = self.root.getName() + "+" + self.inflectionalGroups[0].__str__()
 *         for i in range(1, len(self.inflectionalGroups)):             # <<<<<<<<<<<<<<
 *             result = result + "^DB+" + self.inflectionalGroups[i].__str__()
 *         return result
 */
  __pyx_t_4 = __pyx_v_self->inflectionalGroups;
  __Pyx_INCREF(__pyx_t_4);
  if (unlikely(__pyx_t_4 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 878, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_4); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 878, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 1; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_v_i = __pyx_t_7;

    /* "MorphologicalAnalysis/MorphologicalParse.pyx":879
 *         result = self.root.getName() + "+" + self.inflectionalGroups[0].__str__()
 *         for i in range(1, len(self.inflectionalGroups)):
 *             result = result + "^DB+" + self.inflectionalGroups[i].__str__()             # <<<<<<<<<<<<<<
 *         return result
 */
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_DB); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__pyx_v_self->inflectionalGroups == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 879, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->inflectionalGroups, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 879, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;
  }

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":880
 *         for i in range(1, len(self.inflectionalGroups)):
 *             result = result + "^DB+" + self.inflectionalGroups[i].__str__()
 *         return result             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":865
 *         return "X"
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         """
 *         The overridden toString method gets the root and the first inflectional group as a result String then
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_113__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_113__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_112__reduce_cython__(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_112__reduce_cython__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.inflectionalGroups, self.root)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->inflectionalGroups);
  __Pyx_GIVEREF(__pyx_v_self->inflectionalGroups);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->inflectionalGroups);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->root));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->root));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->root));
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.inflectionalGroups, self.root)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.inflectionalGroups, self.root)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.inflectionalGroups is not None or self.root is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.inflectionalGroups, self.root)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.inflectionalGroups is not None or self.root is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->inflectionalGroups != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (((PyObject *)__pyx_v_self->root) != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.inflectionalGroups is not None or self.root is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.inflectionalGroups is not None or self.root is not None
 *     if use_setstate:
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_MorphologicalPars); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_199806697);
    __Pyx_GIVEREF(__pyx_int_199806697);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_199806697);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.inflectionalGroups is not None or self.root is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, None), state
 *     else:
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_MorphologicalParse__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_MorphologicalPars); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_199806697);
    __Pyx_GIVEREF(__pyx_int_199806697);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_199806697);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_MorphologicalParse__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_115__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_115__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_114__setstate_cython__(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_114__setstate_cython__(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_MorphologicalParse__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_MorphologicalParse, (type(self), 0xbe8cee9, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_MorphologicalParse__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.MorphologicalParse.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_MorphologicalParse(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_1__pyx_unpickle_MorphologicalParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_21MorphologicalAnalysis_18MorphologicalParse_1__pyx_unpickle_MorphologicalParse = {"__pyx_unpickle_MorphologicalParse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_1__pyx_unpickle_MorphologicalParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_1__pyx_unpickle_MorphologicalParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_MorphologicalParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_MorphologicalParse", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_MorphologicalParse", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_MorphologicalParse") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_MorphologicalParse", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.__pyx_unpickle_MorphologicalParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_MorphologicalParse", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xbe8cee9:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xbe8cee9) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xbe8cee9:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)
 *     __pyx_result = MorphologicalParse.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xbe8cee9:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = MorphologicalParse.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xbe, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xbe8cee9:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)
 *     __pyx_result = MorphologicalParse.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)
 *     __pyx_result = MorphologicalParse.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = MorphologicalParse.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse__set_state(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xbe8cee9 = (inflectionalGroups, root))" % __pyx_checksum)
 *     __pyx_result = MorphologicalParse.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_MorphologicalParse(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.__pyx_unpickle_MorphologicalParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_21MorphologicalAnalysis_18MorphologicalParse___pyx_unpickle_MorphologicalParse__set_state(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_MorphologicalParse__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->inflectionalGroups);
  __Pyx_DECREF(__pyx_v___pyx_result->inflectionalGroups);
  __pyx_v___pyx_result->inflectionalGroups = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_10Dictionary_4Word_Word))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->root);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->root));
  __pyx_v___pyx_result->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 2) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_MorphologicalParse__set_state(<MorphologicalParse> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_MorphologicalParse__set_state(MorphologicalParse __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.inflectionalGroups = __pyx_state[0]; __pyx_result.root = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("MorphologicalAnalysis.MorphologicalParse.__pyx_unpickle_MorphologicalParse__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;

static PyObject *__pyx_tp_new_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)o);
  p->__pyx_vtab = __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
  p->inflectionalGroups = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse(PyObject *o) {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *p = (struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->inflectionalGroups);
  Py_CLEAR(p->root);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *p = (struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)o;
  if (p->inflectionalGroups) {
    e = (*v)(p->inflectionalGroups, a); if (e) return e;
  }
  if (p->root) {
    e = (*v)(((PyObject *)p->root), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *p = (struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)o;
  tmp = ((PyObject*)p->inflectionalGroups);
  p->inflectionalGroups = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->root);
  p->root = ((struct __pyx_obj_10Dictionary_4Word_Word *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse[] = {
  {"getWord", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_3getWord, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_2getWord},
  {"getTransitionList", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_5getTransitionList, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_4getTransitionList},
  {"getInflectionalGroupString", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_7getInflectionalGroupString, METH_O, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_6getInflectionalGroupString},
  {"getInflectionalGroup", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_9getInflectionalGroup, METH_O, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_8getInflectionalGroup},
  {"getLastInflectionalGroup", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_11getLastInflectionalGroup, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_10getLastInflectionalGroup},
  {"getTag", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_13getTag, METH_O, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_12getTag},
  {"tagSize", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_15tagSize, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_14tagSize},
  {"size", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_17size, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_16size},
  {"firstInflectionalGroup", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_19firstInflectionalGroup, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_18firstInflectionalGroup},
  {"lastInflectionalGroup", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_21lastInflectionalGroup, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_20lastInflectionalGroup},
  {"getWordWithPos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_23getWordWithPos, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_22getWordWithPos},
  {"getPos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_25getPos, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_24getPos},
  {"getRootPos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_27getRootPos, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_26getRootPos},
  {"lastIGContainsCase", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_29lastIGContainsCase, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_28lastIGContainsCase},
  {"lastIGContainsTag", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_31lastIGContainsTag, METH_O, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_30lastIGContainsTag},
  {"lastIGContainsPossessive", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_33lastIGContainsPossessive, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_32lastIGContainsPossessive},
  {"isCapitalWord", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_35isCapitalWord, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_34isCapitalWord},
  {"isNoun", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_37isNoun, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_36isNoun},
  {"isVerb", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_39isVerb, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_38isVerb},
  {"isRootVerb", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_41isRootVerb, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_40isRootVerb},
  {"isAdjective", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_43isAdjective, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_42isAdjective},
  {"isProperNoun", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_45isProperNoun, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_44isProperNoun},
  {"isPunctuation", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_47isPunctuation, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_46isPunctuation},
  {"isCardinal", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_49isCardinal, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_48isCardinal},
  {"isOrdinal", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_51isOrdinal, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_50isOrdinal},
  {"isReal", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_53isReal, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_52isReal},
  {"isNumber", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_55isNumber, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_54isNumber},
  {"isTime", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_57isTime, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_56isTime},
  {"isDate", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_59isDate, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_58isDate},
  {"isHashTag", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_61isHashTag, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_60isHashTag},
  {"isEmail", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_63isEmail, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_62isEmail},
  {"isPercent", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_65isPercent, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_64isPercent},
  {"isFraction", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_67isFraction, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_66isFraction},
  {"isRange", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_69isRange, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_68isRange},
  {"isPlural", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_71isPlural, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_70isPlural},
  {"isAuxiliary", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_73isAuxiliary, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_72isAuxiliary},
  {"containsTag", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_75containsTag, METH_O, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_74containsTag},
  {"getTreePos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_77getTreePos, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_76getTreePos},
  {"getPronType", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_79getPronType, METH_NOARGS, 0},
  {"getNumType", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_81getNumType, METH_NOARGS, 0},
  {"getReflex", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_83getReflex, METH_NOARGS, 0},
  {"getNumber", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_85getNumber, METH_NOARGS, 0},
  {"getCase", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_87getCase, METH_NOARGS, 0},
  {"getDefinite", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_89getDefinite, METH_NOARGS, 0},
  {"getDegree", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_91getDegree, METH_NOARGS, 0},
  {"getPolarity", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_93getPolarity, METH_NOARGS, 0},
  {"getPerson", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_95getPerson, METH_NOARGS, 0},
  {"getVoice", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_97getVoice, METH_NOARGS, 0},
  {"getAspect", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_99getAspect, METH_NOARGS, 0},
  {"getTense", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_101getTense, METH_NOARGS, 0},
  {"getMood", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_103getMood, METH_NOARGS, 0},
  {"getVerbForm", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_105getVerbForm, METH_NOARGS, 0},
  {"getUniversalDependencyFeatures", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_107getUniversalDependencyFeatures, METH_O, 0},
  {"getUniversalDependencyPos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_109getUniversalDependencyPos, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_113__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_115__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = {
  PyVarObject_HEAD_INIT(0, 0)
  "MorphologicalAnalysis.MorphologicalParse.MorphologicalParse", /*tp_name*/
  sizeof(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_111__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, /*tp_traverse*/
  __pyx_tp_clear_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_MorphologicalParse(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_MorphologicalParse},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "MorphologicalParse",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_kp_u_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 1, 0, 0},
  {&__pyx_kp_u_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 1, 0, 0},
  {&__pyx_kp_u_3, __pyx_k_3, sizeof(__pyx_k_3), 0, 1, 0, 0},
  {&__pyx_n_s_A1PL, __pyx_k_A1PL, sizeof(__pyx_k_A1PL), 0, 0, 1, 1},
  {&__pyx_n_s_A1SG, __pyx_k_A1SG, sizeof(__pyx_k_A1SG), 0, 0, 1, 1},
  {&__pyx_n_s_A2PL, __pyx_k_A2PL, sizeof(__pyx_k_A2PL), 0, 0, 1, 1},
  {&__pyx_n_s_A2SG, __pyx_k_A2SG, sizeof(__pyx_k_A2SG), 0, 0, 1, 1},
  {&__pyx_n_s_A3PL, __pyx_k_A3PL, sizeof(__pyx_k_A3PL), 0, 0, 1, 1},
  {&__pyx_n_s_A3SG, __pyx_k_A3SG, sizeof(__pyx_k_A3SG), 0, 0, 1, 1},
  {&__pyx_n_s_ABLATIVE, __pyx_k_ABLATIVE, sizeof(__pyx_k_ABLATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_ACCUSATIVE, __pyx_k_ACCUSATIVE, sizeof(__pyx_k_ACCUSATIVE), 0, 0, 1, 1},
  {&__pyx_n_u_ADJ, __pyx_k_ADJ, sizeof(__pyx_k_ADJ), 0, 1, 0, 1},
  {&__pyx_n_u_ADJP, __pyx_k_ADJP, sizeof(__pyx_k_ADJP), 0, 1, 0, 1},
  {&__pyx_n_u_ADP, __pyx_k_ADP, sizeof(__pyx_k_ADP), 0, 1, 0, 1},
  {&__pyx_n_u_ADV, __pyx_k_ADV, sizeof(__pyx_k_ADV), 0, 1, 0, 1},
  {&__pyx_n_s_ADVERB, __pyx_k_ADVERB, sizeof(__pyx_k_ADVERB), 0, 0, 1, 1},
  {&__pyx_n_u_ADVP, __pyx_k_ADVP, sizeof(__pyx_k_ADVP), 0, 1, 0, 1},
  {&__pyx_n_s_AFTERDOINGSO, __pyx_k_AFTERDOINGSO, sizeof(__pyx_k_AFTERDOINGSO), 0, 0, 1, 1},
  {&__pyx_n_s_AORIST, __pyx_k_AORIST, sizeof(__pyx_k_AORIST), 0, 0, 1, 1},
  {&__pyx_n_u_AUX, __pyx_k_AUX, sizeof(__pyx_k_AUX), 0, 1, 0, 1},
  {&__pyx_n_u_Abl, __pyx_k_Abl, sizeof(__pyx_k_Abl), 0, 1, 0, 1},
  {&__pyx_n_u_Acc, __pyx_k_Acc, sizeof(__pyx_k_Acc), 0, 1, 0, 1},
  {&__pyx_kp_u_Aspect, __pyx_k_Aspect, sizeof(__pyx_k_Aspect), 0, 1, 0, 0},
  {&__pyx_n_s_BYDOINGSO, __pyx_k_BYDOINGSO, sizeof(__pyx_k_BYDOINGSO), 0, 0, 1, 1},
  {&__pyx_n_s_CARDINAL, __pyx_k_CARDINAL, sizeof(__pyx_k_CARDINAL), 0, 0, 1, 1},
  {&__pyx_n_s_CAUSATIVE, __pyx_k_CAUSATIVE, sizeof(__pyx_k_CAUSATIVE), 0, 0, 1, 1},
  {&__pyx_n_u_CCONJ, __pyx_k_CCONJ, sizeof(__pyx_k_CCONJ), 0, 1, 0, 1},
  {&__pyx_n_s_CONDITIONAL, __pyx_k_CONDITIONAL, sizeof(__pyx_k_CONDITIONAL), 0, 0, 1, 1},
  {&__pyx_n_u_CONJ, __pyx_k_CONJ, sizeof(__pyx_k_CONJ), 0, 1, 0, 1},
  {&__pyx_n_u_CONJP, __pyx_k_CONJP, sizeof(__pyx_k_CONJP), 0, 1, 0, 1},
  {&__pyx_n_s_CONJUNCTION, __pyx_k_CONJUNCTION, sizeof(__pyx_k_CONJUNCTION), 0, 0, 1, 1},
  {&__pyx_n_u_Card, __pyx_k_Card, sizeof(__pyx_k_Card), 0, 1, 0, 1},
  {&__pyx_kp_u_Case, __pyx_k_Case, sizeof(__pyx_k_Case), 0, 1, 0, 0},
  {&__pyx_n_u_Cau, __pyx_k_Cau, sizeof(__pyx_k_Cau), 0, 1, 0, 1},
  {&__pyx_n_u_Cmp, __pyx_k_Cmp, sizeof(__pyx_k_Cmp), 0, 1, 0, 1},
  {&__pyx_n_u_Cnd, __pyx_k_Cnd, sizeof(__pyx_k_Cnd), 0, 1, 0, 1},
  {&__pyx_n_u_Conv, __pyx_k_Conv, sizeof(__pyx_k_Conv), 0, 1, 0, 1},
  {&__pyx_n_s_DATE, __pyx_k_DATE, sizeof(__pyx_k_DATE), 0, 0, 1, 1},
  {&__pyx_n_s_DATIVE, __pyx_k_DATIVE, sizeof(__pyx_k_DATIVE), 0, 0, 1, 1},
  {&__pyx_kp_u_DB, __pyx_k_DB, sizeof(__pyx_k_DB), 0, 1, 0, 0},
  {&__pyx_n_s_DEMONSTRATIVEPRONOUN, __pyx_k_DEMONSTRATIVEPRONOUN, sizeof(__pyx_k_DEMONSTRATIVEPRONOUN), 0, 0, 1, 1},
  {&__pyx_n_s_DESIRE, __pyx_k_DESIRE, sizeof(__pyx_k_DESIRE), 0, 0, 1, 1},
  {&__pyx_n_u_DET, __pyx_k_DET, sizeof(__pyx_k_DET), 0, 1, 0, 1},
  {&__pyx_n_s_DETERMINER, __pyx_k_DETERMINER, sizeof(__pyx_k_DETERMINER), 0, 0, 1, 1},
  {&__pyx_n_s_DISTRIBUTIVE, __pyx_k_DISTRIBUTIVE, sizeof(__pyx_k_DISTRIBUTIVE), 0, 0, 1, 1},
  {&__pyx_n_u_DP, __pyx_k_DP, sizeof(__pyx_k_DP), 0, 1, 0, 1},
  {&__pyx_n_u_Dat, __pyx_k_Dat, sizeof(__pyx_k_Dat), 0, 1, 0, 1},
  {&__pyx_n_u_Def, __pyx_k_Def, sizeof(__pyx_k_Def), 0, 1, 0, 1},
  {&__pyx_kp_u_Definite, __pyx_k_Definite, sizeof(__pyx_k_Definite), 0, 1, 0, 0},
  {&__pyx_kp_u_Degree, __pyx_k_Degree, sizeof(__pyx_k_Degree), 0, 1, 0, 0},
  {&__pyx_n_u_Dem, __pyx_k_Dem, sizeof(__pyx_k_Dem), 0, 1, 0, 1},
  {&__pyx_n_u_Des, __pyx_k_Des, sizeof(__pyx_k_Des), 0, 1, 0, 1},
  {&__pyx_n_u_Dist, __pyx_k_Dist, sizeof(__pyx_k_Dist), 0, 1, 0, 1},
  {&__pyx_n_u_Dur, __pyx_k_Dur, sizeof(__pyx_k_Dur), 0, 1, 0, 1},
  {&__pyx_n_s_EMAIL, __pyx_k_EMAIL, sizeof(__pyx_k_EMAIL), 0, 0, 1, 1},
  {&__pyx_n_s_FRACTION, __pyx_k_FRACTION, sizeof(__pyx_k_FRACTION), 0, 0, 1, 1},
  {&__pyx_n_s_FUTURE, __pyx_k_FUTURE, sizeof(__pyx_k_FUTURE), 0, 0, 1, 1},
  {&__pyx_n_s_FUTUREPARTICIPLE, __pyx_k_FUTUREPARTICIPLE, sizeof(__pyx_k_FUTUREPARTICIPLE), 0, 0, 1, 1},
  {&__pyx_n_u_Fut, __pyx_k_Fut, sizeof(__pyx_k_Fut), 0, 1, 0, 1},
  {&__pyx_n_s_GENITIVE, __pyx_k_GENITIVE, sizeof(__pyx_k_GENITIVE), 0, 0, 1, 1},
  {&__pyx_n_u_Gen, __pyx_k_Gen, sizeof(__pyx_k_Gen), 0, 1, 0, 1},
  {&__pyx_n_s_HASHTAG, __pyx_k_HASHTAG, sizeof(__pyx_k_HASHTAG), 0, 0, 1, 1},
  {&__pyx_n_s_HASTILY, __pyx_k_HASTILY, sizeof(__pyx_k_HASTILY), 0, 0, 1, 1},
  {&__pyx_n_u_Hab, __pyx_k_Hab, sizeof(__pyx_k_Hab), 0, 1, 0, 1},
  {&__pyx_n_s_IMPERATIVE, __pyx_k_IMPERATIVE, sizeof(__pyx_k_IMPERATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_INFINITIVE3, __pyx_k_INFINITIVE3, sizeof(__pyx_k_INFINITIVE3), 0, 0, 1, 1},
  {&__pyx_n_s_INSTRUMENTAL, __pyx_k_INSTRUMENTAL, sizeof(__pyx_k_INSTRUMENTAL), 0, 0, 1, 1},
  {&__pyx_n_s_INTERJECTION, __pyx_k_INTERJECTION, sizeof(__pyx_k_INTERJECTION), 0, 0, 1, 1},
  {&__pyx_n_u_INTJ, __pyx_k_INTJ, sizeof(__pyx_k_INTJ), 0, 1, 0, 1},
  {&__pyx_n_u_INTJP, __pyx_k_INTJP, sizeof(__pyx_k_INTJP), 0, 1, 0, 1},
  {&__pyx_n_u_Imp, __pyx_k_Imp, sizeof(__pyx_k_Imp), 0, 1, 0, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xbe, __pyx_k_Incompatible_checksums_s_vs_0xbe, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xbe), 0, 0, 1, 0},
  {&__pyx_n_u_Ind, __pyx_k_Ind, sizeof(__pyx_k_Ind), 0, 1, 0, 1},
  {&__pyx_n_u_Ins, __pyx_k_Ins, sizeof(__pyx_k_Ins), 0, 1, 0, 1},
  {&__pyx_n_u_Int, __pyx_k_Int, sizeof(__pyx_k_Int), 0, 1, 0, 1},
  {&__pyx_n_s_LOCATIVE, __pyx_k_LOCATIVE, sizeof(__pyx_k_LOCATIVE), 0, 0, 1, 1},
  {&__pyx_kp_u_LRB, __pyx_k_LRB, sizeof(__pyx_k_LRB), 0, 1, 0, 0},
  {&__pyx_n_u_Loc, __pyx_k_Loc, sizeof(__pyx_k_Loc), 0, 1, 0, 1},
  {&__pyx_kp_u_Mood, __pyx_k_Mood, sizeof(__pyx_k_Mood), 0, 1, 0, 0},
  {&__pyx_n_s_MorphologicalAnalysis_Morphologi, __pyx_k_MorphologicalAnalysis_Morphologi, sizeof(__pyx_k_MorphologicalAnalysis_Morphologi), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalAnalysis_Morphologi_2, __pyx_k_MorphologicalAnalysis_Morphologi_2, sizeof(__pyx_k_MorphologicalAnalysis_Morphologi_2), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalParse, __pyx_k_MorphologicalParse, sizeof(__pyx_k_MorphologicalParse), 0, 0, 1, 1},
  {&__pyx_n_s_MorphologicalTag, __pyx_k_MorphologicalTag, sizeof(__pyx_k_MorphologicalTag), 0, 0, 1, 1},
  {&__pyx_n_s_NARRATIVE, __pyx_k_NARRATIVE, sizeof(__pyx_k_NARRATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_NECESSITY, __pyx_k_NECESSITY, sizeof(__pyx_k_NECESSITY), 0, 0, 1, 1},
  {&__pyx_n_u_NEG, __pyx_k_NEG, sizeof(__pyx_k_NEG), 0, 1, 0, 1},
  {&__pyx_n_s_NEGATIVE, __pyx_k_NEGATIVE, sizeof(__pyx_k_NEGATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_NOMINATIVE, __pyx_k_NOMINATIVE, sizeof(__pyx_k_NOMINATIVE), 0, 0, 1, 1},
  {&__pyx_n_u_NOMP, __pyx_k_NOMP, sizeof(__pyx_k_NOMP), 0, 1, 0, 1},
  {&__pyx_n_u_NOUN, __pyx_k_NOUN, sizeof(__pyx_k_NOUN), 0, 1, 0, 1},
  {&__pyx_n_u_NP, __pyx_k_NP, sizeof(__pyx_k_NP), 0, 1, 0, 1},
  {&__pyx_n_u_NULL, __pyx_k_NULL, sizeof(__pyx_k_NULL), 0, 1, 0, 1},
  {&__pyx_n_u_NUM, __pyx_k_NUM, sizeof(__pyx_k_NUM), 0, 1, 0, 1},
  {&__pyx_n_s_NUMBER, __pyx_k_NUMBER, sizeof(__pyx_k_NUMBER), 0, 0, 1, 1},
  {&__pyx_n_u_Nec, __pyx_k_Nec, sizeof(__pyx_k_Nec), 0, 1, 0, 1},
  {&__pyx_n_u_Neg, __pyx_k_Neg, sizeof(__pyx_k_Neg), 0, 1, 0, 1},
  {&__pyx_n_u_Nom, __pyx_k_Nom, sizeof(__pyx_k_Nom), 0, 1, 0, 1},
  {&__pyx_kp_u_NumType, __pyx_k_NumType, sizeof(__pyx_k_NumType), 0, 1, 0, 0},
  {&__pyx_kp_u_Number, __pyx_k_Number, sizeof(__pyx_k_Number), 0, 1, 0, 0},
  {&__pyx_n_s_OPTATIVE, __pyx_k_OPTATIVE, sizeof(__pyx_k_OPTATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_ORDINAL, __pyx_k_ORDINAL, sizeof(__pyx_k_ORDINAL), 0, 0, 1, 1},
  {&__pyx_n_u_Opt, __pyx_k_Opt, sizeof(__pyx_k_Opt), 0, 1, 0, 1},
  {&__pyx_n_u_Ord, __pyx_k_Ord, sizeof(__pyx_k_Ord), 0, 1, 0, 1},
  {&__pyx_n_s_P1PL, __pyx_k_P1PL, sizeof(__pyx_k_P1PL), 0, 0, 1, 1},
  {&__pyx_n_s_P1SG, __pyx_k_P1SG, sizeof(__pyx_k_P1SG), 0, 0, 1, 1},
  {&__pyx_n_s_P2PL, __pyx_k_P2PL, sizeof(__pyx_k_P2PL), 0, 0, 1, 1},
  {&__pyx_n_s_P2SG, __pyx_k_P2SG, sizeof(__pyx_k_P2SG), 0, 0, 1, 1},
  {&__pyx_n_s_P3PL, __pyx_k_P3PL, sizeof(__pyx_k_P3PL), 0, 0, 1, 1},
  {&__pyx_n_s_P3SG, __pyx_k_P3SG, sizeof(__pyx_k_P3SG), 0, 0, 1, 1},
  {&__pyx_n_s_PASSIVE, __pyx_k_PASSIVE, sizeof(__pyx_k_PASSIVE), 0, 0, 1, 1},
  {&__pyx_n_s_PASTPARTICIPLE, __pyx_k_PASTPARTICIPLE, sizeof(__pyx_k_PASTPARTICIPLE), 0, 0, 1, 1},
  {&__pyx_n_s_PASTTENSE, __pyx_k_PASTTENSE, sizeof(__pyx_k_PASTTENSE), 0, 0, 1, 1},
  {&__pyx_n_s_PCABLATIVE, __pyx_k_PCABLATIVE, sizeof(__pyx_k_PCABLATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_PCACCUSATIVE, __pyx_k_PCACCUSATIVE, sizeof(__pyx_k_PCACCUSATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_PCDATIVE, __pyx_k_PCDATIVE, sizeof(__pyx_k_PCDATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_PCGENITIVE, __pyx_k_PCGENITIVE, sizeof(__pyx_k_PCGENITIVE), 0, 0, 1, 1},
  {&__pyx_n_s_PCINSTRUMENTAL, __pyx_k_PCINSTRUMENTAL, sizeof(__pyx_k_PCINSTRUMENTAL), 0, 0, 1, 1},
  {&__pyx_n_s_PCNOMINATIVE, __pyx_k_PCNOMINATIVE, sizeof(__pyx_k_PCNOMINATIVE), 0, 0, 1, 1},
  {&__pyx_n_s_PERCENT, __pyx_k_PERCENT, sizeof(__pyx_k_PERCENT), 0, 0, 1, 1},
  {&__pyx_n_s_PERSONALPRONOUN, __pyx_k_PERSONALPRONOUN, sizeof(__pyx_k_PERSONALPRONOUN), 0, 0, 1, 1},
  {&__pyx_n_s_POSITIVE, __pyx_k_POSITIVE, sizeof(__pyx_k_POSITIVE), 0, 0, 1, 1},
  {&__pyx_n_u_POSTP, __pyx_k_POSTP, sizeof(__pyx_k_POSTP), 0, 1, 0, 1},
  {&__pyx_n_s_POSTPOSITION, __pyx_k_POSTPOSITION, sizeof(__pyx_k_POSTPOSITION), 0, 0, 1, 1},
  {&__pyx_n_u_PP, __pyx_k_PP, sizeof(__pyx_k_PP), 0, 1, 0, 1},
  {&__pyx_n_s_PRESENTPARTICIPLE, __pyx_k_PRESENTPARTICIPLE, sizeof(__pyx_k_PRESENTPARTICIPLE), 0, 0, 1, 1},
  {&__pyx_n_s_PROGRESSIVE1, __pyx_k_PROGRESSIVE1, sizeof(__pyx_k_PROGRESSIVE1), 0, 0, 1, 1},
  {&__pyx_n_s_PROGRESSIVE2, __pyx_k_PROGRESSIVE2, sizeof(__pyx_k_PROGRESSIVE2), 0, 0, 1, 1},
  {&__pyx_n_u_PRON, __pyx_k_PRON, sizeof(__pyx_k_PRON), 0, 1, 0, 1},
  {&__pyx_n_s_PRONOUN, __pyx_k_PRONOUN, sizeof(__pyx_k_PRONOUN), 0, 0, 1, 1},
  {&__pyx_n_s_PROPERNOUN, __pyx_k_PROPERNOUN, sizeof(__pyx_k_PROPERNOUN), 0, 0, 1, 1},
  {&__pyx_n_u_PROPN, __pyx_k_PROPN, sizeof(__pyx_k_PROPN), 0, 1, 0, 1},
  {&__pyx_n_u_PUNCT, __pyx_k_PUNCT, sizeof(__pyx_k_PUNCT), 0, 1, 0, 1},
  {&__pyx_n_s_PUNCTUATION, __pyx_k_PUNCTUATION, sizeof(__pyx_k_PUNCTUATION), 0, 0, 1, 1},
  {&__pyx_n_u_Part, __pyx_k_Part, sizeof(__pyx_k_Part), 0, 1, 0, 1},
  {&__pyx_n_u_Pass, __pyx_k_Pass, sizeof(__pyx_k_Pass), 0, 1, 0, 1},
  {&__pyx_n_u_Past, __pyx_k_Past, sizeof(__pyx_k_Past), 0, 1, 0, 1},
  {&__pyx_n_u_Perf, __pyx_k_Perf, sizeof(__pyx_k_Perf), 0, 1, 0, 1},
  {&__pyx_kp_u_Person, __pyx_k_Person, sizeof(__pyx_k_Person), 0, 1, 0, 0},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_u_Plur, __pyx_k_Plur, sizeof(__pyx_k_Plur), 0, 1, 0, 1},
  {&__pyx_kp_u_Polarity, __pyx_k_Polarity, sizeof(__pyx_k_Polarity), 0, 1, 0, 0},
  {&__pyx_n_u_Pos, __pyx_k_Pos, sizeof(__pyx_k_Pos), 0, 1, 0, 1},
  {&__pyx_n_u_Pqp, __pyx_k_Pqp, sizeof(__pyx_k_Pqp), 0, 1, 0, 1},
  {&__pyx_n_u_Pres, __pyx_k_Pres, sizeof(__pyx_k_Pres), 0, 1, 0, 1},
  {&__pyx_n_u_Prog, __pyx_k_Prog, sizeof(__pyx_k_Prog), 0, 1, 0, 1},
  {&__pyx_kp_u_PronType, __pyx_k_PronType, sizeof(__pyx_k_PronType), 0, 1, 0, 0},
  {&__pyx_n_u_Prs, __pyx_k_Prs, sizeof(__pyx_k_Prs), 0, 1, 0, 1},
  {&__pyx_kp_u_Punc, __pyx_k_Punc, sizeof(__pyx_k_Punc), 0, 1, 0, 0},
  {&__pyx_n_u_Punc_2, __pyx_k_Punc_2, sizeof(__pyx_k_Punc_2), 0, 1, 0, 1},
  {&__pyx_n_u_QUES, __pyx_k_QUES, sizeof(__pyx_k_QUES), 0, 1, 0, 1},
  {&__pyx_n_s_QUESTIONPRONOUN, __pyx_k_QUESTIONPRONOUN, sizeof(__pyx_k_QUESTIONPRONOUN), 0, 0, 1, 1},
  {&__pyx_n_s_RANGE, __pyx_k_RANGE, sizeof(__pyx_k_RANGE), 0, 0, 1, 1},
  {&__pyx_n_s_REAL, __pyx_k_REAL, sizeof(__pyx_k_REAL), 0, 0, 1, 1},
  {&__pyx_n_s_RECIPROCAL, __pyx_k_RECIPROCAL, sizeof(__pyx_k_RECIPROCAL), 0, 0, 1, 1},
  {&__pyx_n_s_REFLEXIVE, __pyx_k_REFLEXIVE, sizeof(__pyx_k_REFLEXIVE), 0, 0, 1, 1},
  {&__pyx_n_s_REPEAT, __pyx_k_REPEAT, sizeof(__pyx_k_REPEAT), 0, 0, 1, 1},
  {&__pyx_kp_u_RRB, __pyx_k_RRB, sizeof(__pyx_k_RRB), 0, 1, 0, 0},
  {&__pyx_n_u_Rapid, __pyx_k_Rapid, sizeof(__pyx_k_Rapid), 0, 1, 0, 1},
  {&__pyx_n_u_Rcp, __pyx_k_Rcp, sizeof(__pyx_k_Rcp), 0, 1, 0, 1},
  {&__pyx_kp_u_Reflex, __pyx_k_Reflex, sizeof(__pyx_k_Reflex), 0, 1, 0, 0},
  {&__pyx_n_u_Rfl, __pyx_k_Rfl, sizeof(__pyx_k_Rfl), 0, 1, 0, 1},
  {&__pyx_n_u_SCONJ, __pyx_k_SCONJ, sizeof(__pyx_k_SCONJ), 0, 1, 0, 1},
  {&__pyx_n_s_SINCEDOINGSO, __pyx_k_SINCEDOINGSO, sizeof(__pyx_k_SINCEDOINGSO), 0, 0, 1, 1},
  {&__pyx_n_s_START, __pyx_k_START, sizeof(__pyx_k_START), 0, 0, 1, 1},
  {&__pyx_n_s_STAY, __pyx_k_STAY, sizeof(__pyx_k_STAY), 0, 0, 1, 1},
  {&__pyx_n_u_Sing, __pyx_k_Sing, sizeof(__pyx_k_Sing), 0, 1, 0, 1},
  {&__pyx_n_u_Sup, __pyx_k_Sup, sizeof(__pyx_k_Sup), 0, 1, 0, 1},
  {&__pyx_n_s_TIME, __pyx_k_TIME, sizeof(__pyx_k_TIME), 0, 0, 1, 1},
  {&__pyx_kp_u_Tense, __pyx_k_Tense, sizeof(__pyx_k_Tense), 0, 1, 0, 0},
  {&__pyx_n_u_VERB, __pyx_k_VERB, sizeof(__pyx_k_VERB), 0, 1, 0, 1},
  {&__pyx_n_u_VP, __pyx_k_VP, sizeof(__pyx_k_VP), 0, 1, 0, 1},
  {&__pyx_kp_u_VerbForm, __pyx_k_VerbForm, sizeof(__pyx_k_VerbForm), 0, 1, 0, 0},
  {&__pyx_kp_u_Voice, __pyx_k_Voice, sizeof(__pyx_k_Voice), 0, 1, 0, 0},
  {&__pyx_n_s_WITHOUTBEINGABLETOHAVEDONESO, __pyx_k_WITHOUTBEINGABLETOHAVEDONESO, sizeof(__pyx_k_WITHOUTBEINGABLETOHAVEDONESO), 0, 0, 1, 1},
  {&__pyx_n_s_WITHOUTHAVINGDONESO, __pyx_k_WITHOUTHAVINGDONESO, sizeof(__pyx_k_WITHOUTHAVINGDONESO), 0, 0, 1, 1},
  {&__pyx_n_u_WP, __pyx_k_WP, sizeof(__pyx_k_WP), 0, 1, 0, 1},
  {&__pyx_n_u_X, __pyx_k_X, sizeof(__pyx_k_X), 0, 1, 0, 1},
  {&__pyx_kp_u_XXX, __pyx_k_XXX, sizeof(__pyx_k_XXX), 0, 1, 0, 0},
  {&__pyx_n_u_Yes, __pyx_k_Yes, sizeof(__pyx_k_Yes), 0, 1, 0, 1},
  {&__pyx_n_s_ZERO, __pyx_k_ZERO, sizeof(__pyx_k_ZERO), 0, 0, 1, 1},
  {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
  {&__pyx_kp_u__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 1, 0, 0},
  {&__pyx_kp_u__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 1, 0, 0},
  {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
  {&__pyx_kp_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 0},
  {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
  {&__pyx_kp_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 0},
  {&__pyx_n_u_baz, __pyx_k_baz, sizeof(__pyx_k_baz), 0, 1, 0, 1},
  {&__pyx_n_u_bir, __pyx_k_bir, sizeof(__pyx_k_bir), 0, 1, 0, 1},
  {&__pyx_n_u_birbiri, __pyx_k_birbiri, sizeof(__pyx_k_birbiri), 0, 1, 0, 1},
  {&__pyx_n_u_birbirleri, __pyx_k_birbirleri, sizeof(__pyx_k_birbirleri), 0, 1, 0, 1},
  {&__pyx_n_u_birka, __pyx_k_birka, sizeof(__pyx_k_birka), 0, 1, 0, 1},
  {&__pyx_n_u_btn, __pyx_k_btn, sizeof(__pyx_k_btn), 0, 1, 0, 1},
  {&__pyx_n_u_bu, __pyx_k_bu, sizeof(__pyx_k_bu), 0, 1, 0, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_containsTag, __pyx_k_containsTag, sizeof(__pyx_k_containsTag), 0, 0, 1, 1},
  {&__pyx_n_u_daha, __pyx_k_daha, sizeof(__pyx_k_daha), 0, 1, 0, 1},
  {&__pyx_n_u_deil, __pyx_k_deil, sizeof(__pyx_k_deil), 0, 1, 0, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_u_diye, __pyx_k_diye, sizeof(__pyx_k_diye), 0, 1, 0, 1},
  {&__pyx_n_u_eer, __pyx_k_eer, sizeof(__pyx_k_eer), 0, 1, 0, 1},
  {&__pyx_n_u_en, __pyx_k_en, sizeof(__pyx_k_en), 0, 1, 0, 1},
  {&__pyx_n_u_et, __pyx_k_et, sizeof(__pyx_k_et), 0, 1, 0, 1},
  {&__pyx_n_s_firstInflectionalGroup, __pyx_k_firstInflectionalGroup, sizeof(__pyx_k_firstInflectionalGroup), 0, 0, 1, 1},
  {&__pyx_n_s_getAspect, __pyx_k_getAspect, sizeof(__pyx_k_getAspect), 0, 0, 1, 1},
  {&__pyx_n_s_getCase, __pyx_k_getCase, sizeof(__pyx_k_getCase), 0, 0, 1, 1},
  {&__pyx_n_s_getDefinite, __pyx_k_getDefinite, sizeof(__pyx_k_getDefinite), 0, 0, 1, 1},
  {&__pyx_n_s_getDegree, __pyx_k_getDegree, sizeof(__pyx_k_getDegree), 0, 0, 1, 1},
  {&__pyx_n_s_getInflectionalGroup, __pyx_k_getInflectionalGroup, sizeof(__pyx_k_getInflectionalGroup), 0, 0, 1, 1},
  {&__pyx_n_s_getInflectionalGroupString, __pyx_k_getInflectionalGroupString, sizeof(__pyx_k_getInflectionalGroupString), 0, 0, 1, 1},
  {&__pyx_n_s_getLastInflectionalGroup, __pyx_k_getLastInflectionalGroup, sizeof(__pyx_k_getLastInflectionalGroup), 0, 0, 1, 1},
  {&__pyx_n_s_getMood, __pyx_k_getMood, sizeof(__pyx_k_getMood), 0, 0, 1, 1},
  {&__pyx_n_s_getNumType, __pyx_k_getNumType, sizeof(__pyx_k_getNumType), 0, 0, 1, 1},
  {&__pyx_n_s_getNumber, __pyx_k_getNumber, sizeof(__pyx_k_getNumber), 0, 0, 1, 1},
  {&__pyx_n_s_getPerson, __pyx_k_getPerson, sizeof(__pyx_k_getPerson), 0, 0, 1, 1},
  {&__pyx_n_s_getPolarity, __pyx_k_getPolarity, sizeof(__pyx_k_getPolarity), 0, 0, 1, 1},
  {&__pyx_n_s_getPos, __pyx_k_getPos, sizeof(__pyx_k_getPos), 0, 0, 1, 1},
  {&__pyx_n_s_getPronType, __pyx_k_getPronType, sizeof(__pyx_k_getPronType), 0, 0, 1, 1},
  {&__pyx_n_s_getReflex, __pyx_k_getReflex, sizeof(__pyx_k_getReflex), 0, 0, 1, 1},
  {&__pyx_n_s_getRootPos, __pyx_k_getRootPos, sizeof(__pyx_k_getRootPos), 0, 0, 1, 1},
  {&__pyx_n_s_getTag, __pyx_k_getTag, sizeof(__pyx_k_getTag), 0, 0, 1, 1},
  {&__pyx_n_s_getTagString, __pyx_k_getTagString, sizeof(__pyx_k_getTagString), 0, 0, 1, 1},
  {&__pyx_n_s_getTense, __pyx_k_getTense, sizeof(__pyx_k_getTense), 0, 0, 1, 1},
  {&__pyx_n_s_getTransitionList, __pyx_k_getTransitionList, sizeof(__pyx_k_getTransitionList), 0, 0, 1, 1},
  {&__pyx_n_s_getTreePos, __pyx_k_getTreePos, sizeof(__pyx_k_getTreePos), 0, 0, 1, 1},
  {&__pyx_n_s_getUniversalDependencyFeatures, __pyx_k_getUniversalDependencyFeatures, sizeof(__pyx_k_getUniversalDependencyFeatures), 0, 0, 1, 1},
  {&__pyx_n_s_getUniversalDependencyPos, __pyx_k_getUniversalDependencyPos, sizeof(__pyx_k_getUniversalDependencyPos), 0, 0, 1, 1},
  {&__pyx_n_s_getVerbForm, __pyx_k_getVerbForm, sizeof(__pyx_k_getVerbForm), 0, 0, 1, 1},
  {&__pyx_n_s_getVoice, __pyx_k_getVoice, sizeof(__pyx_k_getVoice), 0, 0, 1, 1},
  {&__pyx_n_s_getWord, __pyx_k_getWord, sizeof(__pyx_k_getWord), 0, 0, 1, 1},
  {&__pyx_n_s_getWordWithPos, __pyx_k_getWordWithPos, sizeof(__pyx_k_getWordWithPos), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_u_hangi, __pyx_k_hangi, sizeof(__pyx_k_hangi), 0, 1, 0, 1},
  {&__pyx_n_u_her, __pyx_k_her, sizeof(__pyx_k_her), 0, 1, 0, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_isAdjective, __pyx_k_isAdjective, sizeof(__pyx_k_isAdjective), 0, 0, 1, 1},
  {&__pyx_n_s_isAuxiliary, __pyx_k_isAuxiliary, sizeof(__pyx_k_isAuxiliary), 0, 0, 1, 1},
  {&__pyx_n_s_isCapitalWord, __pyx_k_isCapitalWord, sizeof(__pyx_k_isCapitalWord), 0, 0, 1, 1},
  {&__pyx_n_s_isCardinal, __pyx_k_isCardinal, sizeof(__pyx_k_isCardinal), 0, 0, 1, 1},
  {&__pyx_n_s_isDate, __pyx_k_isDate, sizeof(__pyx_k_isDate), 0, 0, 1, 1},
  {&__pyx_n_s_isEmail, __pyx_k_isEmail, sizeof(__pyx_k_isEmail), 0, 0, 1, 1},
  {&__pyx_n_s_isFraction, __pyx_k_isFraction, sizeof(__pyx_k_isFraction), 0, 0, 1, 1},
  {&__pyx_n_s_isHashTag, __pyx_k_isHashTag, sizeof(__pyx_k_isHashTag), 0, 0, 1, 1},
  {&__pyx_n_s_isNoun, __pyx_k_isNoun, sizeof(__pyx_k_isNoun), 0, 0, 1, 1},
  {&__pyx_n_s_isNumber, __pyx_k_isNumber, sizeof(__pyx_k_isNumber), 0, 0, 1, 1},
  {&__pyx_n_s_isOrdinal, __pyx_k_isOrdinal, sizeof(__pyx_k_isOrdinal), 0, 0, 1, 1},
  {&__pyx_n_s_isPercent, __pyx_k_isPercent, sizeof(__pyx_k_isPercent), 0, 0, 1, 1},
  {&__pyx_n_s_isPlural, __pyx_k_isPlural, sizeof(__pyx_k_isPlural), 0, 0, 1, 1},
  {&__pyx_n_s_isProperNoun, __pyx_k_isProperNoun, sizeof(__pyx_k_isProperNoun), 0, 0, 1, 1},
  {&__pyx_n_s_isPunctuation, __pyx_k_isPunctuation, sizeof(__pyx_k_isPunctuation), 0, 0, 1, 1},
  {&__pyx_n_s_isRange, __pyx_k_isRange, sizeof(__pyx_k_isRange), 0, 0, 1, 1},
  {&__pyx_n_s_isReal, __pyx_k_isReal, sizeof(__pyx_k_isReal), 0, 0, 1, 1},
  {&__pyx_n_s_isRootVerb, __pyx_k_isRootVerb, sizeof(__pyx_k_isRootVerb), 0, 0, 1, 1},
  {&__pyx_n_s_isTime, __pyx_k_isTime, sizeof(__pyx_k_isTime), 0, 0, 1, 1},
  {&__pyx_n_s_isVerb, __pyx_k_isVerb, sizeof(__pyx_k_isVerb), 0, 0, 1, 1},
  {&__pyx_n_s_isupper, __pyx_k_isupper, sizeof(__pyx_k_isupper), 0, 0, 1, 1},
  {&__pyx_n_u_ka, __pyx_k_ka, sizeof(__pyx_k_ka), 0, 1, 0, 1},
  {&__pyx_n_u_kanc, __pyx_k_kanc, sizeof(__pyx_k_kanc), 0, 1, 0, 1},
  {&__pyx_n_u_kendi, __pyx_k_kendi, sizeof(__pyx_k_kendi), 0, 1, 0, 1},
  {&__pyx_n_u_ki, __pyx_k_ki, sizeof(__pyx_k_ki), 0, 1, 0, 1},
  {&__pyx_n_u_kim, __pyx_k_kim, sizeof(__pyx_k_kim), 0, 1, 0, 1},
  {&__pyx_n_s_lastIGContainsCase, __pyx_k_lastIGContainsCase, sizeof(__pyx_k_lastIGContainsCase), 0, 0, 1, 1},
  {&__pyx_n_s_lastIGContainsPossessive, __pyx_k_lastIGContainsPossessive, sizeof(__pyx_k_lastIGContainsPossessive), 0, 0, 1, 1},
  {&__pyx_n_s_lastIGContainsTag, __pyx_k_lastIGContainsTag, sizeof(__pyx_k_lastIGContainsTag), 0, 0, 1, 1},
  {&__pyx_n_s_lastInflectionalGroup, __pyx_k_lastInflectionalGroup, sizeof(__pyx_k_lastInflectionalGroup), 0, 0, 1, 1},
  {&__pyx_kp_u_lrb, __pyx_k_lrb, sizeof(__pyx_k_lrb), 0, 1, 0, 0},
  {&__pyx_n_u_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 1, 0, 1},
  {&__pyx_n_u_m_2, __pyx_k_m_2, sizeof(__pyx_k_m_2), 0, 1, 0, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_u_mi, __pyx_k_mi, sizeof(__pyx_k_mi), 0, 1, 0, 1},
  {&__pyx_n_u_mu, __pyx_k_mu, sizeof(__pyx_k_mu), 0, 1, 0, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_u_nasl, __pyx_k_nasl, sizeof(__pyx_k_nasl), 0, 1, 0, 1},
  {&__pyx_n_u_ne, __pyx_k_ne, sizeof(__pyx_k_ne), 0, 1, 0, 1},
  {&__pyx_n_u_nere, __pyx_k_nere, sizeof(__pyx_k_nere), 0, 1, 0, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_u_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 1, 0, 1},
  {&__pyx_n_u_ol, __pyx_k_ol, sizeof(__pyx_k_ol), 0, 1, 0, 1},
  {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_MorphologicalPars, __pyx_k_pyx_unpickle_MorphologicalPars, sizeof(__pyx_k_pyx_unpickle_MorphologicalPars), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_kp_u_rrb, __pyx_k_rrb, sizeof(__pyx_k_rrb), 0, 1, 0, 0},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_tagSize, __pyx_k_tagSize, sizeof(__pyx_k_tagSize), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_u_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 1, 0, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_u_yap, __pyx_k_yap, sizeof(__pyx_k_yap), 0, 1, 0, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 60, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":52
 *                 self.inflectionalGroups = []
 *                 if iGs[0] == "++Punc":
 *                     self.root = Word("+")             # <<<<<<<<<<<<<<
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))
 *                 else:
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":53
 *                 if iGs[0] == "++Punc":
 *                     self.root = Word("+")
 *                     self.inflectionalGroups.append(InflectionalGroup("Punc"))             # <<<<<<<<<<<<<<
 *                 else:
 *                     if iGs[0].index("+") != -1:
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_n_u_Punc_2); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "(tree fragment)":1
 * def __pyx_unpickle_MorphologicalParse(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__15 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_MorphologicalPars, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyUnicode_Type_index.type = (PyObject*)&PyUnicode_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_199806697 = PyInt_FromLong(199806697L); if (unlikely(!__pyx_int_199806697)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = &__pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getWord = (struct __pyx_obj_10Dictionary_4Word_Word *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWord;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getTransitionList = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTransitionList;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getInflectionalGroupString = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroupString;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getInflectionalGroup = (struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getInflectionalGroup;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getLastInflectionalGroup = (struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getLastInflectionalGroup;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getTag = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTag;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.tagSize = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_tagSize;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.size = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_size;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.firstInflectionalGroup = (struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_firstInflectionalGroup;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.lastInflectionalGroup = (struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastInflectionalGroup;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getWordWithPos = (struct __pyx_obj_10Dictionary_4Word_Word *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getWordWithPos;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getPos = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPos;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getRootPos = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getRootPos;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.lastIGContainsCase = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsCase;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.lastIGContainsTag = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsTag;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.lastIGContainsPossessive = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_lastIGContainsPossessive;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isCapitalWord = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCapitalWord;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isNoun = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNoun;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isVerb = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isVerb;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isRootVerb = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRootVerb;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isAdjective = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAdjective;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isProperNoun = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isProperNoun;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isPunctuation = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPunctuation;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isCardinal = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isCardinal;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isOrdinal = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isOrdinal;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isReal = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isReal;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isNumber = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isNumber;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isTime = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isTime;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isDate = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isDate;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isHashTag = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isHashTag;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isEmail = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isEmail;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isPercent = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPercent;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isFraction = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isFraction;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isRange = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isRange;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isPlural = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isPlural;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.isAuxiliary = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_isAuxiliary;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.containsTag = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_containsTag;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getTreePos = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTreePos;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getPronType = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPronType;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getNumType = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumType;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getReflex = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getReflex;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getNumber = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getNumber;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getCase = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getCase;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getDefinite = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDefinite;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getDegree = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getDegree;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getPolarity = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPolarity;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getPerson = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getPerson;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getVoice = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVoice;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getAspect = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getAspect;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getTense = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getTense;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getMood = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getMood;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getVerbForm = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getVerbForm;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getUniversalDependencyFeatures = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyFeatures;
  __pyx_vtable_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.getUniversalDependencyPos = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_getUniversalDependencyPos;
  if (PyType_Ready(&__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.tp_dictoffset && __pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 7, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__.doc = __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse___init__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse, "__str__"); if (unlikely(!wrapper)) __PYX_ERR(0, 7, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__.doc = __pyx_doc_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_21MorphologicalAnalysis_18MorphologicalParse_18MorphologicalParse_110__str__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse.tp_dict, __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_MorphologicalParse, (PyObject *)&__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = &__pyx_type_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Word"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Word_Word = __Pyx_ImportType(__pyx_t_1, "Dictionary.Word", "Word", sizeof(struct __pyx_obj_10Dictionary_4Word_Word), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Word_Word) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Word_Word = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Word_Word->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Word_Word)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.InflectionalGroup"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.InflectionalGroup", "InflectionalGroup", sizeof(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup) __PYX_ERR(3, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = (struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup)) __PYX_ERR(3, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initMorphologicalParse(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initMorphologicalParse(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_MorphologicalParse(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_MorphologicalParse(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_MorphologicalParse(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'MorphologicalParse' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_MorphologicalParse(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("MorphologicalParse", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_MorphologicalAnalysis__MorphologicalParse) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "MorphologicalAnalysis.MorphologicalParse")) {
      if (unlikely(PyDict_SetItemString(modules, "MorphologicalAnalysis.MorphologicalParse", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":4
 * 
 * from MorphologicalAnalysis.InflectionalGroup cimport InflectionalGroup
 * from MorphologicalAnalysis.MorphologicalTag import MorphologicalTag             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_MorphologicalTag);
  __Pyx_GIVEREF(__pyx_n_s_MorphologicalTag);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_MorphologicalTag);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_MorphologicalAnalysis_Morphologi, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_MorphologicalTag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MorphologicalTag, __pyx_t_1) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_MorphologicalParse(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_21MorphologicalAnalysis_18MorphologicalParse_1__pyx_unpickle_MorphologicalParse, NULL, __pyx_n_s_MorphologicalAnalysis_Morphologi_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_MorphologicalPars, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/MorphologicalParse.pyx":1
 * from Dictionary.Word cimport Word             # <<<<<<<<<<<<<<
 * 
 * from MorphologicalAnalysis.InflectionalGroup cimport InflectionalGroup
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init MorphologicalAnalysis.MorphologicalParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init MorphologicalAnalysis.MorphologicalParse");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if (PY_VERSION_HEX >= 0x030600B1 && flag == METH_FASTCALL) {
            if (PY_VERSION_HEX >= 0x030700A0) {
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            } else {
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            }
        } else if (PY_VERSION_HEX >= 0x030700A0 && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_empty_unicode);
#if CYTHON_PEP393_ENABLED
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#else
    return PyUnicode_FromUnicode(PyUnicode_AS_UNICODE(text)+start, stop-start);
#endif
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_FALSE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a != b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_TRUE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_TRUE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a != (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
